---
name: d.background.py
description: Fills the graphics display frame with user defined color.
keywords: [ display, graphics, background, fill, erase ]
---

# d.background.py

## NAME

***d.background.py*** - Fills the graphics display frame with user defined color.

### 
### SYNOPSIS

**d.background.py**  
**d.background.py --help**  
**d.background.py**  **color**=*name*
 [**--verbose**]  [**--quiet**]  [**--ui**]

**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**color**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Background color  
&nbsp;&nbsp;&nbsp;&nbsp;Either a standard color name or R:G:B triplet

## DESCRIPTION

*d.background* will fill the image (or generally display monitor) with a
single color specified by the **color** option.

## NOTES

*d.background* is a frontend to *d.erase* and shares its limitations.
Namely, it does not work with the wx monitors such as `d.mon wx0`.

## EXAMPLES

In this example, the *streets_wake* map from the North Carolina sample
dataset is displayed with custom background color (specified using HTML
hex color code) using *cairo* display monitor (creates file called
*map.png*):

```sh
g.region vector=streets_wake
d.mon cairo
d.background color=#ADEFD1
d.vect map=streets_wake color=#00203F legend_label="Streets"
d.legend.vect -b at=70,30 title="Wake County"
```

![Street network with legend and background color](d_background.png)

Figure: Wake County street network with custom background color (North
Carolina sample dataset)

## SEE ALSO

*[d.erase](d.erase.md)*

## AUTHOR

Vaclav Petras, [NCSU GeoForAll
Lab](https://geospatial.ncsu.edu/geoforall/)

## SOURCE CODE

Available at: [d.background source code](https://github.com/OSGeo/grass/tree/main/scripts/d.background)
([history](https://github.com/OSGeo/grass/commits/main/scripts/d.background))  
Latest change: Friday Feb 07 19:16:09 2025 in commit [a82a39f](https://github.com/OSGeo/grass/commit/a82a39f673b97fafcfce1604dc3e6015cb96487a)
