---
name: d.histogram
description: Displays a histogram in the form of a pie or bar chart for a user-specified raster map.
keywords: [ display, histogram, statistics ]
---

# d.histogram

## NAME

***d.histogram*** - Displays a histogram in the form of a pie or bar chart for a user-specified raster map.

### 
### SYNOPSIS

**d.histogram**  
**d.histogram --help**  
**d.histogram** [**-nc**]  **map**=*name*
 [**style**=*string*]
 [**color**=*name*]
 [**bgcolor**=*name*]
 [**nsteps**=*integer*]
 [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**-n**  
&nbsp;&nbsp;&nbsp;&nbsp;Display information for null cells  
**-c**  
&nbsp;&nbsp;&nbsp;&nbsp;Report for ranges defined in cats file (fp maps only)  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**map**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Raster map for which histogram will be displayed  
**style**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Indicate if a pie or bar chart is desired  
&nbsp;&nbsp;&nbsp;&nbsp;Options: *pie, bar*  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *bar*  
**color**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Color for text and axes  
&nbsp;&nbsp;&nbsp;&nbsp;Either a standard color name or R:G:B triplet  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *black*  
**bgcolor**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Background color  
&nbsp;&nbsp;&nbsp;&nbsp;Either a standard color name, R:G:B triplet, or "none"  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *white*  
**nsteps**=*integer*  
&nbsp;&nbsp;&nbsp;&nbsp;Number of steps to divide the data range into (fp maps only)  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *255*

## DESCRIPTION

*d.histogram* displays the category-value distribution for a
user-specified raster map layer, in the form of a bar chart or a pie
chart. The display will be displayed in the active display frame on the
graphics monitor, using the colors in the raster map layer's color
table. The program determines the raster map's category value
distribution by counting cells.

## NOTES

*d.histogram* respects the current geographic region settings and the
current raster mask (if mask is active).

*d.histogram* uses the colors in the map's color look-up table (i.e.,
the map's *colr* or *colr2* file).

## EXAMPLES

Running the command below will generate the bar graph shown in the
figure:

```sh
g.region raster=elevation -p
d.mon wx0
d.histogram map=elevation
```

![d.histogram bar graph example](d_histogram_bar.png)  
*Figure: Bar graph histogram for elevation map*

Running the command below will generate the pie graph shown in the
figure:

```sh
g.region raster=landuse96_28m -p
d.histogram map=landuse96_28m style=pie
```

![d.histogram pie graph example](d_histogram_pie.png)  
*Figure: Pie graph histogram for landuse map*

## SEE ALSO

*[d.colortable](d.colortable.md), [d.frame](d.frame.md),
[d.graph](d.graph.md), [d.linegraph](d.linegraph.md), [d.mon](d.mon.md),
[d.polar](d.polar.md), [g.region](g.region.md), [r.stats](r.stats.md)*

## AUTHOR

Dave Johnson  
DBA Systems, Inc.  
10560 Arrowhead Drive  
Fairfax, Virginia 22030

## SOURCE CODE

Available at: [d.histogram source code](https://github.com/OSGeo/grass/tree/main/display/d.histogram)
([history](https://github.com/OSGeo/grass/commits/main/display/d.histogram))  
Latest change: Wednesday Apr 02 16:37:00 2025 in commit [a2fa5a0](https://github.com/OSGeo/grass/commit/a2fa5a049335dbfbe721c8d1b20b9db51c2c0f64)
