---
name: d.path
description: Finds shortest path for selected starting and ending node.
keywords: [ display, network, shortest path ]
---

# d.path

## NAME

***d.path*** - Finds shortest path for selected starting and ending node.

### 
### SYNOPSIS

**d.path**  
**d.path --help**  
**d.path** [**-gb**]  **map**=*name*
 [**arc_type**=*string* [,*string*,...]]
 **coordinates**=*x1,y1,x2,y2*
 [**arc_layer**=*string*]
 [**node_layer**=*string*]
 [**arc_column**=*string*]
 [**arc_backward_column**=*string*]
 [**node_column**=*string*]
 [**highlight_color**=*string*]
 [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**-g**  
&nbsp;&nbsp;&nbsp;&nbsp;Use geodesic calculation for longitude-latitude locations  
**-b**  
&nbsp;&nbsp;&nbsp;&nbsp;Render bold lines  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**map**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of vector map  
&nbsp;&nbsp;&nbsp;&nbsp;Or data source for direct OGR access  
**arc_type**=*string* [,*string*,...]  
&nbsp;&nbsp;&nbsp;&nbsp;Arc type  
&nbsp;&nbsp;&nbsp;&nbsp;Options: *line, boundary*  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *line,boundary*  
**coordinates**=*x1,y1,x2,y2* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Starting and ending coordinates  
**arc_layer**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Arc layer  
&nbsp;&nbsp;&nbsp;&nbsp;Vector features can have category values in different layers. This number determines which layer to use. When used with direct OGR access this is the layer name.  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *1*  
**node_layer**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Node layer  
&nbsp;&nbsp;&nbsp;&nbsp;Vector features can have category values in different layers. This number determines which layer to use. When used with direct OGR access this is the layer name.  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *2*  
**arc_column**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Arc forward/both direction(s) cost column (number)  
**arc_backward_column**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Arc backward direction cost column (number)  
**node_column**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Node cost column  
**highlight_color**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Highlight color  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *red*

## DESCRIPTION

*d.path* enables shortest path vector networking. Costs may be either
line lengths, or attributes saved in a database table. Supported are
cost assignments for both arcs and nodes, and also different in both
directions of a vector line. For areas cost will be calculated along
boundary lines.

## NOTE

The user needs to display a vector map before using d.path. If no
graphics monitor is open, a file `map.png` is generated in the current
directory.

The 'from' and 'to' points are entered by mouse into the map displayed
in the GRASS monitor, or if the **coordinates** option is used they can
be specified non-interactively. The actions bound to the mouse buttons
are described in the terminal window when running the command.

To calculate shortest path non-interactively and save the path to a new
vector map, use the *v.net.path* module.

## EXAMPLES

Interactive shortest path routing on road network (North Carolina sample
dataset):

```sh
g.region vector=roadsmajor -p
d.vect roadsmajor
d.path roadsmajor coordinates=668646.15,224447.16,668348.83,235894.02
```

Non-interactive shortest path routing on road network (North Carolina
sample dataset):

```sh
d.path -b roadsmajor coordinates=668646.15,224447.16,668348.83,235894.02
```

## SEE ALSO

*[v.net.path](v.net.path.md)*

## AUTHOR

Radim Blazek, ITC-Irst, Trento, Italy

## SOURCE CODE

Available at: [d.path source code](https://github.com/OSGeo/grass/tree/main/display/d.path)
([history](https://github.com/OSGeo/grass/commits/main/display/d.path))  
Latest change: Friday Feb 07 19:16:09 2025 in commit [a82a39f](https://github.com/OSGeo/grass/commit/a82a39f673b97fafcfce1604dc3e6015cb96487a)
