---
name: d.text
description: Draws text in the active display frame on the graphics monitor using the current font.
keywords: [ display, cartography ]
---

# d.text

## NAME

***d.text*** - Draws text in the active display frame on the graphics monitor using the current font.

### 
### SYNOPSIS

**d.text**  
**d.text --help**  
**d.text** [**-pgbrs**]  [**text**=*string*]
 [**input**=*name*]
 [**color**=*name*]
 [**bgcolor**=*name*]
 [**rotation**=*float*]
 [**linespacing**=*float*]
 [**at**=*x,y*]
 [**line**=*integer*]
 [**align**=*string*]
 [**font**=*string*]
 [**size**=*float*]
 [**path**=*name*]
 [**charset**=*string*]
 [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**-p**  
&nbsp;&nbsp;&nbsp;&nbsp;Screen position in pixels ([0,0] is top left)  
**-g**  
&nbsp;&nbsp;&nbsp;&nbsp;Screen position in geographic coordinates  
**-b**  
&nbsp;&nbsp;&nbsp;&nbsp;Use bold text  
**-r**  
&nbsp;&nbsp;&nbsp;&nbsp;Use radians instead of degrees for rotation  
**-s**  
&nbsp;&nbsp;&nbsp;&nbsp;Font size is height in pixels  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**text**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Text to display  
**input**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Input file  
**color**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Text color  
&nbsp;&nbsp;&nbsp;&nbsp;Either a standard color name or R:G:B triplet  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *gray*  
**bgcolor**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Text background color  
&nbsp;&nbsp;&nbsp;&nbsp;Either a standard color name, R:G:B triplet, or "none"  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *none*  
**rotation**=*float*  
&nbsp;&nbsp;&nbsp;&nbsp;Rotation angle in degrees (counter-clockwise)  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *0*  
**linespacing**=*float*  
&nbsp;&nbsp;&nbsp;&nbsp;Line spacing  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *1.25*  
**at**=*x,y*  
&nbsp;&nbsp;&nbsp;&nbsp;Screen position at which text will begin to be drawn (percentage, [0,0] is lower left)  
**line**=*integer*  
&nbsp;&nbsp;&nbsp;&nbsp;The screen line number on which text will begin to be drawn  
&nbsp;&nbsp;&nbsp;&nbsp;Options: *1-1000*  
**align**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Text alignment  
&nbsp;&nbsp;&nbsp;&nbsp;Options: *ll, lc, lr, cl, cc, cr, ul, uc, ur*  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *ll*  
**font**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Font name  
**size**=*float*  
&nbsp;&nbsp;&nbsp;&nbsp;Height of letters in percentage of available frame height  
&nbsp;&nbsp;&nbsp;&nbsp;Options: *0-100*  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *5*  
**path**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Path to font file  
**charset**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Text encoding (only applicable to TrueType fonts)

## DESCRIPTION

*d.text* draws text in the active display frame on the graphics monitor.
Text can be provided through standard input or redirected from a file
(using the UNIX redirection mechanism). In addition to the options
provided on the command line, colors, text size, font type, rotation
angle, and boldness can be adjusted with commands in the standard input
(i.e., if the user invokes *d.text* without options on the command line,
and then assigns values to these options on lines within the standard
input).

### Commands

**.C** *color*  
(where *color* is one of the available colors) causes text appearing on
subsequent lines to be drawn in that color.

**.G** *color*  
(where *color* is one of the available colors) causes the background of
text appearing on subsequent lines to be drawn in that color.

**.S** *size*  
(where *size* is a percentage within the range 0 to 100) adjusts text
size. Note that a size of 10 would allow 10 lines to be drawn in the
active display frame, 5 would allow the drawing of 20 lines, and 50
would allow the drawing of 2 lines.

**.F** *font*  
(where *font* is one of the fonts known by the GRASS program
*[d.font](d.font.md)*) manipulates the font type. Available fonts are
listed in the GRASS manual entry for *[d.font](d.font.md)*. The default
font type used (if unspecified by the user) is *romans*.

**.R** *rotation*  
(where *rotation* is an angle in degrees, counter-clockwise) to rotate
the text.

**.B 1**  
stipulates that following text be printed in **bold**. This command
means *bold on*.

**.B 0**  
turns *bold off* of all text appearing on lines beneath it. (*Bold off*
is used by default, if unspecified by the user.)

## EXAMPLE

The following command will print the short phrase "This is a test of
d.text" in the active display frame using the color yellow, in bold, and
using 4/100'ths (4%) of the active frame's vertical space per line:

```sh
d.text text="This is a test of d.text" color=yellow bgcolor=gray size=4
```

![Displayed Text](d_text.png)  
*Displayed Text*

## NOTES

Note that the GRASS command *[d.title](d.title.md)* creates map TITLEs
in a format suitable for input to *d.text*.

*d.text* needs escape sequences that can be used within lines to change
colors, boldness, and perhaps size.

## SEE ALSO

*[d.font](d.font.md), [d.title](d.title.md), [d.labels](d.labels.md)*

## AUTHORS

James Westervelt, U.S. Army Construction Engineering Research Laboratory

Updates by Huidae Cho

## SOURCE CODE

Available at: [d.text source code](https://github.com/OSGeo/grass/tree/main/display/d.text)
([history](https://github.com/OSGeo/grass/commits/main/display/d.text))  
Latest change: Tuesday Feb 18 17:20:26 2025 in commit [688e625](https://github.com/OSGeo/grass/commit/688e625e7db3be9a465ce99ba25f36d2ebdd5aeb)
