---
name: db.dropcolumn.py
description: Drops a column from selected attribute table.
keywords: [ database, attribute table ]
---

# db.dropcolumn.py

## NAME

***db.dropcolumn.py*** - Drops a column from selected attribute table.

### 
### SYNOPSIS

**db.dropcolumn.py**  
**db.dropcolumn.py --help**  
**db.dropcolumn.py** [**-f**]  **table**=*name*
 **column**=*name*
 [**database**=*name*]
 [**driver**=*name*]
 [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**-f**  
&nbsp;&nbsp;&nbsp;&nbsp;Force removal (required for actual deletion of files)  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**table**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of attribute table  
**column**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of attribute column  
**database**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Name of database  
**driver**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Name of database driver  
&nbsp;&nbsp;&nbsp;&nbsp;Options: *dbf, odbc, ogr, sqlite, pg*

## DESCRIPTION

*db.dropcolumn* drops a column from an attribute table. If the **-f**
force flag is not given then nothing is removed, instead a preview of
the action to be taken is printed.

## NOTES

*db.dropcolumn* is a front-end to *db.execute* to allow easier usage
with a special workaround for the SQLite driver to support column drop
also for SQLite tables.

## EXAMPLE

Dropping a column (North Carolina sample dataset):

```sh
# work on own copy
g.copy vect=roadsmajor,myroads
db.describe -c myroads

# only shows what would happen:
db.dropcolumn myroads column=SHAPE_LEN

# actually drops the column
db.dropcolumn -f myroads column=SHAPE_LEN

db.describe -c myroads
```

## SEE ALSO

*[db.describe](db.describe.md), [db.droptable](db.droptable.md),
[db.execute](db.execute.md), [v.db.dropcolumn](v.db.dropcolumn.md),
[GRASS SQL interface](sql.md)*

## AUTHOR

Markus Neteler

## SOURCE CODE

Available at: [db.dropcolumn source code](https://github.com/OSGeo/grass/tree/main/scripts/db.dropcolumn)
([history](https://github.com/OSGeo/grass/commits/main/scripts/db.dropcolumn))  
Latest change: Wednesday Mar 12 22:27:28 2025 in commit [0095480](https://github.com/OSGeo/grass/commit/0095480779ff07f10b76a859388850c52b9dccbd)
