---
name: db.droptable.py
description: Drops an attribute table.
keywords: [ database, attribute table ]
---

# db.droptable.py

## NAME

***db.droptable.py*** - Drops an attribute table.

### 
### SYNOPSIS

**db.droptable.py**  
**db.droptable.py --help**  
**db.droptable.py** [**-f**]  [**driver**=*name*]
 [**database**=*name*]
 **table**=*name*
 [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**-f**  
&nbsp;&nbsp;&nbsp;&nbsp;Force removal (required for actual deletion of files)  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**driver**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Name of database driver  
&nbsp;&nbsp;&nbsp;&nbsp;If not given then default driver is used  
**database**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Name of database  
&nbsp;&nbsp;&nbsp;&nbsp;If not given then default database is used  
**table**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of table to drop

## DESCRIPTION

*db.droptable* drops an attribute table. If the **-f** force flag is not
given then nothing is removed, instead a preview of the action to be
taken is printed.

## NOTES

*db.droptable* is a front-end to *[db.execute](db.execute.md)* to allow
easier usage. To some extent it is verified if the table is connected to
a vector map to avoid accidental table removal.

## EXAMPLES

### Removing an attribute table from default database

```sh
# show default database
db.connect -p

# show available tables
db.tables -p

# this will show what would happen
db.droptable table=sometable

# actually drop the table
db.droptable -f table=sometable
```

### Removing an attribute table from given database

*db.droptable* allows defining optionally **driver** and **database**
options different from default connection settings (`db.connect -p`).

```sh
# drop the table from SQLite database
db.droptable -f table=sometable driver=sqlite database=/opt/sqlite.db
```

## SEE ALSO

*[db.dropdb](db.dropdb.md), [db.dropcolumn](db.dropcolumn.md),
[db.execute](db.execute.md), [db.login](db.login.md),
[db.connect](db.connect.md), [db.tables](db.tables.md),
[db.describe](db.describe.md), [v.db.droptable](v.db.droptable.md),*

[GRASS SQL interface](sql.md)

## AUTHORS

Markus Neteler  
Driver and database options added by Martin Landa, Czech Technical
University in Prague, Czech Republic

## SOURCE CODE

Available at: [db.droptable source code](https://github.com/OSGeo/grass/tree/main/scripts/db.droptable)
([history](https://github.com/OSGeo/grass/commits/main/scripts/db.droptable))  
Latest change: Wednesday Mar 12 22:27:28 2025 in commit [0095480](https://github.com/OSGeo/grass/commit/0095480779ff07f10b76a859388850c52b9dccbd)
