---
name: db.login
description: Sets user/password for DB driver/database.
keywords: [ database, connection settings ]
---

# db.login

## NAME

***db.login*** - Sets user/password for DB driver/database.

### 
### SYNOPSIS

**db.login**  
**db.login --help**  
**db.login** [**-p**]  **driver**=*name*
 **database**=*name*
 [**user**=*string*]
 [**password**=*string*]
 [**host**=*string*]
 [**port**=*string*]
 [**--overwrite**]  [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**-p**  
&nbsp;&nbsp;&nbsp;&nbsp;Print connection settings and exit  
**--overwrite**  
&nbsp;&nbsp;&nbsp;&nbsp;Allow output files to overwrite existing files  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**driver**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of database driver  
&nbsp;&nbsp;&nbsp;&nbsp;Options: *dbf, odbc, ogr, pg, sqlite*  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *sqlite*  
**database**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of database  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *$GISDBASE/$LOCATION_NAME/$MAPSET/sqlite/sqlite.db*  
**user**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Username  
**password**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Password  
**host**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Hostname  
&nbsp;&nbsp;&nbsp;&nbsp;Relevant only for pg and mysql driver  
**port**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Port  
&nbsp;&nbsp;&nbsp;&nbsp;Relevant only for pg and mysql driver

## DESCRIPTION

*db.login* sets login parameters such an user name and optionally also a
password, a hostname or a port for the connection to the selected
**database** through the DB **driver**.

## NOTE

Options **host** and **port** are related to only SQL database backends
like [PostgreSQL](grass-pg.md), [MySQL](grass-mysql.md) or
[ODBC](grass-odbc.md).

Note that the passwords are stored in a hidden, *unencrypted* file in
the user account, specifically

- in the 'home' directory, i.e. `$HOME/.grass8/dblogin` (Unix-like
  systems)
- `%APPDATA%\Roaming\GRASS8\dblogin` (MS-Windows)

Only the file owner can access this file.

## EXAMPLES

Only username specified (assuming locally accessible PostgreSQL DB
without password):

```sh
db.login driver=pg database=mydb
```

Username, password and hostname specified (note that the command lines
history will store the password in this way):

```sh
db.login driver=pg database=mydb user=bacava password=secret host=db.example.com
```

Username and empty password specified:

```sh
db.login driver=pg database=mydb user=bacava password=""
```

## SEE ALSO

*[db.connect](db.connect.md), [db.test](db.test.md),
[db.tables](db.tables.md)*

[SQL support in GRASS GIS](sql.md)

## AUTHOR

Radim Blazek  
Support for hostname and port by Martin Landa, OSGeoREL, Czech Technical
University in Prague, Czech Republic (GRASS 7.1)

## SOURCE CODE

Available at: [db.login source code](https://github.com/OSGeo/grass/tree/main/db/db.login)
([history](https://github.com/OSGeo/grass/commits/main/db/db.login))  
Latest change: Friday Feb 07 19:16:09 2025 in commit [a82a39f](https://github.com/OSGeo/grass/commit/a82a39f673b97fafcfce1604dc3e6015cb96487a)
