---
name: db.out.ogr.py
description: Exports attribute tables into various formats.
keywords: [ database, export, output, attribute table ]
---

# db.out.ogr.py

## NAME

***db.out.ogr.py*** - Exports attribute tables into various formats.

### 
### SYNOPSIS

**db.out.ogr.py**  
**db.out.ogr.py --help**  
**db.out.ogr.py**  **input**=*name*
 **output**=*name*
 [**layer**=*string*]
 **format**=*string*
 [**table**=*name*]
 [**--overwrite**]  [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**--overwrite**  
&nbsp;&nbsp;&nbsp;&nbsp;Allow output files to overwrite existing files  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**input**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;GRASS table name  
&nbsp;&nbsp;&nbsp;&nbsp;Or data source for direct OGR access  
**output**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Output table file name or DB connection string  
**layer**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Layer number or name  
&nbsp;&nbsp;&nbsp;&nbsp;Vector features can have category values in different layers. This number determines which layer to use. When used with direct OGR access this is the layer name.  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *1*  
**format**=*string* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Table format  
&nbsp;&nbsp;&nbsp;&nbsp;Options: *CSV, DBF, GML, MySQL, PostgreSQL, SQLite*  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *CSV*  
**table**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Name for output table (default: input name)

## DESCRIPTION

*db.out.ogr* exports GRASS GIS attribute tables into various formats as
supported by the OGR driver on the local system (CSV, DBF, PostgreSQL,
SQLite, MySQL, ODBC, etc.).

The *output* parameter is used to define the output file name (if the
path is not defined, the module will attempt to write to the current
directory). In case of a database connection as output, the connection
string has to be specified.

The *layer* parameter is needed if the attribute table to be exported is
linked as non-default layer to a vector map.

## EXAMPLES

### Export of GRASS GIS attribute table to a CSV table file (default format)

```sh
db.out.ogr input=precip_30ynormals output=precip_30ynormals.csv
```

### Export of a GRASS GIS attribute table to a DBF table

```sh
db.out.ogr input=precip_30ynormals output=precip_30ynormals.dbf format=DBF
```

### Export of GRASS GIS attribute table into a PostgreSQL table

```sh
db.out.ogr input=precip_30ynormals \
           output="PG:host=localhost dbname=meteo user=neteler" \
           format=PostgreSQL
# verify
echo "SELECT * FROM precip_30ynormals" | psql meteo
```

## SEE ALSO

*[db.tables](db.tables.md)*

*[GRASS SQL interface](sql.md)*

## AUTHORS

Markus Neteler  
Converted to Python by Glynn Clements

## SOURCE CODE

Available at: [db.out.ogr source code](https://github.com/OSGeo/grass/tree/main/scripts/db.out.ogr)
([history](https://github.com/OSGeo/grass/commits/main/scripts/db.out.ogr))  
Latest change: Friday Feb 07 19:16:09 2025 in commit [a82a39f](https://github.com/OSGeo/grass/commit/a82a39f673b97fafcfce1604dc3e6015cb96487a)
