---
name: db.select
description: Performs SQL query statement(s).
keywords: [ database, attribute table, SQL ]
---

# db.select

## NAME

***db.select*** - Selects data from attribute table.

Performs SQL query statement(s).

### 
### SYNOPSIS

**db.select**  
**db.select --help**  
**db.select** [**-cdvt**]  [**sql**=*sql_query*]
 [**input**=*name*]
 [**table**=*name*]
 [**driver**=*name*]
 [**database**=*name*]
 [**separator**=*character*]
 [**vertical_separator**=*character*]
 [**null_value**=*string*]
 [**output**=*name*]
 [**--overwrite**]  [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**-c**  
&nbsp;&nbsp;&nbsp;&nbsp;Do not include column names in output  
**-d**  
&nbsp;&nbsp;&nbsp;&nbsp;Describe query only (don't run it)  
**-v**  
&nbsp;&nbsp;&nbsp;&nbsp;Vertical output (instead of horizontal)  
**-t**  
&nbsp;&nbsp;&nbsp;&nbsp;Only test query, do not execute  
**--overwrite**  
&nbsp;&nbsp;&nbsp;&nbsp;Allow output files to overwrite existing files  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**sql**=*sql_query*  
&nbsp;&nbsp;&nbsp;&nbsp;SQL SELECT statement  
&nbsp;&nbsp;&nbsp;&nbsp;Example: select \* from towns where population &gt; 10000  
**input**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Name of file containing SQL select statement(s)  
&nbsp;&nbsp;&nbsp;&nbsp;'-' for standard input  
**table**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Name of table to query  
**driver**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Name of database driver  
&nbsp;&nbsp;&nbsp;&nbsp;Options: *dbf, odbc, ogr, pg, sqlite*  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *sqlite*  
**database**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Name of database  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *$GISDBASE/$LOCATION_NAME/$MAPSET/sqlite/sqlite.db*  
**separator**=*character*  
&nbsp;&nbsp;&nbsp;&nbsp;Field separator  
&nbsp;&nbsp;&nbsp;&nbsp;Special characters: pipe, comma, space, tab, newline  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *pipe*  
**vertical_separator**=*character*  
&nbsp;&nbsp;&nbsp;&nbsp;Vertical record separator (requires -v flag)  
&nbsp;&nbsp;&nbsp;&nbsp;Special characters: pipe, comma, space, tab, newline  
**null_value**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;String representing NULL value  
**output**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Name for output file (if omitted or "-" output to stdout)

## DESCRIPTION

*db.select* prints result of selection from database based on SQL
statement read from input file or from standard input to standard
output. Each individual query has to be written on one single line and
different queries have to be written on separate lines.

## NOTE

If parameters for database connection are already set with
*[db.connect](db.connect.md)*, they are taken as default values and do
not need to be specified each time. Output will be displayed to standard
output or can be directed to a file (option **output**).

## EXAMPLES

### Basic usage

```sh
db.select sql="select * from roads"
```

or

```sh
echo "select * from roads" | db.select input=-
```

or

```sh
db.select input=file.sql
```

or

```sh
cat file.sql | db.select input=-
```

Select all from table roads:

```sh
db.select -c driver=odbc database=mydb table=hospitals \
          input=file.sql output=result.csv
```

Select some string attribute, exclude others:

```sh
db.select sql="SELECT * FROM archsites WHERE str1 <> 'No Name'"
```

Select some string attribute with ZERO length:

```sh
db.select sql="SELECT * FROM archsites WHERE str1 IS NULL"
```

Select coordinates from PostGIS table:

```sh
db.select sql="SELECT x(geo),y(geo) FROM localizzazione"
```

### Execute multiple SQL statements

```sh
cat file.sql
SELECT * FROM busstopsall WHERE cat = 1
SELECT cat FROM busstopsall WHERE cat > 4 AND cat < 8

db.select input=file.sql
```

### Count number of cases falling into same position

When multiple observation have the spatial coordinates, they can still
be counted (if needed, coordinates can be uploaded to the attribute
table by *v.to.db*:

```sh
db.select sql="SELECT long,lat,site_id,department,obs,COUNT(long) as count_cases \
               FROM diseases GROUP BY long,lat"
```

## SEE ALSO

*[db.connect](db.connect.md), [db.describe](db.describe.md),
[db.drivers](db.drivers.md), [db.droptable](db.droptable.md),
[db.execute](db.execute.md), [db.login](db.login.md),
[db.tables](db.tables.md)*

*[GRASS SQL interface](sql.md)*

## AUTHORS

Original author unknown (probably CERL)  
Modifications by Radim Blazek, ITC-Irst, Trento, Italy  
Support for multiple statements by Martin Landa, Czech Technical
University in Prague

## SOURCE CODE

Available at: [db.select source code](https://github.com/OSGeo/grass/tree/main/db/db.select)
([history](https://github.com/OSGeo/grass/commits/main/db/db.select))  
Latest change: Friday Feb 07 19:16:09 2025 in commit [a82a39f](https://github.com/OSGeo/grass/commit/a82a39f673b97fafcfce1604dc3e6015cb96487a)
