---
name: db.univar.py
description: Calculates univariate statistics on selected table column.
keywords: [ database, statistics, attribute table ]
---

# db.univar.py

## NAME

***db.univar.py*** - Calculates univariate statistics on selected table column.

### 
### SYNOPSIS

**db.univar.py**  
**db.univar.py --help**  
**db.univar.py** [**-eg**]  **table**=*name*
 **column**=*name*
 [**database**=*name*]
 [**driver**=*name*]
 [**where**=*sql_query*]
 [**percentile**=*float* [,*float*,...]]
 [**format**=*string*]
 [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**-e**  
&nbsp;&nbsp;&nbsp;&nbsp;Extended statistics (quartiles and 90th percentile)  
**-g**  
&nbsp;&nbsp;&nbsp;&nbsp;Print stats in shell script style  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**table**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of attribute table  
**column**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of attribute column on which to calculate statistics (must be numeric)  
**database**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Name of database  
**driver**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Name of database driver  
&nbsp;&nbsp;&nbsp;&nbsp;Options: *dbf, odbc, ogr, sqlite, pg*  
**where**=*sql_query*  
&nbsp;&nbsp;&nbsp;&nbsp;WHERE conditions of SQL statement without 'where' keyword  
&nbsp;&nbsp;&nbsp;&nbsp;Example: income &lt; 1000 and population &gt;= 10000  
**percentile**=*float* [,*float*,...]  
&nbsp;&nbsp;&nbsp;&nbsp;Percentile to calculate (requires extended statistics flag)  
&nbsp;&nbsp;&nbsp;&nbsp;Options: *0-100*  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *90*  
**format**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Output format  
&nbsp;&nbsp;&nbsp;&nbsp;Options: *plain, json, shell*  
&nbsp;&nbsp;&nbsp;&nbsp;**plain**: Plain text output  
&nbsp;&nbsp;&nbsp;&nbsp;**json**: JSON (JavaScript Object Notation)  
&nbsp;&nbsp;&nbsp;&nbsp;**shell**: Shell script style for Bash eval

## DESCRIPTION

*db.univar* calculates basic univariate statistics for numeric
attributes in a data table. It will calculate minimum, maximum, range,
mean, standard deviation, variance, coefficient of variation, quartiles,
median, and 90th percentile. It uses *db.select* to create list values
for statistical calculations. *NOTES* If the database and driver are not
specified, the default values set in *db.connect* will be used.

## EXAMPLE

In this example, random points are sampled from the elevation map (North
Carolina sample dataset) and univariate statistics performed:

```sh
g.region raster=elevation -p
v.random output=samples n=100
v.db.addtable samples column="heights double precision"
v.what.rast samples raster=elevation column=heights
v.db.select samples

db.univar samples column=heights
```

## SEE ALSO

*[v.db.univar](v.db.univar.md), [r.univar](r.univar.md),
[v.univar](v.univar.md), [db.select](db.select.md),
[d.vect.thematic](d.vect.thematic.md)*

## AUTHORS

Michael Barton, Arizona State University

and authors of *r.univar.sh*

## SOURCE CODE

Available at: [db.univar source code](https://github.com/OSGeo/grass/tree/main/scripts/db.univar)
([history](https://github.com/OSGeo/grass/commits/main/scripts/db.univar))  
Latest change: Monday Mar 10 19:11:25 2025 in commit [9137ecc](https://github.com/OSGeo/grass/commit/9137ecc26b29bfbf19fa89149ab7a0931337963b)
