---
name: g.download.project.py
description: Get GRASS project from an URL or file path
keywords: [ general, data, download, import ]
---

# g.download.project.py

## NAME

***g.download.project.py*** - Download GRASS project from the web

Get GRASS project from an URL or file path

### 
### SYNOPSIS

**g.download.project.py**  
**g.download.project.py --help**  
**g.download.project.py**  **url**=*string*
 [**name**=*name*]
 [**path**=*path*]
 [**--verbose**]  [**--quiet**]  [**--ui**]

**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**url**=*string* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;URL of the archive with a project to be downloaded  
&nbsp;&nbsp;&nbsp;&nbsp;URL of ZIP, TAR.GZ, or other similar archive  
**name**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Project (location) name  
&nbsp;&nbsp;&nbsp;&nbsp;Project name (not path to project)  
**path**=*path*  
&nbsp;&nbsp;&nbsp;&nbsp;GRASS GIS database directory  
&nbsp;&nbsp;&nbsp;&nbsp;Default: path to the current GRASS GIS database

## DESCRIPTION

*g.download.project* downloads an archived (e.g., `.zip` or `.tar.gz`)
project (previously called location) from a given URL and unpacks it to
a specified or current GRASS GIS Spatial Database. URL can be also a
local file on the disk. If the archive contains a directory which
contains a project, the module will recognize that and use the project
automatically. The first directory which is a project is used. Other
projects or any other files are ignored.

## EXAMPLES

### Download the full GRASS GIS sample project within a running session

Download and unpack the full North Carolina sample project into the
user's HOME directory:

```sh
g.download.project url=https://grass.osgeo.org/sampledata/north_carolina/nc_spm_full_v2alpha2.tar.gz path=$HOME
```

### Download the full GRASS GIS sample project in a temporary session

In a temporary session, download and unpack the full North Carolina
sample project into the user's HOME directory:

```sh
grass --tmp-project XY --exec g.download.project url=https://grass.osgeo.org/sampledata/north_carolina/nc_spm_full_v2alpha2.tar.gz path=$HOME
```

## SEE ALSO

*[g.mapset](g.mapset.md), [g.mapsets](g.mapsets.md),
[r.proj](r.proj.md), [v.proj](v.proj.md),
[g.proj.all](https://grass.osgeo.org/grass-stable/manuals/addons/g.proj.all.html)*

## AUTHOR

Vaclav Petras, [NCSU GeoForAll
Lab](http://geospatial.ncsu.edu/geoforall/)

## SOURCE CODE

Available at: [g.download.project source code](https://github.com/OSGeo/grass/tree/main/scripts/g.download.project)
([history](https://github.com/OSGeo/grass/commits/main/scripts/g.download.project))  
Latest change: Monday Mar 10 22:43:37 2025 in commit [3df7050](https://github.com/OSGeo/grass/commit/3df7050671caae0961fb17f69cefad82ff99f6bf)
