---
name: g.search.modules.py
description: Search in GRASS modules using keywords
keywords: [ general, modules, search ]
---

# g.search.modules.py

## NAME

***g.search.modules.py*** - Search in GRASS modules using keywords

### 
### SYNOPSIS

**g.search.modules.py**  
**g.search.modules.py --help**  
**g.search.modules.py** [**-anmkcgj**]  [**keyword**=*string* [,*string*,...]]
 [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**-a**  
&nbsp;&nbsp;&nbsp;&nbsp;Display only modules where all keywords are available (AND), default: OR  
**-n**  
&nbsp;&nbsp;&nbsp;&nbsp;Invert selection (logical NOT)  
**-m**  
&nbsp;&nbsp;&nbsp;&nbsp;Search in manual pages too (can be slow)  
**-k**  
&nbsp;&nbsp;&nbsp;&nbsp;Search only for the exact keyword in module keyword list  
&nbsp;&nbsp;&nbsp;&nbsp;Instead of full text search, search only in actual keywords  
**-c**  
&nbsp;&nbsp;&nbsp;&nbsp;Use colorized (more readable) output to terminal  
**-g**  
&nbsp;&nbsp;&nbsp;&nbsp;Shell script format  
**-j**  
&nbsp;&nbsp;&nbsp;&nbsp;JSON format  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**keyword**=*string* [,*string*,...]  
&nbsp;&nbsp;&nbsp;&nbsp;Keyword to be searched  
&nbsp;&nbsp;&nbsp;&nbsp;List all modules if not given

## DESCRIPTION

*g.search.module* searches for given keyword in GRASS GIS modules name,
description, keywords and optionally manpages, too. Also installed
addons are considered in the search.

## NOTES

Multiple keywords may be specified, *g.search.modules* will search for
all of them.

## EXAMPLES

Search all modules, where keywords *buffer* OR *clip* can be found:

```sh
g.search.modules keyword=buffer,clip

r.circle
    keywords: raster,buffer,geometry,circle
    description: Creates a raster map containing concentric rings around a
                 given point.

r.buffer.lowmem
    keywords: raster,buffer
    description: Creates a raster map showing buffer zones surrounding cells
                 that contain non-NULL category values. This is the low-
                 memory alternative to the classic r.buffer module.

r.buffer
    keywords: raster,buffer
    description: Creates a raster map showing buffer zones surrounding cells
                 that contain non-NULL category values.
```

Search all modules, where keywords *overlay* AND *clip* can be found
with some fancy terminal output (not shown here):

```sh
g.search.modules keyword=clip,overlay -a -c

v.clip
    keywords: vector,clip,area
    description: Extracts features of input map which overlay features
                 of clip map.

v.overlay
    keywords: vector,geometry,spatial
              query,clip,difference,intersection,union
    description: Overlays two vector maps offering clip, intersection,
                 difference, symmetrical difference, union operators.
```

Search in manual pages as well:

```sh
g.search.modules -m keyword=kapri

db.execute
    keywords: database,attribute table,SQL
    description: Executes any SQL statement. For SELECT statements use
                 'db.select'.

db.select
    keywords: database,attribute table,SQL
    description: Selects data from attribute table. Performs SQL query
                 statement(s).
```

## SEE ALSO

*[g.manual](g.manual.md)*

## AUTHORS

Jachym Cepicky, OpenGeoLabs s.r.o., Czech Republic: original author  
Anika Bettge, mundialis, Germany: addon search added

## SOURCE CODE

Available at: [g.search.modules source code](https://github.com/OSGeo/grass/tree/main/scripts/g.search.modules)
([history](https://github.com/OSGeo/grass/commits/main/scripts/g.search.modules))  
Latest change: Friday Feb 07 19:16:09 2025 in commit [a82a39f](https://github.com/OSGeo/grass/commit/a82a39f673b97fafcfce1604dc3e6015cb96487a)
