---
name: i.aster.toar
description: Calculates Top of Atmosphere Radiance/Reflectance/Brightness Temperature from ASTER DN.
keywords: [ imagery, radiometric conversion, radiance, reflectance, brightness temperature, satellite, ASTER ]
---

# i.aster.toar

## NAME

***i.aster.toar*** - Calculates Top of Atmosphere Radiance/Reflectance/Brightness Temperature from ASTER DN.

### 
### SYNOPSIS

**i.aster.toar**  
**i.aster.toar --help**  
**i.aster.toar** [**-rabcde**]  **input**=*name* [,*name*,...]
 **dayofyear**=*float*
 **sun_elevation**=*float*
 **output**=*name*
 [**--overwrite**]  [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**-r**  
&nbsp;&nbsp;&nbsp;&nbsp;Output is radiance (W/m2)  
**-a**  
&nbsp;&nbsp;&nbsp;&nbsp;VNIR is High Gain  
**-b**  
&nbsp;&nbsp;&nbsp;&nbsp;SWIR is High Gain  
**-c**  
&nbsp;&nbsp;&nbsp;&nbsp;VNIR is Low Gain 1  
**-d**  
&nbsp;&nbsp;&nbsp;&nbsp;SWIR is Low Gain 1  
**-e**  
&nbsp;&nbsp;&nbsp;&nbsp;SWIR is Low Gain 2  
**--overwrite**  
&nbsp;&nbsp;&nbsp;&nbsp;Allow output files to overwrite existing files  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**input**=*name* [,*name*,...] **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Names of ASTER DN layers (15 layers)  
**dayofyear**=*float* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Day of Year of satellite overpass [0-366]  
**sun_elevation**=*float* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Sun elevation angle (degrees, &lt; 90.0)  
**output**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Base name of the output layers (will add .x)

## DESCRIPTION

*i.aster.toar* calculates the Top Of Atmosphere (TOA) reflectance for
Terra-ASTER L1B in the visible, NIR and SWIR bands (9+1 bands) and
brightness temperature for the TIR bands (5 bands), all from L1B DN
values. It is useful to apply after import of original ASTER imagery
that is generally in standard DN values range.

The order of input bands is

- VNIR: 1,2,3N,3B
- SWIR: 4,5,6,7,8,9
- TIR: 10,11,12,13,14

in one comma-separated list.

## NOTES

Internally, a gain code is defined to modify gains according to spectral
bands following the GeoSystems GmbH ATCOR Ver. 2.0 Calibration Files.
The function is defined in gain_aster.c file.

```sh
/*Gain Code*/
    /*0 - High (Not Applicable for band 10-14: TIR)*/
    /*1 - Normal*/
    /*2 - Low 1(Not Applicable for band 10-14: TIR)*/
    /*3 - Low 2(Not Applicable for Band 1-3N/B and 10-14)*/
```

## SEE ALSO

*[i.landsat.toar](i.landsat.toar.md), [r.in.aster](r.in.aster.md)*

ASTER sensor data download: [ASTER: Advanced Spaceborne Thermal Emission
and Reflection Radiometer](https://asterweb.jpl.nasa.gov/)

## AUTHOR

Yann Chemin, CSU, Australia

## SOURCE CODE

Available at: [i.aster.toar source code](https://github.com/OSGeo/grass/tree/main/imagery/i.aster.toar)
([history](https://github.com/OSGeo/grass/commits/main/imagery/i.aster.toar))  
Latest change: Wednesday Apr 02 17:48:37 2025 in commit [571253a](https://github.com/OSGeo/grass/commit/571253a5e75ae2ff6ba7adf14fbc859ba7acd92c)
