---
name: i.cca
description: Canonical components analysis (CCA) program for image processing.
keywords: [ imagery, statistics, CCA, canonical components analysis ]
---

# i.cca

## NAME

***i.cca*** - Canonical components analysis (CCA) program for image processing.

### 
### SYNOPSIS

**i.cca**  
**i.cca --help**  
**i.cca**  **group**=*name*
 **subgroup**=*name*
 **signature**=*name*
 **output**=*name*
 [**--overwrite**]  [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**--overwrite**  
&nbsp;&nbsp;&nbsp;&nbsp;Allow output files to overwrite existing files  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**group**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of input imagery group  
**subgroup**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of input imagery subgroup  
**signature**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;File containing spectral signatures  
**output**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Output raster map prefix name

## DESCRIPTION

**i.cca** is an image processing program that takes any number of
(raster) band files and a signature file, and outputs the same number of
raster band files transformed to provide maximum separability of the
categories indicated by the signatures. This implementation of the
canonical components transformation is based on the algorithm contained
in the [LAS image processing
system](http://dbwww.essc.psu.edu/lasdoc/user/canal.html). CCA is also
known as "Canonical components transformation".

Typically the user will use the *[g.gui.iclass](g.gui.iclass.md)*
program to collect a set of signatures and then pass those signatures
along with the raster band files to *i.cca*. The raster band file names
are specified on the command line by giving the group and subgroup that
were used to collect the signatures.

The output raster map names are built by appending a ".1", ".2", etc. to
the output raster map name specified on the command line.

### Parameters

**group**=*name*  
Name of the [imagery](i.group.md) group to which the raster band files
used belong.

**subgroup**=*name*  
Name of the [imagery](i.group.md) subgroup to which the raster band
files used belong.

**signature**=*name*  
Name of an ASCII file containing spectral signatures.

**output**=*name*  
Output raster map prefix name. The output raster map layer names are
built by appending a ".1", ".2", etc. onto the *output* name specified
by the user.

## NOTES

*i.cca* respects the current geographic region definition and the
current mask setting while performing the transformation.

## REFERENCES

Schowengerdt, Robert A. **Techniques for Image Processing and
Classification in Remote Sensing**, Academic Press, 1983.

## SEE ALSO

*[g.gui.iclass](g.gui.iclass.md), [i.gensig](i.gensig.md),
[i.cluster](i.cluster.md), [i.pca](i.pca.md), [r.covar](r.covar.md),
[r.mapcalc](r.mapcalc.md)*

## AUTHORS

David Satnik, GIS Laboratory, Central Washington University  
Ali R. Vali, University of Texas  
Semantic label support: Maris Nartiss, University of Latvia

## SOURCE CODE

Available at: [i.cca source code](https://github.com/OSGeo/grass/tree/main/imagery/i.cca)
([history](https://github.com/OSGeo/grass/commits/main/imagery/i.cca))  
Latest change: Monday Feb 24 16:07:55 2025 in commit [4ab71fd](https://github.com/OSGeo/grass/commit/4ab71fd34113b347c3c86c736cd82ca0f6be1d4b)
