---
name: i.eb.hsebal01
description: Computes sensible heat flux iteration SEBAL 01.
keywords: [ imagery, energy balance, soil moisture, evaporative fraction, SEBAL ]
---

# i.eb.hsebal01

## NAME

***i.eb.hsebal01*** - Computes sensible heat flux iteration SEBAL 01.

### 
### SYNOPSIS

**i.eb.hsebal01**  
**i.eb.hsebal01 --help**  
**i.eb.hsebal01** [**-ac**]  **netradiation**=*name*
 **soilheatflux**=*name*
 **aerodynresistance**=*name*
 **temperaturemeansealevel**=*name*
 **vapourpressureactual**=*name*
 **frictionvelocitystar**=*float*
 [**row_wet_pixel**=*float*]
 [**column_wet_pixel**=*float*]
 [**row_dry_pixel**=*float*]
 [**column_dry_pixel**=*float*]
 **output**=*name*
 [**--overwrite**]  [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**-a**  
&nbsp;&nbsp;&nbsp;&nbsp;Automatic wet/dry pixel (careful!)  
**-c**  
&nbsp;&nbsp;&nbsp;&nbsp;Dry/Wet pixels coordinates are in image projection, not row/col  
**--overwrite**  
&nbsp;&nbsp;&nbsp;&nbsp;Allow output files to overwrite existing files  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**netradiation**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of instantaneous net radiation raster map [W/m2]  
**soilheatflux**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of instantaneous soil heat flux raster map [W/m2]  
**aerodynresistance**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of aerodynamic resistance to heat momentum raster map [s/m]  
**temperaturemeansealevel**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of altitude corrected surface temperature raster map [K]  
**vapourpressureactual**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of the actual vapour pressure (e_act) map [KPa]  
**frictionvelocitystar**=*float* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Value of the height independent friction velocity (u\*) [m/s]  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *0.32407*  
**row_wet_pixel**=*float*  
&nbsp;&nbsp;&nbsp;&nbsp;Row value of the wet pixel  
**column_wet_pixel**=*float*  
&nbsp;&nbsp;&nbsp;&nbsp;Column value of the wet pixel  
**row_dry_pixel**=*float*  
&nbsp;&nbsp;&nbsp;&nbsp;Row value of the dry pixel  
**column_dry_pixel**=*float*  
&nbsp;&nbsp;&nbsp;&nbsp;Column value of the dry pixel  
**output**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name for output sensible heat flux raster map [W/m2]

## DESCRIPTION

*i.eb.hsebal01* will calculate the sensible heat flux map (h0), given
both maps of Net Radiation and soil Heat flux (Rn, g0) at instantaneous
time, the surface roughness (z0m), a map of the altitude corrected
temperature (t0dem), a point data of the frictional velocity (u\*), a
value of actual vapour pressure (ea\[KPa\]) and the (x,y) pairs for wet
and dry pixels. Full process will need those:

- *i.vi*, *i.albedo*, *r.latlong*, *i.emissivity*
- *i.evapo.potrad* (GRASS Addon)
- *i.eb.netrad*, *i.eb.soilheatflux*, *i.eb.hsebal01*
- *i.eb.evapfr*, *i.eb.eta*

(for time integration: *i.evapo.time_integration*)

*i.eb.hsebal01* performs the computation of *sensible heat flux*
\[W/m2\] after Bastiaanssen, 1995 in \[1\], used in this form in 2001 by
\[2\]. Implemented in this code in \[3\].

## NOTES

- z0m can be alculated by *i.eb.z0m* or *i.eb.z0m0* (GRASS Addons).
- ea can be calculated with standard meteorological data.  
  eoTmin=0.6108\*EXP(17.27\*Tmin/(Tmin+237.3))  
  eoTmax=0.6108\*EXP(17.27\*Tmax/(Tmax+237.3))  
  ea=(RH/100)/((eoTmin+eoTmax)/2)
- t0dem = surface temperature + (altitude \* 0.627 / 100)

## REFERENCES

\[1\] Bastiaanssen, W.G.M., 1995. Estimation of Land surface parameters
by remote sensing under clear-sky conditions. PhD thesis, Wageningen
University, Wageningen, The Netherlands.
([PDF](https://edepot.wur.nl/206553))

\[2\] Chemin Y., Alexandridis T.A., 2001. Improving spatial resolution
of ET seasonal for irrigated rice in Zhanghe, China. Asian Journal of
Geoinformatics. 5(1):3-11,2004.

\[3\] Alexandridis T.K., Cherif I., Chemin Y., Silleos N.G., Stavrinos
E., Zalidis G.C. Integrated methodology for estimating water use in
Mediterranean agricultural areas. Remote Sensing. 2009, 1, 445-465.
([PDF](https://doi.org/10.3390/rs1030445))

\[4\] Chemin, Y., 2012. A Distributed Benchmarking Framework for Actual
ET Models, in: Irmak, A. (Ed.), Evapotranspiration - Remote Sensing and
Modeling. InTech. ([PDF](https://www.intechopen.com/chapters/26115))

## SEE ALSO

*[i.eb.soilheatflux](i.eb.soilheatflux.md),
[i.eb.evapfr](i.eb.evapfr.md)*

## AUTHOR

Yann Chemin, International Rice Research Institute, Los Banos, The
Philippines.

Contact: [Yann Chemin](mailto:yann.chemin@gmail.com)

## SOURCE CODE

Available at: [i.eb.hsebal01 source code](https://github.com/OSGeo/grass/tree/main/imagery/i.eb.hsebal01)
([history](https://github.com/OSGeo/grass/commits/main/imagery/i.eb.hsebal01))  
Latest change: Wednesday Apr 02 17:48:37 2025 in commit [571253a](https://github.com/OSGeo/grass/commit/571253a5e75ae2ff6ba7adf14fbc859ba7acd92c)
