---
name: i.eb.netrad
description: Net radiation approximation (Bastiaanssen, 1995).
keywords: [ imagery, energy balance, net radiation, SEBAL ]
---

# i.eb.netrad

## NAME

***i.eb.netrad*** - Net radiation approximation (Bastiaanssen, 1995).

### 
### SYNOPSIS

**i.eb.netrad**  
**i.eb.netrad --help**  
**i.eb.netrad**  **albedo**=*name*
 **ndvi**=*name*
 **temperature**=*name*
 **localutctime**=*name*
 **temperaturedifference2m**=*name*
 **emissivity**=*name*
 **transmissivity_singleway**=*name*
 **dayofyear**=*name*
 **sunzenithangle**=*name*
 **output**=*name*
 [**--overwrite**]  [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**--overwrite**  
&nbsp;&nbsp;&nbsp;&nbsp;Allow output files to overwrite existing files  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**albedo**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of albedo raster map [0.0;1.0]  
**ndvi**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of NDVI raster map [-1.0;+1.0]  
**temperature**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of surface temperature raster map [K]  
**localutctime**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of time of satellite overpass raster map [local time in UTC]  
**temperaturedifference2m**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of the difference map of temperature from surface skin to about 2 m height [K]  
**emissivity**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of the emissivity map [-]  
**transmissivity_singleway**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of the single-way atmospheric transmissivitymap [-]  
**dayofyear**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of the Day Of Year (DOY) map [-]  
**sunzenithangle**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of the sun zenith angle map [degrees]  
**output**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of the output net radiation layer

## DESCRIPTION

*i.eb.netrad* calculates the net radiation at the time of satellite
overpass, the way it is in the SEBAL model of Bastiaanssen (1995). It
takes input of Albedo, NDVI, Surface Skin temperature, time of satellite
overpass, surface emissivity, difference of temperature from surface
skin and about 2 m height (dT), instantaneous satellite overpass
single-way atmospheric transmissivity (tsw), Day of Year (DOY), and sun
zenith angle.

## NOTES

In the old methods, dT was taken as flat images (dT=5.0), if you don't
have a dT map from ground data, you would want to try something in this
line, this is to calculate atmospherical energy balance. In the same
way, a standard tsw is used in those equations. Refer to `r_net.c` for
that and for other non-used equations, but stored in there for further
research convenience.

## TODO

Add more explanations.

## REFERENCES

- Bastiaanssen, W.G.M., 1995. Regionalization of surface flux densities
  and moisture indicators in composite terrain; a remote sensing
  approach under clear skies in mediterranean climates. PhD thesis,
  Wageningen Agricultural Univ., The Netherland, 271 pp.
  ([PDF](https://edepot.wur.nl/206553))
- Chemin, Y., 2012. A Distributed Benchmarking Framework for Actual ET
  Models, in: Irmak, A. (Ed.), Evapotranspiration - Remote Sensing and
  Modeling. InTech. ([PDF](https://www.intechopen.com/chapters/26115))

## SEE ALSO

*[i.eb.soilheatflux](i.eb.soilheatflux.md),
[i.eb.hsebal01](i.eb.hsebal01.md), [i.albedo](i.albedo.md)*

## AUTHOR

Yann Chemin, International Rice Research Institute, The Philippines

## SOURCE CODE

Available at: [i.eb.netrad source code](https://github.com/OSGeo/grass/tree/main/imagery/i.eb.netrad)
([history](https://github.com/OSGeo/grass/commits/main/imagery/i.eb.netrad))  
Latest change: Friday Feb 07 19:16:09 2025 in commit [a82a39f](https://github.com/OSGeo/grass/commit/a82a39f673b97fafcfce1604dc3e6015cb96487a)
