---
name: i.evapo.pt
description: Computes evapotranspiration calculation Priestley and Taylor formulation, 1972.
keywords: [ imagery, evapotranspiration ]
---

# i.evapo.pt

## NAME

***i.evapo.pt*** - Computes evapotranspiration calculation Priestley and Taylor formulation, 1972.

### 
### SYNOPSIS

**i.evapo.pt**  
**i.evapo.pt --help**  
**i.evapo.pt** [**-z**]  **net_radiation**=*name*
 **soil_heatflux**=*name*
 **air_temperature**=*name*
 **atmospheric_pressure**=*name*
 **priestley_taylor_coeff**=*float*
 **output**=*name*
 [**--overwrite**]  [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**-z**  
&nbsp;&nbsp;&nbsp;&nbsp;Set negative ETa to zero  
**--overwrite**  
&nbsp;&nbsp;&nbsp;&nbsp;Allow output files to overwrite existing files  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**net_radiation**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of input net radiation raster map [W/m2]  
**soil_heatflux**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of input soil heat flux raster map [W/m2]  
**air_temperature**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of input air temperature raster map [K]  
**atmospheric_pressure**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of input atmospheric pressure raster map [millibars]  
**priestley_taylor_coeff**=*float* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Priestley-Taylor coefficient  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *1.26*  
**output**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of output evapotranspiration raster map [mm/d]

## DESCRIPTION

*i.evapo.pt* Calculates the diurnal evapotranspiration after Prestley
and Taylor (1972). The Priestley-Taylor model (Priestley and Taylor,
1972) is a modification of Penman's more theoretical equation.

## NOTES

RNETD optional output from *i.evapo.potrad* is giving good results as
input for net radiation in this module.

Alpha values:

- 1.32 for estimates from vegetated areas as a result of the increase in
  surface roughness (Morton, 1983; Brutsaert and Stricker, 1979)
- 1.26 is applicable in humid climates (De Bruin and Keijman, 1979;
  Stewart and Rouse, 1976; Shuttleworth and Calder, 1979), and temperate
  hardwood swamps (Munro, 1979)
- 1.74 has been recommended for estimating potential evapotranspiration
  in more arid regions (ASCE, 1990). This worked well in Greece with
  University of Thessaloniki.

Alpha values extracted from: [Watflood
manual](http://www.civil.uwaterloo.ca/Watflood/Manual/02_03_1.htm).

## SEE ALSO

*[i.evapo.mh](i.evapo.mh.md), [i.evapo.pm](i.evapo.pm.md),
[i.evapo.time](i.evapo.time.md), [i.eb.netrad](i.eb.netrad.md),
[r.sun](r.sun.md)*

## AUTHOR

Yann Chemin, GRASS Development Team, 2007-08

## SOURCE CODE

Available at: [i.evapo.pt source code](https://github.com/OSGeo/grass/tree/main/imagery/i.evapo.pt)
([history](https://github.com/OSGeo/grass/commits/main/imagery/i.evapo.pt))  
Latest change: Friday Feb 07 19:16:09 2025 in commit [a82a39f](https://github.com/OSGeo/grass/commit/a82a39f673b97fafcfce1604dc3e6015cb96487a)
