---
name: i.ortho.transform
description: Computes a coordinate transformation based on the control points.
keywords: [ imagery, orthorectify, transformation, GCP ]
---

# i.ortho.transform

## NAME

***i.ortho.transform*** - Computes a coordinate transformation based on the control points.

### 
### SYNOPSIS

**i.ortho.transform**  
**i.ortho.transform --help**  
**i.ortho.transform** [**-srxp**]  **group**=*name*
 [**format**=*string* [,*string*,...]]
 [**coords**=*name*]
 [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**-s**  
&nbsp;&nbsp;&nbsp;&nbsp;Display summary information  
**-r**  
&nbsp;&nbsp;&nbsp;&nbsp;Reverse transform of coords file or coeff. dump  
&nbsp;&nbsp;&nbsp;&nbsp;Target east,north,height coordinates to local x,y,z  
**-x**  
&nbsp;&nbsp;&nbsp;&nbsp;Display transform matrix coefficients  
**-p**  
&nbsp;&nbsp;&nbsp;&nbsp;Enable panorama camera correction  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**group**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of input imagery group  
**format**=*string* [,*string*,...]  
&nbsp;&nbsp;&nbsp;&nbsp;Output format  
&nbsp;&nbsp;&nbsp;&nbsp;Options: *idx, src, dst, fwd, rev, fxy, rxy, fd, rd*  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *fd,rd*  
&nbsp;&nbsp;&nbsp;&nbsp;**idx**: point index  
&nbsp;&nbsp;&nbsp;&nbsp;**src**: source coordinates  
&nbsp;&nbsp;&nbsp;&nbsp;**dst**: destination coordinates  
&nbsp;&nbsp;&nbsp;&nbsp;**fwd**: forward coordinates (destination)  
&nbsp;&nbsp;&nbsp;&nbsp;**rev**: reverse coordinates (source)  
&nbsp;&nbsp;&nbsp;&nbsp;**fxy**: forward coordinates difference (destination)  
&nbsp;&nbsp;&nbsp;&nbsp;**rxy**: reverse coordinates difference (source)  
&nbsp;&nbsp;&nbsp;&nbsp;**fd**: forward error (destination)  
&nbsp;&nbsp;&nbsp;&nbsp;**rd**: reverse error (source)  
**coords**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;File containing coordinates to transform ("-" to read from stdin)  
&nbsp;&nbsp;&nbsp;&nbsp;Local x,y,z coordinates to target east,north,height

## DESCRIPTION

*i.ortho.transform* is an utility to compute transformation based upon
GCPs and output error measurements.

If coordinates are given with the **input** file option or fed from
`stdin`, both the input and the output format is "x y z" with one
coordinate pair per line. Reverse transform is performed with the **-r**
flag.

The **format** option determines how control points are printed out. A
summary on the control points can be printed with the **-s** flag. The
summary includes maximum deviation observed when transforming GCPs and
overall RMS. The **format** option is ignored when coordinates are given
with the **input** file option.

## NOTES

Ortho-transformation is a 2-step transformation. First, source
coordinates are transformed to sensor coordinates, then sensor
coordinates are transformed to target coordinates.

## SEE ALSO

*[i.rectify](i.rectify.md)*

## TODO

Update this document with x,y,z\<-\>E,N,H information

## AUTHORS

Brian J. Buckley  
Glynn Clements  
Hamish Bowman

## SOURCE CODE

Available at: [i.ortho.transform source code](https://github.com/OSGeo/grass/tree/main/imagery/i.ortho.photo/i.ortho.transform)
([history](https://github.com/OSGeo/grass/commits/main/imagery/i.ortho.photo/i.ortho.transform))  
Latest change: Wednesday Mar 19 14:27:15 2025 in commit [a56e76f](https://github.com/OSGeo/grass/commit/a56e76fdea227d834ac8884dc9009f97d87ca624)
