---
name: i.signatures
description: Manage imagery classification signature files
keywords: [ imagery, classification, signatures ]
---

# i.signatures

## NAME

***i.signatures*** - Manage imagery classification signature files

### 
### SYNOPSIS

**i.signatures**  
**i.signatures --help**  
**i.signatures** [**-p**]  [**type**=*name*]
 **format**=*name*
 [**mapset**=*name* [,*name*,...]]
 [**remove**=*name* [,*name*,...]]
 [**rename**=*from,to* [,*from,to*,...]]
 [**copy**=*from,to* [,*from,to*,...]]
 [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**-p**  
&nbsp;&nbsp;&nbsp;&nbsp;Print signature files  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**type**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Type of signature file  
&nbsp;&nbsp;&nbsp;&nbsp;Options: *sig, sigset, libsvm*  
**format**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Output format  
&nbsp;&nbsp;&nbsp;&nbsp;Options: *plain, json*  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *plain*  
&nbsp;&nbsp;&nbsp;&nbsp;**plain**: Plain text output  
&nbsp;&nbsp;&nbsp;&nbsp;**json**: JSON (JavaScript Object Notation)  
**mapset**=*name* [,*name*,...]  
&nbsp;&nbsp;&nbsp;&nbsp;Name of mapset to list  
&nbsp;&nbsp;&nbsp;&nbsp;Default: current search path  
**remove**=*name* [,*name*,...]  
&nbsp;&nbsp;&nbsp;&nbsp;Name of file(s) to remove  
**rename**=*from,to* [,*from,to*,...]  
&nbsp;&nbsp;&nbsp;&nbsp;Name of file to rename  
**copy**=*from,to* [,*from,to*,...]  
&nbsp;&nbsp;&nbsp;&nbsp;Name of file to copy

## DESCRIPTION

*i.signatures* module allows managing signature files:

- "sig" – generated by [i.gensig](i.gensig.md) for
  [i.maxlik](i.maxlik.md)
- "sigset" – generated by [i.gensigset](i.gensigset.md) for
  [i.smap](i.smap.md)
- "libsvm" - generated internally by [i.svm.train](i.svm.train.md) and used by
  [i.svm.predict](i.svm.predict.md) for classification.
The module can perform multiple actions per run. The order of execution
is "copy", "remove", "rename". When the print flag is specified without
specifying any type of signature files, it would print all signatures
grouped by type.

## NOTES

By default the module will list signature files from all mapsets in the
current search path. It is possible to limit listing only to a single
mapset by providing the "mapset" option. The mapset can be also not
listed in the current search path.  
Actions "remove" and "rename" operate only on the current mapset
(although accept fully qualified names). The "copy" action will accept a
signature file name from any mapset as its first argument (source file
to copy).

## EXAMPLES

Print names of all signature files:

```sh
i.signatures -p
```

Print only signature files of certain type as a JSON:

```sh
i.signatures -p type=sigset format=json
```

Delete signature file called "foo" of type "sig" (i.gensig / i.maxlik).

```sh
i.signatures remove=foo type=sig
```

Copy signature file "bar" from mapset "baz" to current mapset

```sh
i.signatures copy=bar@baz,best_version type=sigset
```

## SEE ALSO

*[i.gensig](i.gensig.md) [i.gensigset](i.gensigset.md) [i.svm.predict](i.svm.predict.md)*

## AUTHOR

Maris Nartiss

## SOURCE CODE

Available at: [i.signatures source code](https://github.com/OSGeo/grass/tree/main/imagery/i.signatures)
([history](https://github.com/OSGeo/grass/commits/main/imagery/i.signatures))  
Latest change: Wednesday Apr 02 10:01:47 2025 in commit [e328b0b](https://github.com/OSGeo/grass/commit/e328b0b93b6e035d0c434c3b7d4713a4200caf6a)
