---
name: i.spectral.py
description: Displays spectral response at user specified locations in group or images.
keywords: [ imagery, querying, raster, multispectral ]
---

# i.spectral.py

## NAME

***i.spectral.py*** - Displays spectral response at user specified locations in group or images.

### 
### SYNOPSIS

**i.spectral.py**  
**i.spectral.py --help**  
**i.spectral.py** [**-cgt**]  [**group**=*name*]
 [**subgroup**=*name*]
 [**raster**=*name* [,*name*,...]]
 **coordinates**=*east,north* [,*east,north*,...]
 [**output**=*name*]
 [**format**=*string*]
 [**--overwrite**]  [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**-c**  
&nbsp;&nbsp;&nbsp;&nbsp;Show sampling coordinates instead of numbering in the legend (valid for -g flag)  
**-g**  
&nbsp;&nbsp;&nbsp;&nbsp;Use gnuplot for display  
**-t**  
&nbsp;&nbsp;&nbsp;&nbsp;output to text file  
**--overwrite**  
&nbsp;&nbsp;&nbsp;&nbsp;Allow output files to overwrite existing files  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**group**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Name of input imagery group  
**subgroup**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Name of input imagery subgroup  
**raster**=*name* [,*name*,...]  
&nbsp;&nbsp;&nbsp;&nbsp;Name of input raster map(s)  
**coordinates**=*east,north* [,*east,north*,...] **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Coordinates  
**output**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Name for output image is valid for -g (or text file for -t flag)  
**format**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Graphics format for output file (valid for -g flag)  
&nbsp;&nbsp;&nbsp;&nbsp;Options: *png, eps, svg*  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *png*

## DESCRIPTION

*i.spectral* displays spectral response at user specified locations in
images.

## NOTES

This script requires the launch of one of the supported monitors (cairo,
png, ps) or gnuplot to be installed.

## EXAMPLE

Analysis of LANDSAT TM7 channels (North Carolina dataset):

```sh
g.region raster=lsat7_2002_10 -p
i.spectral -g raster=lsat7_2002_10,lsat7_2002_20,lsat7_2002_30,lsat7_2002_40,lsat7_2002_50,lsat7_2002_70 \
           coordinates=636069,215440,637958,223393,633277,223605
```

![Spectral plot of 3 different land cover types](i_spectral.png)  
*Spectral plot of 3 different land cover types: (1) water, (2) green
vegetation, and (3) highway*

North Carolina sample dataset:

```sh
g.region raster=lsat7_2002_10 -p
LIST=`g.list type=raster pattern="lsat7_2002_[1-5,7]0" separator=","`
d.mon start=cairo output=plot.png
i.spectral raster=$LIST coordinates=637502.25,221744.25
d.mon stop=cairo
```

This will search all LANDSAT map for 2002 but select only the B, G, R,
NIR, and MIR channels.

## SEE ALSO

*[d.where](d.where.md), [r.what](r.what.md), [Cairo
driver](cairodriver.md), [PNG driver](pngdriver.md), [PS driver
(Postscript)](psdriver.md)*

## AUTHORS

Markus Neteler  
Francesco Pirotti

## SOURCE CODE

Available at: [i.spectral source code](https://github.com/OSGeo/grass/tree/main/scripts/i.spectral)
([history](https://github.com/OSGeo/grass/commits/main/scripts/i.spectral))  
Latest change: Friday Mar 07 23:20:43 2025 in commit [b94776a](https://github.com/OSGeo/grass/commit/b94776ae711b613e98849395a1b4635336af9479)
