---
name: m.measure
description: Measures the lengths and areas of features.
keywords: [ miscellaneous, measurement, distance, area ]
---

# m.measure

## NAME

***m.measure*** - Measures the lengths and areas of features.

### 
### SYNOPSIS

**m.measure**  
**m.measure --help**  
**m.measure** [**-g**]  **coordinates**=*east,north* [,*east,north*,...]
 [**units**=*string*]
 [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**-g**  
&nbsp;&nbsp;&nbsp;&nbsp;Shell script style  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**coordinates**=*east,north* [,*east,north*,...] **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Coordinates  
**units**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Units  
&nbsp;&nbsp;&nbsp;&nbsp;Default: project map units  
&nbsp;&nbsp;&nbsp;&nbsp;Options: *miles, feet, meters, kilometers, acres, hectares*

## DESCRIPTION

*m.measure* provides the user with a way to measure the lengths and
areas of lines and polygons. Areas can be stated in acres, hectares,
square miles, square feet, square meters and square kilometers.

## EXAMPLES

Distance example in a latitude-longitude coordinate reference system (on
great circle, i.e. an orthodrome):

```sh
Bonn_DE="7.09549,50.73438"
Philadelphia_US="-75.16379,39.95233"

m.measure coordinates="$Bonn_DE,$Philadelphia_US" units=kilometers
Length:  6217.916452 kilometers
```

![Visualization (with d.geodesic) of m.measure distance example](m_measure_distance.png)  
*Visualization (with d.geodesic) of m.measure
distance example*

As an example for the North Carolina sample dataset, here four points
describing a square of 1000m side length:

```sh
m.measure units=meters \
  coordinates=922000,2106000,923000,2106000,923000,2107000,922000,2107000
Length:  3000.000000 meters
Area:    1000000.000000 square meters

# script style output:
m.measure -g units=hectares \
  coordinates=922000,2106000,923000,2106000,923000,2107000,922000,2107000
units=meters,square meters
length=3000.000000
area=1000000.000000
```

## SEE ALSO

*[d.geodesic](d.geodesic.md)*

## AUTHORS

Glynn Clements  
Some updates by Martin Landa, CTU in Prague, Czech Republic  
  
Derived from d.measure by James Westervelt, Michael Shapiro, U.S. Army
Construction Engineering Research Laboratory

## SOURCE CODE

Available at: [m.measure source code](https://github.com/OSGeo/grass/tree/main/misc/m.measure)
([history](https://github.com/OSGeo/grass/commits/main/misc/m.measure))  
Latest change: Wednesday Feb 12 23:02:46 2025 in commit [9c11460](https://github.com/OSGeo/grass/commit/9c1146064f7c3c21fb0746063fa8bd2cdf4633cb)
