---
name: r.blend.py
description: Blends color components of two raster maps by a given ratio.
keywords: [ raster, composite ]
---

# r.blend.py

## NAME

***r.blend.py*** - Blends color components of two raster maps by a given ratio.

### 
### SYNOPSIS

**r.blend.py**  
**r.blend.py --help**  
**r.blend.py** [**-c**]  **first**=*name*
 **second**=*name*
 **output**=*basename*
 [**percent**=*float*]
 [**--overwrite**]  [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**-c**  
&nbsp;&nbsp;&nbsp;&nbsp;Combine resulting R,G,B layers into single output map  
**--overwrite**  
&nbsp;&nbsp;&nbsp;&nbsp;Allow output files to overwrite existing files  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**first**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of first raster map for blending  
**second**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of second raster map for blending  
**output**=*basename* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Basename for red, green and blue output raster maps  
**percent**=*float*  
&nbsp;&nbsp;&nbsp;&nbsp;Percentage weight of first map for color blending  
&nbsp;&nbsp;&nbsp;&nbsp;Options: *0-100*  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *50*

## DESCRIPTION

*r.blend* blends color components of 2 raster maps by a specified
percentage of the first map.

## EXAMPLE

Blending the aspect map with the elevation map for a shaded map (North
Carolina sample dataset):

```sh
g.region raster=elevation
r.relief input=elevation output=relief zscale=10
r.blend -c first=elevation second=relief output=blend percent=75
```

![r.blend example](r_blend.png)  
*Figure: Elevation blended with shaded relief*

## SEE ALSO

*[d.shade](d.shade.md), [g.region](g.region.md), [r.shade](r.shade.md),
[r.colors](r.colors.md), [r.his](r.his.md), [r.mapcalc](r.mapcalc.md),
[r.rgb](r.rgb.md), [r.support](r.support.md)*

## AUTHORS

Unknown: probably CERL  
Updated to GRASS 5.7 by Michael Barton, Arizona State University

## SOURCE CODE

Available at: [r.blend source code](https://github.com/OSGeo/grass/tree/main/scripts/r.blend)
([history](https://github.com/OSGeo/grass/commits/main/scripts/r.blend))  
Latest change: Wednesday Feb 12 23:02:46 2025 in commit [9c11460](https://github.com/OSGeo/grass/commit/9c1146064f7c3c21fb0746063fa8bd2cdf4633cb)
