---
name: r.colors.stddev.py
description: Sets color rules based on stddev from a raster map's mean value.
keywords: [ raster, color table ]
---

# r.colors.stddev.py

## NAME

***r.colors.stddev.py*** - Sets color rules based on stddev from a raster map's mean value.

### 
### SYNOPSIS

**r.colors.stddev.py**  
**r.colors.stddev.py --help**  
**r.colors.stddev.py** [**-bz**]  **map**=*name*
 [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**-b**  
&nbsp;&nbsp;&nbsp;&nbsp;Color using standard deviation bands  
**-z**  
&nbsp;&nbsp;&nbsp;&nbsp;Force center at zero  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**map**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of raster map

## DESCRIPTION

*r.colors.stddev* set raster map color rules based on standard
deviations from a map's mean value, either as a continuous color
gradient or in color bands per standard deviation (S.D.) from the mean.

With the color band option values less that 1 S.D. from the mean are
colored green, within 1-2 S.D. are colored yellow, within 2-3 S.D. are
colored red, and beyond 3 S.D. are colored black.

For a differences map there is an option to lock the center of the color
table at zero. Values more than two S.D. below the mean will be colored
blue; values below the mean but less than 2 S.D. away will transition to
white, and above the mean the colors will simularly transition to full
red at +2 S.D.

## EXAMPLE

North Carolina sample dataset:

```sh
g.region raster=elevation -p
r.colors.stddev elevation
```

![r.colors.stddev example](r_colors_stddev.png)  
*Figure: Standard deviations from mean elevation*

## SEE ALSO

*[r.colors](r.colors.md), [r.univar](r.univar.md),
[v.colors](v.colors.md)*

## AUTHOR

Hamish Bowman, *Dunedin, New Zealand*

## SOURCE CODE

Available at: [r.colors.stddev source code](https://github.com/OSGeo/grass/tree/main/scripts/r.colors.stddev)
([history](https://github.com/OSGeo/grass/commits/main/scripts/r.colors.stddev))  
Latest change: Wednesday Feb 12 23:02:46 2025 in commit [9c11460](https://github.com/OSGeo/grass/commit/9c1146064f7c3c21fb0746063fa8bd2cdf4633cb)
