---
name: r.composite
description: Combines red, green and blue raster maps into a single composite raster map.
keywords: [ raster, composite, RGB ]
---

# r.composite

## NAME

***r.composite*** - Combines red, green and blue raster maps into a single composite raster map.

### 
### SYNOPSIS

**r.composite**  
**r.composite --help**  
**r.composite** [**-dc**]  **red**=*name*
 **green**=*name*
 **blue**=*name*
 [**levels**=*integer*]
 [**level_red**=*integer*]
 [**level_green**=*integer*]
 [**level_blue**=*integer*]
 **output**=*name*
 [**--overwrite**]  [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**-d**  
&nbsp;&nbsp;&nbsp;&nbsp;Dither  
**-c**  
&nbsp;&nbsp;&nbsp;&nbsp;Use closest color  
**--overwrite**  
&nbsp;&nbsp;&nbsp;&nbsp;Allow output files to overwrite existing files  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**red**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of raster map to be used for &lt;red&gt;  
**green**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of raster map to be used for &lt;green&gt;  
**blue**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of raster map to be used for &lt;blue&gt;  
**levels**=*integer*  
&nbsp;&nbsp;&nbsp;&nbsp;Number of levels to be used for each component  
&nbsp;&nbsp;&nbsp;&nbsp;Options: *1-256*  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *32*  
**level_red**=*integer*  
&nbsp;&nbsp;&nbsp;&nbsp;Number of levels to be used for &lt;red&gt;  
&nbsp;&nbsp;&nbsp;&nbsp;Options: *1-256*  
**level_green**=*integer*  
&nbsp;&nbsp;&nbsp;&nbsp;Number of levels to be used for &lt;green&gt;  
&nbsp;&nbsp;&nbsp;&nbsp;Options: *1-256*  
**level_blue**=*integer*  
&nbsp;&nbsp;&nbsp;&nbsp;Number of levels to be used for &lt;blue&gt;  
&nbsp;&nbsp;&nbsp;&nbsp;Options: *1-256*  
**output**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name for output raster map

## DESCRIPTION

This program combines three raster maps to form a composite RGB map. For
each input map layer, the corresponding component from the map's color
table is used (e.g. for the red map, the red component is used, and so
on). In general, the maps should use a grey-scale color table.

## NOTES

The default number of intensity levels for each component is 32,
resulting in a total of 32768 possible colors (equivalent to 15 bits per
pixel). If significantly more levels than this are used, not only will
*r.composite* take longer to run, but displaying the resulting layer
with *[d.rast](d.rast.md)* will also be significantly slower.

Floyd-Steinberg dithering is optionally used with the **-d** flag.

## EXAMPLES

### RGB composite of three satellite bands

Color composite of a LANDSAT scene (North Carolina sample dataset):

```sh
g.region raster=lsat7_2002_10
r.composite blue=lsat7_2002_10 green=lsat7_2002_20 red=lsat7_2002_30 \
            output=lsat7_2002_rgb
```

### RGB composite with dithering

Creating a composite RGB raster using 32 color levels per layer, with
dithering:

```sh
r.composite -d red=elevation.r green=elevation.g blue=elevation.b \
            output=elev.composite
```

## SEE ALSO

*[d.rast](d.rast.md), [d.rgb](d.rgb.md), [r.blend](r.blend.md),
[r.colors](r.colors.md), [r.rgb](r.rgb.md)*

*[Wikipedia Entry: Floyd-Steinberg
dithering](https://en.wikipedia.org/wiki/Floyd-Steinberg_dithering)*

## AUTHOR

Glynn Clements

## SOURCE CODE

Available at: [r.composite source code](https://github.com/OSGeo/grass/tree/main/raster/r.composite)
([history](https://github.com/OSGeo/grass/commits/main/raster/r.composite))  
Latest change: Friday Feb 07 19:16:09 2025 in commit [a82a39f](https://github.com/OSGeo/grass/commit/a82a39f673b97fafcfce1604dc3e6015cb96487a)
