---
name: r.distance
description: Locates the closest points between objects in two raster maps.
keywords: [ raster, distance ]
---

# r.distance

## NAME

***r.distance*** - Locates the closest points between objects in two raster maps.

### 
### SYNOPSIS

**r.distance**  
**r.distance --help**  
**r.distance** [**-lon**]  **map**=*name1,name2* [,*name1,name2*,...]
 [**separator**=*character*]
 [**sort**=*string*]
 [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**-l**  
&nbsp;&nbsp;&nbsp;&nbsp;Include category labels in the output  
**-o**  
&nbsp;&nbsp;&nbsp;&nbsp;Report zero distance if rasters are overlapping  
**-n**  
&nbsp;&nbsp;&nbsp;&nbsp;Report null objects as \*  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**map**=*name1,name2* [,*name1,name2*,...] **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of two input raster maps for computing inter-class distances  
**separator**=*character*  
&nbsp;&nbsp;&nbsp;&nbsp;Field separator  
&nbsp;&nbsp;&nbsp;&nbsp;Special characters: pipe, comma, space, tab, newline  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *:*  
**sort**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Sort output by distance  
&nbsp;&nbsp;&nbsp;&nbsp;Default: sorted by categories  
&nbsp;&nbsp;&nbsp;&nbsp;Options: *asc, desc*  
&nbsp;&nbsp;&nbsp;&nbsp;**asc**: Sort by distance in ascending order  
&nbsp;&nbsp;&nbsp;&nbsp;**desc**: Sort by distance in descending order

## DESCRIPTION

*r.distance* locates the closest points between "objects" in two raster
maps. An "object" is defined as all the grid cells that have the same
category number, and closest means having the shortest "straight-line"
distance. The cell centers are considered for the distance calculation
(two adjacent grid cells have the distance between their cell centers).

The output is an ascii list, one line per pair of objects, in the
following form:

```sh
cat1:cat2:distance:east1:north1:east2:north2
```

**cat1**  
Category number from map1

**cat2**  
Category number from map2

**distance**  
The distance in meters between "cat1" and "cat2"

**east1,north1**  
The coordinates of the grid cell "cat1" which is closest to "cat2"

**east2,north2**  
The coordinates of the grid cell "cat2" which is closest to "cat1"

### Flags

**-l** The -l flag outputs the category labels of the matched raster
objects at the beginning of the line, if they exist.

**-o** The -o flag reports zero distance if the input rasters are
overlapping.

## NOTES

The output format lends itself to filtering. For example, to "see" lines
connecting each of the category pairs in two maps, filter the output
using awk and then into *d.graph*:

```sh
r.distance map=map1,map2 | \
  awk -F: '{print "move",$4,$5,"\ndraw",$6,$7}' | d.graph -m
```

To create a vector map of all the "map1" coordinates, filter the output
into awk and then into *v.in.ascii*:

```sh
r.distance map=map1,map2 | \
  awk -F: '{print $4,$5}' | v.in.ascii format=point output=name separator=space
```

## SEE ALSO

*[r.buffer](r.buffer.md), [r.cost](r.cost.md), [r.drain](r.drain.md),
[r.grow](r.grow.md), [r.grow.distance](r.grow.distance.md),
[v.distance](v.distance.md)*

## AUTHOR

Michael Shapiro, U.S. Army Construction Engineering Research Laboratory

## SOURCE CODE

Available at: [r.distance source code](https://github.com/OSGeo/grass/tree/main/raster/r.distance)
([history](https://github.com/OSGeo/grass/commits/main/raster/r.distance))  
Latest change: Friday Feb 07 19:16:09 2025 in commit [a82a39f](https://github.com/OSGeo/grass/commit/a82a39f673b97fafcfce1604dc3e6015cb96487a)
