---
name: r.external
description: Links GDAL supported raster data as a pseudo GRASS raster map.
keywords: [ raster, import, external ]
---

# r.external

## NAME

***r.external*** - Links GDAL supported raster data as a pseudo GRASS raster map.

### 
### SYNOPSIS

**r.external**  
**r.external --help**  
**r.external** [**-fojeahvtmr**]  [**input**=*name*]
 [**source**=*name*]
 **output**=*name*
 [**band**=*integer*]
 [**title**=*phrase*]
 [**--overwrite**]  [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**-f**  
&nbsp;&nbsp;&nbsp;&nbsp;List supported formats and exit  
**-o**  
&nbsp;&nbsp;&nbsp;&nbsp;Override projection check (use current project's CRS)  
&nbsp;&nbsp;&nbsp;&nbsp;Assume that the dataset has the same coordinate reference system as the current project  
**-j**  
&nbsp;&nbsp;&nbsp;&nbsp;Perform projection check only and exit  
**-e**  
&nbsp;&nbsp;&nbsp;&nbsp;Extend region extents based on new dataset  
&nbsp;&nbsp;&nbsp;&nbsp;Also updates the default region if in the PERMANENT mapset  
**-a**  
&nbsp;&nbsp;&nbsp;&nbsp;Auto-adjustment for lat/lon  
&nbsp;&nbsp;&nbsp;&nbsp;Attempt to fix small precision errors in resolution and extents  
**-h**  
&nbsp;&nbsp;&nbsp;&nbsp;Flip horizontally  
**-v**  
&nbsp;&nbsp;&nbsp;&nbsp;Flip vertically  
**-t**  
&nbsp;&nbsp;&nbsp;&nbsp;List available bands including band type in dataset and exit  
&nbsp;&nbsp;&nbsp;&nbsp;Format: band number,type,projection check  
**-m**  
&nbsp;&nbsp;&nbsp;&nbsp;Read data range from metadata  
&nbsp;&nbsp;&nbsp;&nbsp;WARNING: metadata are sometimes approximations with wrong data range  
**-r**  
&nbsp;&nbsp;&nbsp;&nbsp;Create fast link without data range  
&nbsp;&nbsp;&nbsp;&nbsp;WARNING: some modules do not work correctly without known data range  
**--overwrite**  
&nbsp;&nbsp;&nbsp;&nbsp;Allow output files to overwrite existing files  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**input**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Name of raster file to be linked  
**source**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Name of non-file GDAL data source  
**output**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name for output raster map  
**band**=*integer*  
&nbsp;&nbsp;&nbsp;&nbsp;Band to select (default is all bands)  
**title**=*phrase*  
&nbsp;&nbsp;&nbsp;&nbsp;Title for resultant raster map

## DESCRIPTION

*r.external* allows a user to link a GDAL supported raster file to a
binary raster map layer, from any GDAL supported raster map format, with
an optional title. The file is not imported but just registered as GRASS
raster map.

## NOTES

In essence, *r.external* creates a read-only link to the original
dataset which is only valid if the original dataset remains at the
originally indicated directory and filename.

## NULL data handling

GDAL-linked (*r.external*) maps do not have or use a NULL bitmap, hence
*r.null* cannot manipulate them directly. Here NULL cells are those
whose value matches the value reported by the GDALGetRasterNoDataValue()
function.

To introduce additional NULL values to a computation based on a
GDAL-linked raster, the user needs to either create a mask with with
*r.mask* and then "apply" it using e.g. *r.resample* or *r.mapcalc*, or
use *r.mapcalc* to create a copy with the appropriate categories changed
to NULL (`if()` condition).

## EXAMPLES

### RGB Orthophoto from GeoTIFF

```sh
# import of all channels (each channel will become a GRASS raster map):
r.external input=/home/user/data/maps/059100.tif output=ortho
g.region raster=ortho.3 -p
d.rgb r=ortho.1 g=ortho.2 b=ortho.3
r.composite r=ortho.1 g=ortho.2 b=ortho.3 output=ortho.rgb
```

### Processing workflow without data import and export

External raster maps to be processed can be directly linked using
*r.external*; likewise, results can be written out to standard raster
formats with *r.external.out* (GDAL supported formats):

```sh
# register GeoTIFF file to be used in current mapset:
r.external input=terra_lst1km20030314.LST_Day.tif output=modis_celsius

# define output directory for files resulting from GRASS calculation:
r.external.out directory=$HOME/gisoutput/ format="GTiff"

# perform GRASS calculation (here: extract pixels > 20 deg C)
# this stores the output map directly as GeoTIFF:
r.mapcalc "warm.tif = if(modis_celsius > 20.0, modis_celsius, null() )"

# cease GDAL output connection and turn back to write GRASS raster files:
r.external.out -r

# now use the resulting file elsewhere
gdalinfo $HOME/gisoutput/warm.tif
```

## REFERENCES

GDAL Pages: [https://gdal.org/](https://gdal.org)  

## SEE ALSO

*[r.import](r.import.md), [r.in.gdal](r.in.gdal.md),
[r.external.out](r.external.out.md)*

*[v.import](v.import.md), [v.in.ogr](v.in.ogr.md),
[v.external](v.external.md), [v.external.out](v.external.out.md)*

## AUTHOR

Glynn Clements

## SOURCE CODE

Available at: [r.external source code](https://github.com/OSGeo/grass/tree/main/raster/r.external)
([history](https://github.com/OSGeo/grass/commits/main/raster/r.external))  
Latest change: Tuesday Apr 01 04:59:21 2025 in commit [8bb8306](https://github.com/OSGeo/grass/commit/8bb83062f08ea003d27c7d2f70e7a25f86a8a026)
