---
name: r.in.aster.py
description: Georeference, rectify, and import Terra-ASTER imagery and relative DEMs using gdalwarp.
keywords: [ raster, import, imagery, ASTER, elevation ]
---

# r.in.aster.py

## NAME

***r.in.aster.py*** - Georeference, rectify, and import Terra-ASTER imagery and relative DEMs using gdalwarp.

### 
### SYNOPSIS

**r.in.aster.py**  
**r.in.aster.py --help**  
**r.in.aster.py**  **input**=*name*
 **proctype**=*string*
 **band**=*string*
 **output**=*name*
 [**--overwrite**]  [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**--overwrite**  
&nbsp;&nbsp;&nbsp;&nbsp;Allow output files to overwrite existing files  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**input**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of input ASTER image  
**proctype**=*string* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;ASTER imagery processing type (Level 1A, Level 1B, or relative DEM)  
&nbsp;&nbsp;&nbsp;&nbsp;Options: *L1A, L1B, L1T, DEM*  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *L1B*  
**band**=*string* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;List L1A L1B or L1T band to translate (1,2,3n,...), or enter 'all' to translate all bands  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *all*  
**output**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Base name for output raster map (band number will be appended to base name)

## DESCRIPTION

*r.in.aster* rectifies, georeferences, and imports Terra-ASTER imagery
to current project using gdalwarp, hdf 4, and r.in.gdal, using
projection parameters from g.proj. It can import Level 1A, Level 1B,
their relative DEM products, and Level 1T.

The program may be run interactively or non-interactively from the
command line. In either case, the user must specify an **input** \*.hdf
file name, the **type** of processing used, the image **band** to
import, and an **output** GRASS raster map name.

The **type** parameter can take values of L1A, L1B, L1T or DEM.

The **band** parameter can take values of 1, 2, 3n, 3b, 4-14

## NOTES

*r.in.aster* requires GDAL library to be in the user's path and the hdf
4 driver to be installed. The GDAL library must be compiled with hdf
support.

## AUTHORS

Michael Barton, Arizona State University and Paul Kelly

## SOURCE CODE

Available at: [r.in.aster source code](https://github.com/OSGeo/grass/tree/main/scripts/r.in.aster)
([history](https://github.com/OSGeo/grass/commits/main/scripts/r.in.aster))  
Latest change: Friday Feb 07 19:16:09 2025 in commit [a82a39f](https://github.com/OSGeo/grass/commit/a82a39f673b97fafcfce1604dc3e6015cb96487a)
