---
name: r.out.bin
description: Exports a GRASS raster to a binary array.
keywords: [ raster, export, output ]
---

# r.out.bin

## NAME

***r.out.bin*** - Exports a GRASS raster to a binary array.

### 
### SYNOPSIS

**r.out.bin**  
**r.out.bin --help**  
**r.out.bin** [**-ifhbs**]  **input**=*string*
 [**output**=*string*]
 [**null**=*float*]
 [**bytes**=*integer*]
 [**order**=*string*]
 [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**-i**  
&nbsp;&nbsp;&nbsp;&nbsp;Generate integer output  
**-f**  
&nbsp;&nbsp;&nbsp;&nbsp;Generate floating-point output  
**-h**  
&nbsp;&nbsp;&nbsp;&nbsp;Export array with GMT compatible header  
**-b**  
&nbsp;&nbsp;&nbsp;&nbsp;Generate BIL world and header files  
**-s**  
&nbsp;&nbsp;&nbsp;&nbsp;Byte swap output  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**input**=*string* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of input raster map  
**output**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Name for output binary map (use output=- for stdout)  
**null**=*float*  
&nbsp;&nbsp;&nbsp;&nbsp;Value to write out for null  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *0*  
**bytes**=*integer*  
&nbsp;&nbsp;&nbsp;&nbsp;Number of bytes per cell  
&nbsp;&nbsp;&nbsp;&nbsp;Options: *1, 2, 4, 8*  
**order**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Output byte order  
&nbsp;&nbsp;&nbsp;&nbsp;Options: *big, little, native, swap*  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *native*

## DESCRIPTION

The *r.out.bin* program exports a GRASS raster map to a binary array
file. Optionally, output can be sent to standard output (stdout) for
direct input (pipe) into other applications. Data is exported according
to the original GRASS raster type (e.g. float). If the "-i" flag is
specified, an integer array is output. The region parameters are printed
to stderr.

## NOTES

With the -h flag, data can be directly used by
[GMT](https://www.generic-mapping-tools.org/) as Grid Format 1 (float)
or 2 (short). For example:

```sh
r.out.bin -h input=grass.raster output=new.grd
grdinfo new.grd=1 (if float)
```

Exported data can be piped directly into the GMT program xyz2grd.

```sh
r.out.bin input=grass.raster output=- | xyz2grd -R....  -ZTLf -
```

The example uses the GMT program xyz2grd with the -ZTLf flag indicating
that a float array was output.

## SEE ALSO

*[r.in.bin](r.in.bin.md), [r.in.ascii](r.in.ascii.md),
[r.in.gdal](r.in.gdal.md), [r.out.ascii](r.out.ascii.md)*

## AUTHOR

This program is derived from *[r.out.ascii](r.out.ascii.md)* with a few
modifications.  
Author: [Bob Covill](mailto:bcovill@tekmap.ns.ca)

## SOURCE CODE

Available at: [r.out.bin source code](https://github.com/OSGeo/grass/tree/main/raster/r.out.bin)
([history](https://github.com/OSGeo/grass/commits/main/raster/r.out.bin))  
Latest change: Friday Feb 07 19:16:09 2025 in commit [a82a39f](https://github.com/OSGeo/grass/commit/a82a39f673b97fafcfce1604dc3e6015cb96487a)
