---
name: r.out.png
description: Export a GRASS raster map as a non-georeferenced PNG image.
keywords: [ raster, export, output, PNG ]
---

# r.out.png

## NAME

***r.out.png*** - Export a GRASS raster map as a non-georeferenced PNG image.

### 
### SYNOPSIS

**r.out.png**  
**r.out.png --help**  
**r.out.png** [**-tw**]  **input**=*name*
 **output**=*name*
 [**compression**=*integer*]
 [**--overwrite**]  [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**-t**  
&nbsp;&nbsp;&nbsp;&nbsp;Make NULL cells transparent  
**-w**  
&nbsp;&nbsp;&nbsp;&nbsp;Output world file  
**--overwrite**  
&nbsp;&nbsp;&nbsp;&nbsp;Allow output files to overwrite existing files  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**input**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of input raster map  
**output**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name for new PNG file (use '-' for stdout)  
**compression**=*integer*  
&nbsp;&nbsp;&nbsp;&nbsp;Compression level of PNG file  
&nbsp;&nbsp;&nbsp;&nbsp;(0 = none, 1 = fastest, 9 = best)  
&nbsp;&nbsp;&nbsp;&nbsp;Options: *0-9*  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *6*

## DESCRIPTION

*r.out.png* exports a GRASS GIS raster map in non-georeferenced Portable
Network Graphics (PNG) image format, respecting the current region
resolution and bounds.

Optionally the user can choose to export a World File (.wld) to provide
basic georeferencing support. When used with the transparency flag this
can create images useful for KML, TMS, or WMS overlays. (e.g. for use in
Google Earth or as OpenLayers tiles) If output is redirected to stdout,
the world file will be called `png_map.wld`.

## EXAMPLE

The example is based on the North Carolina sample data.

Export of the soil map to PNG format with world file:

```sh
g.region raster=soils_Kfactor -p
# export PNG file with additional world file
r.out.png input=soils_Kfactor output=soils_Kfactor -w
# verify
gdalinfo soils_Kfactor.png
```

## SEE ALSO

*[r.out.gdal](r.out.gdal.md), [r.out.ppm](r.out.ppm.md),
[r.out.ascii](r.out.ascii.md), [r.import](r.import.md)*

## AUTHORS

Alex Shevlakov  
Hamish Bowman

## SOURCE CODE

Available at: [r.out.png source code](https://github.com/OSGeo/grass/tree/main/raster/r.out.png)
([history](https://github.com/OSGeo/grass/commits/main/raster/r.out.png))  
Latest change: Friday Feb 07 19:16:09 2025 in commit [a82a39f](https://github.com/OSGeo/grass/commit/a82a39f673b97fafcfce1604dc3e6015cb96487a)
