---
name: r.quant
description: Produces the quantization file for a floating-point map.
keywords: [ raster, statistics, quantization ]
---

# r.quant

## NAME

***r.quant*** - Produces the quantization file for a floating-point map.

### 
### SYNOPSIS

**r.quant**  
**r.quant --help**  
**r.quant** [**-tr**]  **input**=*string* [,*string*,...]
 [**rules**=*name*]
 [**basemap**=*string*]
 [**fprange**=*dmin,dmax*]
 [**range**=*min,max*]
 [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**-t**  
&nbsp;&nbsp;&nbsp;&nbsp;Truncate floating point data  
**-r**  
&nbsp;&nbsp;&nbsp;&nbsp;Round floating point data  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**input**=*string* [,*string*,...] **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Raster map(s) to be quantized  
**rules**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Path to rules file ("-" to read from stdin)  
**basemap**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Base map to take quant rules from  
**fprange**=*dmin,dmax*  
&nbsp;&nbsp;&nbsp;&nbsp;Floating point range: dmin,dmax  
**range**=*min,max*  
&nbsp;&nbsp;&nbsp;&nbsp;Integer range: min,max

## DESCRIPTION

*r.quant* produces the quantization file for a floating-point map.

The *map* parameter defines the map for which the rules are to be
created. If more than one map is specified, then this implies that the
floating-point range is the minimum and maximum of all the maps
together, unless either *basemap=map* or *fprange=min,max* is specified.

### Quant rules

The quant rules have to be entered interactively.

If rules is specified, the input has the form:

```sh
value1:value2:cat1:[cat2]
```

where *value1* and *value2* are floating point values and *cat1* and
*cat2* are integers. If *cat2* is missing, it is taken to be equal to
*cat1*. All values can be *"\*"* which means infinity.

## NOTE

It is an error to specify both *basemap* and *fprange*.

## SEE ALSO

*[r.support](r.support.md), [r.null](r.null.md)*

## AUTHORS

Michael Shapiro, Olga Waupotitsch, U.S.Army Construction Engineering
Research Laboratory

## SOURCE CODE

Available at: [r.quant source code](https://github.com/OSGeo/grass/tree/main/raster/r.quant)
([history](https://github.com/OSGeo/grass/commits/main/raster/r.quant))  
Latest change: Friday Feb 07 19:16:09 2025 in commit [a82a39f](https://github.com/OSGeo/grass/commit/a82a39f673b97fafcfce1604dc3e6015cb96487a)
