---
name: r.reclass.area.py
description: Reclasses a raster map greater or less than user specified area size (in hectares).
keywords: [ raster, statistics, aggregation ]
---

# r.reclass.area.py

## NAME

***r.reclass.area.py*** - Reclasses a raster map greater or less than user specified area size (in hectares).

### 
### SYNOPSIS

**r.reclass.area.py**  
**r.reclass.area.py --help**  
**r.reclass.area.py** [**-cd**]  **input**=*name*
 **output**=*name*
 **value**=*float*
 **mode**=*string*
 [**method**=*string*]
 [**--overwrite**]  [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**-c**  
&nbsp;&nbsp;&nbsp;&nbsp;Input map is clumped  
**-d**  
&nbsp;&nbsp;&nbsp;&nbsp;Clumps including diagonal neighbors  
**--overwrite**  
&nbsp;&nbsp;&nbsp;&nbsp;Allow output files to overwrite existing files  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**input**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of input raster map  
**output**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name for output raster map  
**value**=*float* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Value option that sets the area size limit (in hectares)  
**mode**=*string* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Lesser or greater than specified value  
&nbsp;&nbsp;&nbsp;&nbsp;Options: *lesser, greater*  
**method**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Method used for reclassification  
&nbsp;&nbsp;&nbsp;&nbsp;Options: *reclass, rmarea*  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *reclass*

## DESCRIPTION

*r.reclass.area* reclasses a raster map greater or less than a user
specified area size (in hectares).

If the **-c** flag is used, *r.reclass.area* will skip the creation of a
clumped raster and assume that the input raster is already clumped.

## EXAMPLES

In this example, the ZIP code map in the North Carolina sample dataset
is filtered for large areas (removing smaller areas from the map).

```sh
g.region raster=zipcodes -p
r.report zipcodes unit=h
```

Extract only areas greater than 2000 ha, NULL otherwise:

```sh
r.reclass.area input=zipcodes output=zipcodes_larger2000ha mode=greater value=2000

r.report zipcodes_larger2000ha unit=h
```

![Figure: r.reclass.area method=reclass](zipcodes_larger2000ha.png)  
*Figure: r.reclass.area method=reclass*

In this example, the ZIP code map in the North Carolina sample dataset
is filtered for smaller areas which are substituted with the value of
the respective adjacent area with largest shared boundary. Reclass by
substitutional removing of areas minor of 1000 ha:

```sh
r.reclass.area input=zipcodes output=zipcodes_minor1000ha mode=lesser value=1000 method=rmarea
```

![Figure: r.reclass.area method=rmarea](zipcodes_minor1000ha.png)  
*Figure: r.reclass.area method=rmarea*

## SEE ALSO

*[r.reclass](r.reclass.md), [r.clump](r.clump.md),
[r.stats](r.stats.md)*

## AUTHORS

NRCS,  
Markus Neteler

## SOURCE CODE

Available at: [r.reclass.area source code](https://github.com/OSGeo/grass/tree/main/scripts/r.reclass.area)
([history](https://github.com/OSGeo/grass/commits/main/scripts/r.reclass.area))  
Latest change: Tuesday Feb 18 17:20:26 2025 in commit [688e625](https://github.com/OSGeo/grass/commit/688e625e7db3be9a465ce99ba25f36d2ebdd5aeb)
