---
name: r.region
description: Sets the boundary definitions for a raster map.
keywords: [ raster, metadata, geometry ]
---

# r.region

## NAME

***r.region*** - Sets the boundary definitions for a raster map.

### 
### SYNOPSIS

**r.region**  
**r.region --help**  
**r.region** [**-cda**]  **map**=*name*
 [**region**=*name*]
 [**raster**=*name*]
 [**vector**=*name*]
 [**n**=*value*]
 [**s**=*value*]
 [**e**=*value*]
 [**w**=*value*]
 [**align**=*name*]
 [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**-c**  
&nbsp;&nbsp;&nbsp;&nbsp;Set from current region  
**-d**  
&nbsp;&nbsp;&nbsp;&nbsp;Set from default region  
**-a**  
&nbsp;&nbsp;&nbsp;&nbsp;Auto-adjustment for lat/lon  
&nbsp;&nbsp;&nbsp;&nbsp;Attempt to fix small precision errors in resolution and extents  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**map**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of raster map to change  
**region**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Set region from named region  
**raster**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Set region to match this raster map  
**vector**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Name of vector map  
&nbsp;&nbsp;&nbsp;&nbsp;Set region to match this vector map  
**n**=*value*  
&nbsp;&nbsp;&nbsp;&nbsp;Value for the northern edge  
**s**=*value*  
&nbsp;&nbsp;&nbsp;&nbsp;Value for the southern edge  
**e**=*value*  
&nbsp;&nbsp;&nbsp;&nbsp;Value for the eastern edge  
**w**=*value*  
&nbsp;&nbsp;&nbsp;&nbsp;Value for the western edge  
**align**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Raster map to align to

## DESCRIPTION

The *r.region* program allows the user to manage the boundaries of a
raster map. These boundaries can be set by the user directly and/or set
from a region definition file (stored under the `windows` directory in
the user's current mapset), a raster or vector map, or a 3dview file.

The **align** parameter sets the current resolution equal to that of the
named raster map, and align the boundaries to a row and column edge in
the named map. Alignment only moves the existing boundaries outward to
the edges of the next nearest cell in the named raster map -- not to the
named map's edges. To perform the latter function, use the
**raster**=*name* option.

## NOTES

After all updates have been applied, the raster map's resolution
settings are recomputed from the boundaries and the number of rows and
columns in the raster map.

The n=*value* may also be specified as a function of its current value:
n=n+*value* increases the current northing, while n=n-*value* decreases
it. This is also true for s=*value*, e=*value*, and w=*value*.

## EXAMPLES

Assign absolute coordinates to map:

```sh
r.region map=mymap n=220750 s=220000 w=638300 e=639000
```

Shift map (using offset, here by +100 map units in the NS direction, -50
in the EW direction):

```sh
r.region map=mymap n=n+100 e=e-50 w=w-50 s=s+100
```

## SEE ALSO

*[r.support](r.support.md), [g.region](g.region.md),
[v.transform](v.transform.md)*

## AUTHOR

Glynn Clements  
Based upon *g.region*

## SOURCE CODE

Available at: [r.region source code](https://github.com/OSGeo/grass/tree/main/raster/r.region)
([history](https://github.com/OSGeo/grass/commits/main/raster/r.region))  
Latest change: Monday Feb 24 16:07:55 2025 in commit [4ab71fd](https://github.com/OSGeo/grass/commit/4ab71fd34113b347c3c86c736cd82ca0f6be1d4b)
