---
name: r.statistics
description: Calculates category or object oriented statistics.
keywords: [ raster, statistics, zonal statistics ]
---

# r.statistics

## NAME

***r.statistics*** - Calculates category or object oriented statistics.

### 
### SYNOPSIS

**r.statistics**  
**r.statistics --help**  
**r.statistics** [**-c**]  **base**=*name*
 **cover**=*name*
 **method**=*string*
 **output**=*name*
 [**--overwrite**]  [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**-c**  
&nbsp;&nbsp;&nbsp;&nbsp;Cover values extracted from the category labels of the cover map  
**--overwrite**  
&nbsp;&nbsp;&nbsp;&nbsp;Allow output files to overwrite existing files  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**base**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of base raster map  
**cover**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of cover raster map  
**method**=*string* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Method of object-based statistic  
&nbsp;&nbsp;&nbsp;&nbsp;Options: *diversity, average, mode, median, avedev, stddev, variance, skewness, kurtosis, min, max, sum*  
&nbsp;&nbsp;&nbsp;&nbsp;**diversity**: Diversity of values in specified objects in %%  
&nbsp;&nbsp;&nbsp;&nbsp;**average**: Average of values in specified objects  
&nbsp;&nbsp;&nbsp;&nbsp;**mode**: Mode of values in specified objects  
&nbsp;&nbsp;&nbsp;&nbsp;**median**: Median of values in specified objects  
&nbsp;&nbsp;&nbsp;&nbsp;**avedev**: Average deviation of values in specified objects  
&nbsp;&nbsp;&nbsp;&nbsp;**stddev**: Standard deviation of values in specified objects  
&nbsp;&nbsp;&nbsp;&nbsp;**variance**: Variance of values in specified objects  
&nbsp;&nbsp;&nbsp;&nbsp;**skewness**: Skewnes of values in specified objects  
&nbsp;&nbsp;&nbsp;&nbsp;**kurtosis**: Kurtosis of values in specified objects  
&nbsp;&nbsp;&nbsp;&nbsp;**min**: Minimum of values in specified objects  
&nbsp;&nbsp;&nbsp;&nbsp;**max**: Maximum of values in specified objects  
&nbsp;&nbsp;&nbsp;&nbsp;**sum**: Sum of values in specified objects  
**output**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Resultant raster map

## DESCRIPTION

*r.statistics* is a tool to analyse exploratory statistics of a
categorical "cover layer" according to how it intersects with objects in
a "base layer". A variety of standard statistical measures are possible
(called "zonal statistics" in some GIS). All cells in the base layer are
considered one object for the analysis. For some applications, one will
first want to prepare the input data so that all areas of contiguous
cell category values in the base layer are uniquely identified, which
can be done with *r.clump*.  
The available methods are the following:

- average deviation
- average
- diversity
- kurtosis
- maximum
- median
- minimum
- mode
- skewness
- standard deviation
- sum
- variance

The calculations will be performed on each area of data of the cover
layers which fall within each unique value, or category, of the base
layer.

Setting the *-c* flag the category labels of the covering raster layer
will be used. This is nice to avoid the GRASS limitation to integer in
raster maps because using category values floating point numbers can be
stored.

All calculations create an output layer. The output layer is a
reclassified version of the base layer with identical category values,
but modified category labels - the results of the calculations are
stored in the category labels of the output layer.

## NOTES

For floating-point cover map support, see the alternative
*[r.stats.zonal](r.stats.zonal.md)*. For quantile calculations with
support for floating-point cover maps, see the alternative
*[r.stats.quantile](r.stats.quantile.md)*.

## EXAMPLES

Calculation of average elevation of each field in the Spearfish region:

```sh
r.statistics base=fields cover=elevation.dem out=elevstats method=average
r.category elevstats
r.mapcalc "fieldelev = @elevstats"
r.univar fieldelev
```

## SEE ALSO

*[r.category](r.category.md), [r.clump](r.clump.md),
[r.mode](r.mode.md), [r.mapcalc](r.mapcalc.md),
[r.neighbors](r.neighbors.md), [r.stats.quantile](r.stats.quantile.md),
[r.stats.zonal](r.stats.zonal.md), [r.univar](r.univar.md)*

## AUTHOR

Martin Schroeder, Geographisches Institut Heidelberg, Germany

## SOURCE CODE

Available at: [r.statistics source code](https://github.com/OSGeo/grass/tree/main/raster/r.statistics)
([history](https://github.com/OSGeo/grass/commits/main/raster/r.statistics))  
Latest change: Monday Feb 10 17:53:49 2025 in commit [be43b74](https://github.com/OSGeo/grass/commit/be43b744ebf6b35b685f771b0f2911d18b658b5d)
