---
name: r.surf.gauss
description: Mean and standard deviation of gaussian deviates can be expressed by the user.
keywords: [ raster, surface, random ]
---

# r.surf.gauss

## NAME

***r.surf.gauss*** - Generates a raster map using gaussian random number generator.

Mean and standard deviation of gaussian deviates can be expressed by the user.

### 
### SYNOPSIS

**r.surf.gauss**  
**r.surf.gauss --help**  
**r.surf.gauss**  **output**=*name*
 [**mean**=*float*]
 [**sigma**=*float*]
 [**seed**=*integer*]
 [**--overwrite**]  [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**--overwrite**  
&nbsp;&nbsp;&nbsp;&nbsp;Allow output files to overwrite existing files  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**output**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name for output raster map  
**mean**=*float*  
&nbsp;&nbsp;&nbsp;&nbsp;Distribution mean  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *0.0*  
**sigma**=*float*  
&nbsp;&nbsp;&nbsp;&nbsp;Standard deviation  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *1.0*  
**seed**=*integer*  
&nbsp;&nbsp;&nbsp;&nbsp;Seed value for the random number generator  
&nbsp;&nbsp;&nbsp;&nbsp;Using the same seed ensures identical results, while a randomly generated seed produces different outcomes in each run.

## DESCRIPTION

*r.surf.gauss* produces a raster map of Gaussian deviates whose mean and
standard deviation can be expressed by the user. It uses a Gaussian
random number generator. It is essentially the same as
*[r.surf.random](r.surf.random.md)*, but uses a Gaussian random number
generator instead.

## EXAMPLE

```sh
g.region -p n=228500 s=215000 w=630000 e=645000 res=10
r.surf.gauss out=gauss mean=0 sigma=10

# check result
r.univar gauss
```

![r.surf.gauss example (mean: 0; sigma: 10)](r_surf_gauss.jpg)  
*Figure: Random Gaussian surface example (mean: 0; sigma: 10)*

With the histogram tool the cell values versus count can be shown.

![r.surf.gauss example histogram (mean: 0; sigma: 10)](r_surf_gauss_hist.png)  
*Figure: Histogram of random Gaussian surface example (mean: 0; sigma:
10)*

## SEE ALSO

*[r.surf.contour](r.surf.contour.md),
[r.surf.fractal](r.surf.fractal.md), [r.surf.idw](r.surf.idw.md),
[r.surf.random](r.surf.random.md), [v.surf.rst](v.surf.rst.md)*

## AUTHOR

Jo Wood, [ASSIST's
home](https://web.archive.org/web/20070707015520/http://www.le.ac.uk/assist/index.html)

## SOURCE CODE

Available at: [r.surf.gauss source code](https://github.com/OSGeo/grass/tree/main/raster/r.surf.gauss)
([history](https://github.com/OSGeo/grass/commits/main/raster/r.surf.gauss))  
Latest change: Thursday Mar 06 19:23:31 2025 in commit [5fd4234](https://github.com/OSGeo/grass/commit/5fd4234a4f6ab09eb244c67111a1db2d84b6d0fe)
