---
name: r.surf.random
description: Produces a raster surface map of uniform random deviates with defined range.
keywords: [ raster, surface, random ]
---

# r.surf.random

## NAME

***r.surf.random*** - Produces a raster surface map of uniform random deviates with defined range.

### 
### SYNOPSIS

**r.surf.random**  
**r.surf.random --help**  
**r.surf.random** [**-i**]  **output**=*name*
 [**min**=*float*]
 [**max**=*float*]
 [**seed**=*integer*]
 [**--overwrite**]  [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**-i**  
&nbsp;&nbsp;&nbsp;&nbsp;Create an integer raster map  
**--overwrite**  
&nbsp;&nbsp;&nbsp;&nbsp;Allow output files to overwrite existing files  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**output**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name for output raster map  
**min**=*float*  
&nbsp;&nbsp;&nbsp;&nbsp;Minimum random value  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *0*  
**max**=*float*  
&nbsp;&nbsp;&nbsp;&nbsp;Maximum random value  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *100*  
**seed**=*integer*  
&nbsp;&nbsp;&nbsp;&nbsp;Seed value for the random number generator  
&nbsp;&nbsp;&nbsp;&nbsp;Using the same seed ensures identical results, while a randomly generated seed produces different outcomes in each run.

## DESCRIPTION

**r.surf.random** produces a raster map layer of uniform random deviates
whose range can be expressed by the user. It is essentially the same as
*r.surf.gauss*, but uses a linear random number generator instead. It
uses the random number generator drand48() or rand(), depending on the
user's platform.

## EXAMPLE

```sh
g.region -p n=228500 s=215000 w=630000 e=645000 res=10
r.surf.random out=random min=0 max=100

# check result
r.univar random
```

![r.random.surface example (min: 10; max: 100)](r_surf_random.jpg)  
*Figure: Random surface example (min: 10; max: 100)*

With the histogram tool the cell values versus count can be shown.

![r.random.surface example histogram (min: 10; max: 100)](r_surf_random_hist.png)  
*Figure: Histogram of random surface example (min: 10; max: 100)*

## SEE ALSO

*[r.random.surface](r.random.surface.md),
[r.surf.contour](r.surf.contour.md),
[r.surf.fractal](r.surf.fractal.md), [r.surf.gauss](r.surf.gauss.md),
[r.surf.idw](r.surf.idw.md), [v.surf.rst](v.surf.rst.md)*

## AUTHOR

Jo Wood  
Midlands Regional Research Laboratory (ASSIST)  
University of Leicester  
*October 1991*

## SOURCE CODE

Available at: [r.surf.random source code](https://github.com/OSGeo/grass/tree/main/raster/r.surf.random)
([history](https://github.com/OSGeo/grass/commits/main/raster/r.surf.random))  
Latest change: Thursday Mar 06 19:23:31 2025 in commit [5fd4234](https://github.com/OSGeo/grass/commit/5fd4234a4f6ab09eb244c67111a1db2d84b6d0fe)
