---
name: r.tile
description: Splits a raster map into tiles.
keywords: [ raster, tiling ]
---

# r.tile

## NAME

***r.tile*** - Splits a raster map into tiles.

### 
### SYNOPSIS

**r.tile**  
**r.tile --help**  
**r.tile**  **input**=*name*
 **output**=*string*
 **width**=*integer*
 **height**=*integer*
 [**overlap**=*integer*]
 [**--verbose**]  [**--quiet**]  [**--ui**]

**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**input**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of input raster map  
**output**=*string* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Output base name  
**width**=*integer* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Width of tiles (columns)  
**height**=*integer* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Height of tiles (rows)  
**overlap**=*integer*  
&nbsp;&nbsp;&nbsp;&nbsp;Overlap of tiles

## DESCRIPTION

*r.tile* retiles an existing raster map with user defined x and y tile
size.

## NOTES

*r.tile* generates a separate raster for each tile. This is equivalent
to running *g.region* along with *r.resample* in a double loop.

The module can be used to split a large raster map into smaller tiles,
e.g. for further parallelized analysis on a cluster computing system.

The overlap is defined in rows/columns.

## EXAMPLE

Retiling example for the North Carolina DEM:

```sh
g.region raster=elevation -p
# rows:       1350
# cols:       1500

# generating 2 x 2 = 4 tiles (width=1500/2, height=rows/2)
r.tile input=elevation output=elev_tile width=750 height=675
```

creates 4 tiles with the prefix *elev_tile* (named: elev_tile-000-000,
elev_tile-000-001, elev_tile-001-000, ...).

## SEE ALSO

*[g.region](g.region.md), [r3.retile](r3.retile.md)*

## AUTHOR

Glynn Clements

## SOURCE CODE

Available at: [r.tile source code](https://github.com/OSGeo/grass/tree/main/raster/r.tile)
([history](https://github.com/OSGeo/grass/commits/main/raster/r.tile))  
Latest change: Friday Feb 07 19:16:09 2025 in commit [a82a39f](https://github.com/OSGeo/grass/commit/a82a39f673b97fafcfce1604dc3e6015cb96487a)
