---
name: r.transect
description: Outputs raster map layer values lying along user defined transect line(s).
keywords: [ raster, profile, transect ]
---

# r.transect

## NAME

***r.transect*** - Outputs raster map layer values lying along user defined transect line(s).

### 
### SYNOPSIS

**r.transect**  
**r.transect --help**  
**r.transect** [**-g**]  **map**=*name*
 **line**=*east,north,azimuth,distance* [,*east,north,azimuth,distance*,...]
 [**null_value**=*string*]
 [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**-g**  
&nbsp;&nbsp;&nbsp;&nbsp;Output easting and northing in first two columns of four column output  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**map**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Raster map to be queried  
**line**=*east,north,azimuth,distance* [,*east,north,azimuth,distance*,...] **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Transect definition  
**null_value**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;String representing NULL value  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *\**

## DESCRIPTION

*r.transect* outputs, in ASCII, the values in a raster map which lie
along one or more user-defined transect lines. The transects are
described by their starting coordinates, azimuth, and distance.

The **line** parameter is a definition of (each) transect line,
specified by the geographic coordinates of its starting point (*easting,
northing*), the angle and direction of its travel (*azimuth*), and its
distance (*distance*).

The *azimuth* is an angle, in degrees, measured to the east of north.
The *distance* is in map units (meters for a metered database, like
UTM).

The **null** parameter can optionally be set to change the character
string representing null values.

## NOTES

This program is a front-end to the *[r.profile](r.profile.md)* program.
It simply converts the azimuth and distance to an ending coordinate and
then runs *[r.profile](r.profile.md)*. There once were **width=** and
**result**=*raw\|median\|average* options which are not currently
implemented.

## SEE ALSO

*[r.profile](r.profile.md), [wxGUI profile tool](wxGUI.md)*

## AUTHOR

Michael Shapiro, U.S. Army Construction Engineering Research Laboratory

## SOURCE CODE

Available at: [r.transect source code](https://github.com/OSGeo/grass/tree/main/raster/r.transect)
([history](https://github.com/OSGeo/grass/commits/main/raster/r.transect))  
Latest change: Monday Feb 24 16:07:55 2025 in commit [4ab71fd](https://github.com/OSGeo/grass/commit/4ab71fd34113b347c3c86c736cd82ca0f6be1d4b)
