---
name: r.unpack.py
description: Imports a GRASS GIS specific raster archive file (packed with r.pack) as a raster map
keywords: [ raster, import, copying ]
---

# r.unpack.py

## NAME

***r.unpack.py*** - Imports a GRASS GIS specific raster archive file (packed with r.pack) as a raster map

### 
### SYNOPSIS

**r.unpack.py**  
**r.unpack.py --help**  
**r.unpack.py** [**-op**]  **input**=*name.pack*
 [**output**=*name*]
 [**--overwrite**]  [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**-o**  
&nbsp;&nbsp;&nbsp;&nbsp;Override projection check (use current projects's CRS)  
&nbsp;&nbsp;&nbsp;&nbsp;Assume that the dataset has same coordinate reference system as the current project  
**-p**  
&nbsp;&nbsp;&nbsp;&nbsp;Print projection information of input pack file and exit  
  
**--overwrite**  
&nbsp;&nbsp;&nbsp;&nbsp;Allow output files to overwrite existing files  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**input**=*name.pack* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of input pack file  
**output**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Name for output raster map (default: taken from input file internals)

## DESCRIPTION

*r.unpack* allows unpacking raster maps packed by *[r.pack](r.pack.md)*.

## NOTES

Name of the raster map is determined by default from pack file
internals. Optionally the name can be given by **output** parameter.
Currently only 2D raster maps are supported.

## EXAMPLE

Pack up raster map *aspect* into *aspect.pack* file.

```sh
r.pack input=aspect
```

the raster map can be afterwards unpacked by

```sh
r.unpack input=aspect.pack
```

## SEE ALSO

*[r.pack](r.pack.md), [r.in.gdal](r.in.gdal.md), [v.pack](v.pack.md)*

## AUTHORS

Original Bash script written by Hamish Bowman, Otago University, New
Zealand as GRASS AddOns  
Converted to Python and updated for GRASS 7 by Martin Landa, CTU in
Prague, Czech Republic

## SOURCE CODE

Available at: [r.unpack source code](https://github.com/OSGeo/grass/tree/main/scripts/r.unpack)
([history](https://github.com/OSGeo/grass/commits/main/scripts/r.unpack))  
Latest change: Friday Feb 07 19:16:09 2025 in commit [a82a39f](https://github.com/OSGeo/grass/commit/a82a39f673b97fafcfce1604dc3e6015cb96487a)
