---
name: r3.gradient
description: Computes gradient of a 3D raster map and outputs gradient components as three 3D raster maps.
keywords: [ raster3d, gradient, voxel ]
---

# r3.gradient

## NAME

***r3.gradient*** - Computes gradient of a 3D raster map and outputs gradient components as three 3D raster maps.

### 
### SYNOPSIS

**r3.gradient**  
**r3.gradient --help**  
**r3.gradient**  **input**=*name*
 **output**=*grad_x,grad_y,grad_z* [,*grad_x,grad_y,grad_z*,...]
 [**blocksize**=*size_x,size_y,size_z* [,*size_x,size_y,size_z*,...]]
 [**--overwrite**]  [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**--overwrite**  
&nbsp;&nbsp;&nbsp;&nbsp;Allow output files to overwrite existing files  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**input**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of input 3D raster map  
**output**=*grad_x,grad_y,grad_z* [,*grad_x,grad_y,grad_z*,...] **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name for output 3D raster map(s)  
**blocksize**=*size_x,size_y,size_z* [,*size_x,size_y,size_z*,...]  
&nbsp;&nbsp;&nbsp;&nbsp;Size of blocks  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *30,30,20*

## DESCRIPTION

Module *r3.gradient* computes gradient from a 3D raster map. Results are
three 3D raster maps describing the x, y, z components of the computed
gradient field.

## EXAMPLES

```sh
# create a 3D raster
g.region s=0 n=100 w=0 e=100 b=0 t=100 -p
r3.mapcalc "test_gradient = sqrt(row()*row() +col()*col()+ depth()*depth())"

# compute gradient
r3.gradient input=test_gradient output=grad_x,grad_y,grad_z
```

## SEE ALSO

*[r3.flow](r3.flow.md), [r.flow](r.flow.md)*

## AUTHOR

Anna Petrasova, [NCSU GeoForAll
Lab](https://geospatial.ncsu.edu/geoforall/), developed during GSoC
2014.

## SOURCE CODE

Available at: [r3.gradient source code](https://github.com/OSGeo/grass/tree/main/raster3d/r3.gradient)
([history](https://github.com/OSGeo/grass/commits/main/raster3d/r3.gradient))  
Latest change: Thursday Feb 27 06:05:37 2025 in commit [49a2352](https://github.com/OSGeo/grass/commit/49a235285f31f0ba428cdce25ff32799e7193f55)
