---
name: r3.mkdspf
description: Creates a display file from an existing 3D raster map according to specified threshold levels.
keywords: [ raster3d, display, voxel ]
---

# r3.mkdspf

## NAME

***r3.mkdspf*** - Creates a display file from an existing 3D raster map according to specified threshold levels.

### 
### SYNOPSIS

**r3.mkdspf**  
**r3.mkdspf --help**  
**r3.mkdspf** [**-qf**]  **input**=*string*
 **dspf**=*name*
 [**levels**=*float* [,*float*,...]]
 [**min**=*float*]
 [**max**=*float*]
 [**step**=*float*]
 [**tnum**=*integer*]
 [**--overwrite**]  [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**-q**  
&nbsp;&nbsp;&nbsp;&nbsp;Suppress progress report & min/max information  
**-f**  
&nbsp;&nbsp;&nbsp;&nbsp;Use flat shading rather than gradient  
**--overwrite**  
&nbsp;&nbsp;&nbsp;&nbsp;Allow output files to overwrite existing files  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**input**=*string* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of an existing 3D raster map  
**dspf**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name for output display file  
**levels**=*float* [,*float*,...]  
&nbsp;&nbsp;&nbsp;&nbsp;List of thresholds for isosurfaces  
**min**=*float*  
&nbsp;&nbsp;&nbsp;&nbsp;Minimum isosurface level  
**max**=*float*  
&nbsp;&nbsp;&nbsp;&nbsp;Maximum isosurface level  
**step**=*float*  
&nbsp;&nbsp;&nbsp;&nbsp;Positive increment between isosurface levels  
**tnum**=*integer*  
&nbsp;&nbsp;&nbsp;&nbsp;Number of isosurface threshold levels  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *7*

## DESCRIPTION

Creates a display file from an existing grid3 file according to
specified threshold levels. The display file is a display list of
polygons that represent isosurfaces of the data volume. If specific
*levels* are given, additional optional parameters are ignored. *Min* or
*max* may be used alone or together to specify a sub-range of the data.
The *step* parameter is given precedence over *tnum*.

### Flags

**-q**  
Suppress progress report & min/max information

**-f**  
Use flat shading rather than gradient

### Parameters

**grid3**  
Name of an existing 3D raster map

**dspf**  
Name of output display file

**levels**  
List of thresholds for isosurfaces

**min**  
Minimum isosurface level

**max**  
Maximum isosurface level

**step**  
Positive increment between isosurface levels

**tnum**  
Number of isosurface threshold levels

Default: 7

## NOTES

Currently the grid3 file must be in the user's mapset since the display
files being created are specific to particular grid3 files and are
contained in directories under them. We should create a mechanism where
users may make display files from others' grid3 files without having to
copy them to their mapset.

## EXAMPLES

With grid3 data (*phdata*) in the range 3-7, we only want to see
isosurface values for the range 4-6. Any of these commands will produce
the same results:  

```sh
r3.mkdspf phdata dspf=iso min=4.0 max=6.0 tnum=5
r3.mkdspf phdata dspf=iso levels=4.0,4.5,5.0,5.5,6.0
r3.mkdspf phdata dspf=iso min=4.0 max=6.0 step=0.5
```

## AUTHOR

Bill Brown, [bbrown@gis.uiuc.edu](mailto:brown@gis.uiuc.edu)

## SOURCE CODE

Available at: [r3.mkdspf source code](https://github.com/OSGeo/grass/tree/main/raster3d/r3.mkdspf)
([history](https://github.com/OSGeo/grass/commits/main/raster3d/r3.mkdspf))  
Latest change: Friday Feb 07 19:16:09 2025 in commit [a82a39f](https://github.com/OSGeo/grass/commit/a82a39f673b97fafcfce1604dc3e6015cb96487a)
