---
name: t.rast.out.vtk.py
description: Exports space time raster dataset as VTK time series.
keywords: [ temporal, export, output, raster, VTK, time ]
---

# t.rast.out.vtk.py

## NAME

***t.rast.out.vtk.py*** - Exports space time raster dataset as VTK time series.

### 
### SYNOPSIS

**t.rast.out.vtk.py**  
**t.rast.out.vtk.py --help**  
**t.rast.out.vtk.py** [**-pcg**]  **input**=*name*
 **directory**=*string*
 [**elevation**=*name*]
 [**where**=*sql_query*]
 [**null**=*float*]
 [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**-p**  
&nbsp;&nbsp;&nbsp;&nbsp;Create VTK point data instead of VTK cell data (if no elevation map is given)  
**-c**  
&nbsp;&nbsp;&nbsp;&nbsp;Correct the coordinates to fit the VTK-OpenGL precision  
**-g**  
&nbsp;&nbsp;&nbsp;&nbsp;Export files using the space time dataset granularity for equidistant time between maps, where statement will be ignored  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**input**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of the input space time raster dataset  
**directory**=*string* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Path to the export directory  
**elevation**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Name of input elevation raster map  
**where**=*sql_query*  
&nbsp;&nbsp;&nbsp;&nbsp;WHERE conditions of SQL statement without 'where' keyword used in the temporal GIS framework  
&nbsp;&nbsp;&nbsp;&nbsp;Example: start_time &gt; '2001-01-01 12:30:00'  
**null**=*float*  
&nbsp;&nbsp;&nbsp;&nbsp;Value to represent no data cell  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *-99999.99*

## DESCRIPTION

*t.rast.out.vtk* exports all maps registered in a space time raster
datasets as VTK legacy files using a numerical numbering scheme. The VTK
files can be visualized with any VTK based visualize. Our preferred tool
is ParaView. The VTK legacy files are created using **r.out.vtk**.

## EXAMPLE

In this simple example we create several raster maps with random values
and one elevation map. The random value raster maps are registered in a
space time raster dataset. All maps of this space time raster dataset
are exported using **t.rast.out.vtk** into the directory
**/tmp/export**.

```sh
mkdir /tmp/export
t.rast.out.vtk input=precip_abs directory=/tmp/export/ elevation=elevation

ls -1 /tmp/export
000000_tempmean_monthly.vtk
000001_tempmean_monthly.vtk
000002_tempmean_monthly.vtk
000003_tempmean_monthly.vtk
000004_tempmean_monthly.vtk
000005_tempmean_monthly.vtk
000006_tempmean_monthly.vtk
000007_tempmean_monthly.vtk
000008_tempmean_monthly.vtk
000009_tempmean_monthly.vtk
000010_tempmean_monthly.vtk
000011_tempmean_monthly.vtk
```

## SEE ALSO

*[r.out.vtk](r.out.vtk.md), [ParaView](https://www.paraview.org)*

## AUTHOR

Sören Gebbert, Thünen Institute of Climate-Smart Agriculture

## SOURCE CODE

Available at: [t.rast.out.vtk source code](https://github.com/OSGeo/grass/tree/main/temporal/t.rast.out.vtk)
([history](https://github.com/OSGeo/grass/commits/main/temporal/t.rast.out.vtk))  
Latest change: Friday Feb 07 19:16:09 2025 in commit [a82a39f](https://github.com/OSGeo/grass/commit/a82a39f673b97fafcfce1604dc3e6015cb96487a)
