---
name: t.rast.to.vect.py
description: Converts a space time raster dataset into a space time vector dataset
keywords: [ temporal, conversion, raster, vector, time ]
---

# t.rast.to.vect.py

## NAME

***t.rast.to.vect.py*** - Converts a space time raster dataset into a space time vector dataset

### 
### SYNOPSIS

**t.rast.to.vect.py**  
**t.rast.to.vect.py --help**  
**t.rast.to.vect.py** [**-ntszbv**]  **input**=*name*
 **output**=*name*
 [**where**=*sql_query*]
 **type**=*string*
 **basename**=*string*
 [**suffix**=*string*]
 [**column**=*string*]
 [**nprocs**=*integer*]
 [**--overwrite**]  [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**-n**  
&nbsp;&nbsp;&nbsp;&nbsp;Register empty vector maps  
**-t**  
&nbsp;&nbsp;&nbsp;&nbsp;Do not create attribute tables  
**-s**  
&nbsp;&nbsp;&nbsp;&nbsp;Smooth corners of area features  
**-z**  
&nbsp;&nbsp;&nbsp;&nbsp;Write raster values as z coordinate  
&nbsp;&nbsp;&nbsp;&nbsp;Table is not created. Currently supported only for points.  
**-b**  
&nbsp;&nbsp;&nbsp;&nbsp;Do not build vector topology  
&nbsp;&nbsp;&nbsp;&nbsp;Name must be SQL compliant  
**-v**  
&nbsp;&nbsp;&nbsp;&nbsp;Use raster values as categories instead of unique sequence (CELL only)  
**--overwrite**  
&nbsp;&nbsp;&nbsp;&nbsp;Allow output files to overwrite existing files  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**input**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of the input space time raster dataset  
**output**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of the output space time vector dataset  
**where**=*sql_query*  
&nbsp;&nbsp;&nbsp;&nbsp;WHERE conditions of SQL statement without 'where' keyword used in the temporal GIS framework  
&nbsp;&nbsp;&nbsp;&nbsp;Example: start_time &gt; '2001-01-01 12:30:00'  
**type**=*string* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Output feature type  
&nbsp;&nbsp;&nbsp;&nbsp;Options: *point, line, area*  
**basename**=*string* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Basename of the new generated output maps  
&nbsp;&nbsp;&nbsp;&nbsp;A numerical suffix separated by an underscore will be attached to create a unique identifier  
**suffix**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Suffix to add at basename: set 'gran' for granularity, 'time' for the full time format, 'num' for numerical suffix with a specific number of digits (default %05)  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *gran*  
**column**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Name of attribute column to store value  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *value*  
**nprocs**=*integer*  
&nbsp;&nbsp;&nbsp;&nbsp;Number of r.to.vect processes to run in parallel, more than 1 process works only in conjunction with flag -t  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *1*

## DESCRIPTION

*t.rast.to.vect* is designed to convert a space time raster dataset into
a space time vector dataset. This module works as a front-end to
[r.to.vect](r.to.vect.md) and therefore supports all parameter of this
module. Hence, all raster map layers in a space time raster dataset are
passed to [r.to.vect](r.to.vect.md) that converts them into vector map
layers (using point,line or area as conversion criteria). Please refer
to the [r.to.vect](r.to.vect.md) documentation for a detailed
description of the raster to vector conversion options. The new
generated vector map layers will be registered in the output space time
vector dataset, using the same time stamps as their raster map layer
origins.

This module supports the parallel processing of
[r.to.vect](r.to.vect.md) module instances. The number of parallel
processes can be set with the *nprocs* option. However, this will only
work in conjunction with the *-t* flag, that avoids the creation of
attribute tables. The parallel creation of attribute tables is not
supported.

The *where* option allows selecting subsets of the input space time
raster dataset.

The flag *-n* can be used to force the registration of empty vector map
layers. Empty vector maps may occur in case that empty raster map layers
should be converted into vector map layers.

## SEE ALSO

*[r.to.vect](r.to.vect.md), [t.rast.db.select](t.vect.db.select.md),
[t.info](t.info.md)*

## AUTHOR

Sören Gebbert, Geoinformatikbüro Dassau

## SOURCE CODE

Available at: [t.rast.to.vect source code](https://github.com/OSGeo/grass/tree/main/temporal/t.rast.to.vect)
([history](https://github.com/OSGeo/grass/commits/main/temporal/t.rast.to.vect))  
Latest change: Saturday Mar 01 11:59:08 2025 in commit [d310a3c](https://github.com/OSGeo/grass/commit/d310a3c28e84eff31e2d2c9f8c6218ba71dd40b8)
