---
name: t.vect.db.select.py
description: Prints attributes of vector maps registered in a space time vector dataset.
keywords: [ temporal, attribute table, vector, database, select, time ]
---

# t.vect.db.select.py

## NAME

***t.vect.db.select.py*** - Prints attributes of vector maps registered in a space time vector dataset.

### 
### SYNOPSIS

**t.vect.db.select.py**  
**t.vect.db.select.py --help**  
**t.vect.db.select.py**  **input**=*name*
 [**columns**=*name* [,*name*,...]]
 [**separator**=*character*]
 [**layer**=*string*]
 [**where**=*sql_query*]
 [**t_where**=*sql_query*]
 [**--verbose**]  [**--quiet**]  [**--ui**]

**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**input**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of the input space time vector dataset  
**columns**=*name* [,*name*,...]  
&nbsp;&nbsp;&nbsp;&nbsp;Name of attribute column(s)  
**separator**=*character*  
&nbsp;&nbsp;&nbsp;&nbsp;Field separator character between the output columns  
&nbsp;&nbsp;&nbsp;&nbsp;Special characters: pipe, comma, space, tab, newline  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *pipe*  
**layer**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Layer number or name  
&nbsp;&nbsp;&nbsp;&nbsp;Vector features can have category values in different layers. This number determines which layer to use. When used with direct OGR access this is the layer name.  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *1*  
**where**=*sql_query*  
&nbsp;&nbsp;&nbsp;&nbsp;WHERE conditions of SQL statement without 'where' keyword  
&nbsp;&nbsp;&nbsp;&nbsp;Example: income &lt; 1000 and population &gt;= 10000  
**t_where**=*sql_query*  
&nbsp;&nbsp;&nbsp;&nbsp;WHERE conditions of SQL statement without 'where' keyword used in the temporal GIS framework  
&nbsp;&nbsp;&nbsp;&nbsp;Example: start_time &gt; '2001-01-01 12:30:00'

## DESCRIPTION

The module *t.vect.db.select* prints attributes of vector maps
registered in a space time vector dataset.

## EXAMPLE

The example is querying the *shoreline* space time dataset:

```sh
t.vect.db.select input=shoreline
start_time|end_time|cat|DESCR|SOURCE|DATE
1849|1873|1|T-736|NOAA/USGS|01/01/1858
1849|1873|2|T-657|NOAA/USGS|01/01/1857
1849|1873|3|T-381(2)|NOAA/USGS|01/01/1852
1849|1873|4|T-381(1)|NOAA/USGS|01/01/1852
1849|1873|5|T-381(1)|NOAA/USGS|01/01/1852
...
2009||44|2009 USDA NAIP|2009-07-11|VA, SAND, Wet / Dry
2009||45|2009 USDA NAIP|2009-07-11|Carolina Beach, SAND, Wet / Dry
2009||46|2009 USDA NAIP|2009-07-11|Carolina Beach, REVETMENT-ROCK, Hard Structure
2009||47|2009 USDA NAIP|2009-07-11|Fort Fisher, REVETMENT-ROCK, Hard Structure
```

In the following example it print only DATE and SOURCE columns for data
before 1900-01-01.

```sh
t.vect.db.select input=shoreline column=DATE,SOURCE t_where="start_time < 1900"
start_time|end_time|DATE|SOURCE
1849|1873|01/01/1858|NOAA/USGS
1849|1873|01/01/1857|NOAA/USGS
1849|1873|01/01/1852|NOAA/USGS
1849|1873|01/01/1852|NOAA/USGS
...
1849|1873|01/01/1860|NOAA/USGS
1849|1873|01/01/1860|NOAA/USGS
1849|1873|01/01/1873|Coastal Carolina University
1849|1873|01/01/1873|Coastal Carolina University
1849|1873|01/01/1873|Coastal Carolina University
```

## SEE ALSO

*[t.create](t.create.md), [t.info](t.info.md)*

## AUTHOR

Sören Gebbert, Thünen Institute of Climate-Smart Agriculture

## SOURCE CODE

Available at: [t.vect.db.select source code](https://github.com/OSGeo/grass/tree/main/temporal/t.vect.db.select)
([history](https://github.com/OSGeo/grass/commits/main/temporal/t.vect.db.select))  
Latest change: Friday Feb 07 19:16:09 2025 in commit [a82a39f](https://github.com/OSGeo/grass/commit/a82a39f673b97fafcfce1604dc3e6015cb96487a)
