---
name: t.vect.extract.py
description: Extracts a subset of a space time vector dataset.
keywords: [ temporal, extract, vector, time ]
---

# t.vect.extract.py

## NAME

***t.vect.extract.py*** - Extracts a subset of a space time vector dataset.

### 
### SYNOPSIS

**t.vect.extract.py**  
**t.vect.extract.py --help**  
**t.vect.extract.py** [**-n**]  **input**=*name*
 [**where**=*sql_query*]
 [**expression**=*sql_query*]
 **output**=*name*
 [**layer**=*string*]
 [**type**=*string* [,*string*,...]]
 [**basename**=*string*]
 [**suffix**=*string*]
 [**nprocs**=*integer*]
 [**--overwrite**]  [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**-n**  
&nbsp;&nbsp;&nbsp;&nbsp;Register empty maps  
**--overwrite**  
&nbsp;&nbsp;&nbsp;&nbsp;Allow output files to overwrite existing files  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**input**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of the input space time vector dataset  
**where**=*sql_query*  
&nbsp;&nbsp;&nbsp;&nbsp;WHERE conditions of SQL statement without 'where' keyword used in the temporal GIS framework  
&nbsp;&nbsp;&nbsp;&nbsp;Example: start_time &gt; '2001-01-01 12:30:00'  
**expression**=*sql_query*  
&nbsp;&nbsp;&nbsp;&nbsp;WHERE conditions of SQL statement without 'where' keyword  
&nbsp;&nbsp;&nbsp;&nbsp;Example: income &lt; 1000 and population &gt;= 10000  
**output**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of the output space time vector dataset  
**layer**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Layer number or name  
&nbsp;&nbsp;&nbsp;&nbsp;Vector features can have category values in different layers. This number determines which layer to use. When used with direct OGR access this is the layer name.  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *1*  
**type**=*string* [,*string*,...]  
&nbsp;&nbsp;&nbsp;&nbsp;Input feature type  
&nbsp;&nbsp;&nbsp;&nbsp;Options: *point, line, boundary, centroid, area*  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *point,line,boundary,centroid,area*  
**basename**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Basename of the new generated output maps  
&nbsp;&nbsp;&nbsp;&nbsp;A numerical suffix separated by an underscore will be attached to create a unique identifier  
**suffix**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Suffix to add at basename: set 'gran' for granularity, 'time' for the full time format, 'num' for numerical suffix with a specific number of digits (default %05)  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *gran*  
**nprocs**=*integer*  
&nbsp;&nbsp;&nbsp;&nbsp;The number of v.extract processes to run in parallel. Use only if database backend is used which supports concurrent writing  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *1*

## DESCRIPTION

The purpose of **t.vect.extract** is to extract a subset of a space time
vector dataset and to store that subset in a different space time vector
dataset.

## EXAMPLE

In the following example a new space time vector dataset will be create
with all the data later than the year 2000:

```sh
t.vect.extract input=shoreline where="start_time > 2000" \
               output=shoreline_later_2000 basename=new_shoreline

t.info shoreline_later_2000@shoreline type=stvds
 +-------------------- Space Time Vector Dataset -----------------------------+
 |                                                                            |
 +-------------------- Basic information -------------------------------------+
 | Id: ........................ shoreline_later_2000@shoreline
 | Name: ...................... shoreline_later_2000
 | Mapset: .................... shoreline
 | Creator: ................... lucadelu
 | Temporal type: ............. relative
 | Creation time: ............. 2014-11-29 08:43:50.043219
 | Modification time:.......... 2014-11-29 08:43:50.085407
 | Semantic type:.............. mean
 +-------------------- Relative time -----------------------------------------+
 | Start time:................. 2003
 | End time:................... 2009
 | Relative time unit:......... years
 | Granularity:................ 1
 | Temporal type of maps:...... point
 +-------------------- Spatial extent ----------------------------------------+
 | North:...................... 1039175.31479
 | South:...................... 34705.216018
 | East:.. .................... 3052322.44671
 | West:....................... 2130004.16779
 | Top:........................ 0.0
 | Bottom:..................... 0.0
 +-------------------- Metadata information ----------------------------------+
 | Vector register table:...... vector_map_register_8395740fc8de42149fef74a3d25bbb05
 | Number of points ........... 0
 | Number of lines ............ 407
 | Number of boundaries ....... 0
 | Number of centroids ........ 0
 | Number of faces ............ 0
 | Number of kernels .......... 0
 | Number of primitives ....... 407
 | Number of nodes ............ 767
 | Number of areas ............ 0
 | Number of islands .......... 0
 | Number of holes ............ 0
 | Number of volumes .......... 0
 | Number of registered maps:.. 3
 |
 | Title:
 | North Carolina shoreline
 | Description:
 | North Caroline shoreline from 2000 to 2009
 | Command history:
 | # 2014-11-29 08:43:50
 | t.vect.extract input="shoreline"
 |     where="start_time > 2000" output="shoreline_later_2000"
 |     basename="new_shoreline"
 | # 2014-11-29 08:44:14
 | t.support type="stvds"
 |     input="shoreline_later_2000@shoreline"
 |     descr="North Caroline shoreline from 2000 to 2009"
 +----------------------------------------------------------------------------+

t.vect.list shoreline_later_2000
name|layer|mapset|start_time|end_time
shoreline_2003|None|shoreline|2003|None
shoreline_2004|None|shoreline|2004|None
shoreline_2009|None|shoreline|2009|None
```

## SEE ALSO

*[t.create](t.create.md), [t.info](t.info.md)*

## AUTHOR

Sören Gebbert, Thünen Institute of Climate-Smart Agriculture

## SOURCE CODE

Available at: [t.vect.extract source code](https://github.com/OSGeo/grass/tree/main/temporal/t.vect.extract)
([history](https://github.com/OSGeo/grass/commits/main/temporal/t.vect.extract))  
Latest change: Wednesday Apr 02 17:48:37 2025 in commit [571253a](https://github.com/OSGeo/grass/commit/571253a5e75ae2ff6ba7adf14fbc859ba7acd92c)
