---
name: v.build
description: Optionally also checks for topological errors.
keywords: [ vector, topology, geometry ]
---

# v.build

## NAME

***v.build*** - Creates topology for vector map.

Optionally also checks for topological errors.

### 
### SYNOPSIS

**v.build**  
**v.build --help**  
**v.build** [**-e**]  **map**=*name*
 [**error**=*name*]
 **option**=*string* [,*string*,...]
 [**--overwrite**]  [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**-e**  
&nbsp;&nbsp;&nbsp;&nbsp;Extensive checks for topological errors  
&nbsp;&nbsp;&nbsp;&nbsp;Perform in-depth checks for topological errors when building topology  
**--overwrite**  
&nbsp;&nbsp;&nbsp;&nbsp;Allow output files to overwrite existing files  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**map**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of vector map  
**error**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Name for output vector map where erroneous vector features are written to  
**option**=*string* [,*string*,...] **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Build topology or dump topology or indices to standard output  
&nbsp;&nbsp;&nbsp;&nbsp;Options: *build, dump, sdump, cdump, fdump*  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *build*  
&nbsp;&nbsp;&nbsp;&nbsp;**build**: build topology  
&nbsp;&nbsp;&nbsp;&nbsp;**dump**: write topology to stdout  
&nbsp;&nbsp;&nbsp;&nbsp;**sdump**: write spatial index to stdout  
&nbsp;&nbsp;&nbsp;&nbsp;**cdump**: write category index to stdout  
&nbsp;&nbsp;&nbsp;&nbsp;**fdump**: write feature index to stdout (OGR simple-feature-based formats only)

## DESCRIPTION

*v.build* builds support files for GRASS vector maps. These support
files supply topology and category information including spatial index
that are needed by other GRASS modules.

GRASS is generating these support files automatically, only in rare
cases the user has to (re)build them.

Refer to [vector data processing in GRASS GIS](vectorintro.md) for more
information on GRASS vector data model.

## NOTES

*v.build* creates support files only for vector maps located in the
user's current mapset. It's not possible to rebuild support files
(**option=build**) for vector maps from other mapsets.

In case of errors, the user can optionally generate an **error** vector
map containing the erroneous vectors for later inspection.

If **error** vector map is specified, *v.build* checks:

- isolated boundaries (which are not forming any areas),
- centroids outside of area,
- duplicated centroids.

Extensive checks for topological errors (flag **-e**) also includes:

- lines or boundaries of zero length,
- intersecting boundaries, i.e. overlapping areas,
- areas without centroids that are not isles.

## EXAMPLES

### Build topology

Note that **option=build** also recreates spatial and category indices,
not only topology. For linked OGR layers (see
*[v.external](v.external.md)*) also feature index is created.

```sh
v.build map=urbanarea option=build
```

Note that the vector map *urbanarea* must be located in the current
mapset.

### Dump topology or indices

Dump options print topology, spatial, category or feature index to
standard output. Such information can also be printed for vector maps
from other mapsets. A description of the vector topology is available in
the [GRASS GIS 8 Programmer's
Manual](https://grass.osgeo.org/programming8/vlibTopology.html), section
"Vector library topology management".

```sh
v.build map=urbanarea option=dump
```

## SEE ALSO

*[v.build.all](v.build.all.md),
[v.build.polylines](v.build.polylines.md), [v.edit](v.edit.md),
[v.split](v.split.md), [v.support](v.support.md)*

See also *[wxGUI vector digitizer](wxGUI.vdigit.md)*.

## AUTHORS

Dave Gerdes, U.S.Army Construction Engineering Research Laboratory,  
Michael Higgins, U.S.Army Construction Engineering Research
Laboratory,  
Radim Blazek, ITC-irst, Trento, Italy

## SOURCE CODE

Available at: [v.build source code](https://github.com/OSGeo/grass/tree/main/vector/v.build)
([history](https://github.com/OSGeo/grass/commits/main/vector/v.build))  
Latest change: Saturday Mar 15 07:34:27 2025 in commit [db9ad65](https://github.com/OSGeo/grass/commit/db9ad655cc37c9277246fb706d1651966607f3f2)
