---
name: v.db.droprow.py
description: Removes a vector feature from a vector map through attribute selection.
keywords: [ vector, attribute table, database ]
---

# v.db.droprow.py

## NAME

***v.db.droprow.py*** - Removes a vector feature from a vector map through attribute selection.

### 
### SYNOPSIS

**v.db.droprow.py**  
**v.db.droprow.py --help**  
**v.db.droprow.py**  **input**=*name*
 [**layer**=*string*]
 **where**=*sql_query*
 **output**=*name*
 [**--overwrite**]  [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**--overwrite**  
&nbsp;&nbsp;&nbsp;&nbsp;Allow output files to overwrite existing files  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**input**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of input vector map  
&nbsp;&nbsp;&nbsp;&nbsp;Or data source for direct OGR access  
**layer**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Layer number or name  
&nbsp;&nbsp;&nbsp;&nbsp;Vector features can have category values in different layers. This number determines which layer to use. When used with direct OGR access this is the layer name.  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *1*  
**where**=*sql_query* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;WHERE conditions of SQL statement without 'where' keyword  
&nbsp;&nbsp;&nbsp;&nbsp;Example: income &lt; 1000 and population &gt;= 10000  
**output**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name for output vector map

## DESCRIPTION

*v.db.droprow* removes vector object(s) (point, line, area, face etc.)
from a vector map through attribute selection in the table connected to
the given vector map. It automatically checks the connection for the
specified layer.

## NOTES

v.db.droprow is a front-end to *v.extract* (reverse selection) to allow
easier usage. The existing database connection(s) can be verified with
*v.db.connect*.

## EXAMPLES

Dropping all vector points without elevation attribute (North Carolina
data set):  

```sh
g.region raster=elevation -p
v.random output=rand5k_elev n=5000

v.db.addtable map=rand5k_elev column="elevation double precision"
v.what.rast vect=rand5k_elev rast=elevation column=elevation

# verify absence of some elevation attributes ("number of NULL attributes"):
v.univar rand5k_elev type=point column=elevation

# Remove all vector points lacking elevation attribute
v.db.droprow rand5k_elev output=rand5k_elev_filt where="elevation IS NULL"

# verify:
v.univar rand5k_elev_filt type=point column=elevation
```

## SEE ALSO

*[db.droptable](db.droptable.md), [db.execute](db.execute.md),
[v.db.addcolumn](v.db.addcolumn.md), [v.db.addtable](v.db.addtable.md),
[v.db.connect](v.db.connect.md), [v.db.dropcolumn](v.db.dropcolumn.md),
[v.db.droptable](v.db.droptable.md), [v.db.select](v.db.select.md),
[v.db.update](v.db.update.md)*

*[GRASS SQL interface](sql.md)*

## AUTHOR

Markus Neteler

## SOURCE CODE

Available at: [v.db.droprow source code](https://github.com/OSGeo/grass/tree/main/scripts/v.db.droprow)
([history](https://github.com/OSGeo/grass/commits/main/scripts/v.db.droprow))  
Latest change: Friday Feb 07 19:16:09 2025 in commit [a82a39f](https://github.com/OSGeo/grass/commit/a82a39f673b97fafcfce1604dc3e6015cb96487a)
