---
name: v.db.droptable.py
description: Removes existing attribute table of a vector map.
keywords: [ vector, attribute table, database ]
---

# v.db.droptable.py

## NAME

***v.db.droptable.py*** - Removes existing attribute table of a vector map.

### 
### SYNOPSIS

**v.db.droptable.py**  
**v.db.droptable.py --help**  
**v.db.droptable.py** [**-f**]  **map**=*name*
 [**table**=*name*]
 [**layer**=*string*]
 [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**-f**  
&nbsp;&nbsp;&nbsp;&nbsp;Force removal (required for actual deletion of table)  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**map**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of vector map  
&nbsp;&nbsp;&nbsp;&nbsp;Or data source for direct OGR access  
**table**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Table name (default: vector map name)  
**layer**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Layer number or name  
&nbsp;&nbsp;&nbsp;&nbsp;Vector features can have category values in different layers. This number determines which layer to use. When used with direct OGR access this is the layer name.  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *1*

## DESCRIPTION

*v.db.droptable* removes an existing attribute table from a given vector
map linked at given layer. If the **-f** force flag is not given then
nothing is removed.

## NOTES

*v.db.droptable* is a front-end to *db.execute* to allow easier usage.

The existing database connection(s) can be verified with *v.db.connect*.

## EXAMPLE

Removing attribute table connected to layer 1:  

```sh
g.copy vect=roadsmajor,myroads
v.db.droptable myroads
v.db.droptable myroads -f
v.db.connect -p myroads
```

## SEE ALSO

*[db.connect](db.connect.md), [db.execute](db.execute.md),
[v.db.addtable](v.db.addtable.md), [v.db.connect](v.db.connect.md),
[v.db.dropcolumn](v.db.dropcolumn.md), [v.db.select](v.db.select.md),
[v.db.update](v.db.update.md)*

*[GRASS SQL interface](sql.md)*

## AUTHOR

Markus Neteler

## SOURCE CODE

Available at: [v.db.droptable source code](https://github.com/OSGeo/grass/tree/main/scripts/v.db.droptable)
([history](https://github.com/OSGeo/grass/commits/main/scripts/v.db.droptable))  
Latest change: Friday Feb 07 19:16:09 2025 in commit [a82a39f](https://github.com/OSGeo/grass/commit/a82a39f673b97fafcfce1604dc3e6015cb96487a)
