---
name: v.delaunay
description: Creates a Delaunay triangulation from an input vector map containing points or centroids.
keywords: [ vector, geometry, triangulation ]
---

# v.delaunay

## NAME

***v.delaunay*** - Creates a Delaunay triangulation from an input vector map containing points or centroids.

### 
### SYNOPSIS

**v.delaunay**  
**v.delaunay --help**  
**v.delaunay** [**-rl**]  **input**=*name*
 [**layer**=*string*]
 **output**=*name*
 [**--overwrite**]  [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**-r**  
&nbsp;&nbsp;&nbsp;&nbsp;Use only points in current region  
**-l**  
&nbsp;&nbsp;&nbsp;&nbsp;Output triangulation as a graph (lines), not areas  
**--overwrite**  
&nbsp;&nbsp;&nbsp;&nbsp;Allow output files to overwrite existing files  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**input**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of input vector map  
&nbsp;&nbsp;&nbsp;&nbsp;Or data source for direct OGR access  
**layer**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Layer number or name ('-1' for all layers)  
&nbsp;&nbsp;&nbsp;&nbsp;A single vector map can be connected to multiple database tables. This number determines which table to use. When used with direct OGR access this is the layer name.  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *-1*  
**output**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name for output vector map

## DESCRIPTION

*v.delaunay* uses an existing vector points map (**input**) to create a
Delaunay triangulation vector map (**output**).

Delaunay triangulation example (red-yellow points are the data points
from which the triangulation was generated):

![v_delaunay](v_delaunay.png)

## EXAMPLE

Commands used with the North Carolina dataset to create the above figure
(subset shown in figure).

```sh
g.region n=220750 s=219950 w=638300 e=639000 -p
v.delaunay input=elev_lid792_randpts output=elev_lid792_randpts_delaunay
```

## REFERENCES

*Leonid Guibas and Jorge Stolfi, (1985). Primitives for the Manipulation
of General Subdivisions and the Computation of Voronoi Diagrams, ACM
Transactions on Graphics, Vol 4, No. 2, April 1985, Pages 74-123*

## SEE ALSO

*[v.voronoi](v.voronoi.md), [v.hull](v.hull.md)*

[Delaunay triangulation
(Wikipedia)](https://en.wikipedia.org/wiki/Delaunay_triangulation)

## AUTHORS

Martin Pavlovsky, Google Summer of Code 2008, Student  
Paul Kelly, Mentor  
Based on "dct" by Geoff Leach, Department of Computer Science, RMIT.

## SOURCE CODE

Available at: [v.delaunay source code](https://github.com/OSGeo/grass/tree/main/vector/v.delaunay)
([history](https://github.com/OSGeo/grass/commits/main/vector/v.delaunay))  
Latest change: Tuesday Feb 18 17:20:26 2025 in commit [688e625](https://github.com/OSGeo/grass/commit/688e625e7db3be9a465ce99ba25f36d2ebdd5aeb)
