---
name: v.extrude
description: Optionally the height can be derived from sampling of elevation raster map.
keywords: [ vector, geometry, sampling, 3D ]
---

# v.extrude

## NAME

***v.extrude*** - Extrudes flat vector features to 3D vector features with defined height.

Optionally the height can be derived from sampling of elevation raster map.

### 
### SYNOPSIS

**v.extrude**  
**v.extrude --help**  
**v.extrude** [**-t**]  **input**=*name*
 [**layer**=*string*]
 [**cats**=*range*]
 [**where**=*sql_query*]
 [**type**=*string* [,*string*,...]]
 **output**=*name*
 [**zshift**=*float*]
 [**height**=*float*]
 [**height_column**=*name*]
 [**elevation**=*name*]
 [**method**=*string*]
 [**scale**=*float*]
 [**null_value**=*float*]
 [**--overwrite**]  [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**-t**  
&nbsp;&nbsp;&nbsp;&nbsp;Trace elevation  
**--overwrite**  
&nbsp;&nbsp;&nbsp;&nbsp;Allow output files to overwrite existing files  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**input**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of input vector map  
&nbsp;&nbsp;&nbsp;&nbsp;Or data source for direct OGR access  
**layer**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Layer number or name ('-1' for all layers)  
&nbsp;&nbsp;&nbsp;&nbsp;A single vector map can be connected to multiple database tables. This number determines which table to use. When used with direct OGR access this is the layer name.  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *-1*  
**cats**=*range*  
&nbsp;&nbsp;&nbsp;&nbsp;Category values  
&nbsp;&nbsp;&nbsp;&nbsp;Example: 1,3,7-9,13  
**where**=*sql_query*  
&nbsp;&nbsp;&nbsp;&nbsp;WHERE conditions of SQL statement without 'where' keyword  
&nbsp;&nbsp;&nbsp;&nbsp;Example: income &lt; 1000 and population &gt;= 10000  
**type**=*string* [,*string*,...]  
&nbsp;&nbsp;&nbsp;&nbsp;Input feature type  
&nbsp;&nbsp;&nbsp;&nbsp;Options: *point, line, area*  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *point,line,area*  
**output**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name for output vector map  
**zshift**=*float*  
&nbsp;&nbsp;&nbsp;&nbsp;Shifting value for z coordinates  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *0*  
**height**=*float*  
&nbsp;&nbsp;&nbsp;&nbsp;Fixed height for 3D vector features  
**height_column**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Name of attribute column with feature height  
**elevation**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Elevation raster map for height extraction  
**method**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Sampling interpolation method  
&nbsp;&nbsp;&nbsp;&nbsp;Options: *nearest, bilinear, bicubic*  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *nearest*  
&nbsp;&nbsp;&nbsp;&nbsp;**nearest**: Nearest-neighbor interpolation  
&nbsp;&nbsp;&nbsp;&nbsp;**bilinear**: Bilinear interpolation  
&nbsp;&nbsp;&nbsp;&nbsp;**bicubic**: Bicubic interpolation  
**scale**=*float*  
&nbsp;&nbsp;&nbsp;&nbsp;Scale factor sampled raster values  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *1.0*  
**null_value**=*float*  
&nbsp;&nbsp;&nbsp;&nbsp;Height for sampled raster NULL values

## DESCRIPTION

*v.extrude* creates faces, kernels or 3D lines based on input 2D vector
features. Points are converted to 3D vertical lines, lines to faces and
areas to volumes (composition of closed set of faces and kernel).

If **elevation** parameter is used then 3D vector features follow the
elevation model by using individual elevation values for the vertices.
Height for vertices is interpolated from elevation raster map using
given interpolation **method**.

## NOTES

*v.extrude* extrudes vector features which means that points are
converted to vertical lines. Lines and area boundaries are extruded to a
set of faces, each segment defines one face. Area centroids are written
as kernels. Area as a composition of boundaries and centroid is stored
as a closed set of faces and kernel which define a volume.

For conversion of 2D points or lines to 3D can be used
*[v.to.3d](v.to.3d.md)* or *[v.drape](v.drape.md)*. In opposite to
*v.extrude*, these modules do not extrude vector features, they defines
z-coordinate for the features from given parameters or by sampling
elevation raster map values. It means that no feature type conversion is
applied, points remain still points in the output vector map. Same
applies for the lines.

*v.extrude* modifies only features geometry. Feature categories remain
untouched and attribute data is copied from input vector map to the
output.

By default, all features (including features without category) from
input vector map are processed (**layer=-1**). Feature selection can be
applied by **layer**, **cats** or **where** parameter.

## EXAMPLES

### 3D houses with fixed height

```sh
v.extrude input=houses output=houses3D height=5 type=area
```

### 3D houses with individual height

```sh
v.extrude input=houses output=houses3D elevation=dem height_column=height type=area
```

### Convert 2D points to 3D vertical lines with fixed height

```sh
v.extrude input=geodetic_pts output=points3D height=200 type=point
```

## SEE ALSO

*[v.transform](v.transform.md), [v.drape](v.drape.md),
[v.to.3d](v.to.3d.md)*

*[wxGUI 3D viewer](wxGUI.nviz.md)*

## AUTHORS

Jachym Cepicky,  
Updated for GRASS 7 by Martin Landa, FBK-irst, Italy and Czech Technical
University in Prague, Czech Republic

## SOURCE CODE

Available at: [v.extrude source code](https://github.com/OSGeo/grass/tree/main/vector/v.extrude)
([history](https://github.com/OSGeo/grass/commits/main/vector/v.extrude))  
Latest change: Friday Feb 07 19:16:09 2025 in commit [a82a39f](https://github.com/OSGeo/grass/commit/a82a39f673b97fafcfce1604dc3e6015cb96487a)
