---
name: v.hull
description: Produces a 2D/3D convex hull for a given vector map.
keywords: [ vector, geometry, 3D ]
---

# v.hull

## NAME

***v.hull*** - Produces a 2D/3D convex hull for a given vector map.

### 
### SYNOPSIS

**v.hull**  
**v.hull --help**  
**v.hull** [**-rf**]  **input**=*name*
 [**layer**=*string*]
 **output**=*name*
 [**cats**=*range*]
 [**where**=*sql_query*]
 [**--overwrite**]  [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**-r**  
&nbsp;&nbsp;&nbsp;&nbsp;Limit to current region  
**-f**  
&nbsp;&nbsp;&nbsp;&nbsp;Create a 'flat' 2D hull even if the input is 3D points  
**--overwrite**  
&nbsp;&nbsp;&nbsp;&nbsp;Allow output files to overwrite existing files  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**input**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of input vector map  
&nbsp;&nbsp;&nbsp;&nbsp;Or data source for direct OGR access  
**layer**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Layer number or name ('-1' for all layers)  
&nbsp;&nbsp;&nbsp;&nbsp;A single vector map can be connected to multiple database tables. This number determines which table to use. When used with direct OGR access this is the layer name.  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *-1*  
**output**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name for output vector map  
**cats**=*range*  
&nbsp;&nbsp;&nbsp;&nbsp;Category values  
&nbsp;&nbsp;&nbsp;&nbsp;Example: 1,3,7-9,13  
**where**=*sql_query*  
&nbsp;&nbsp;&nbsp;&nbsp;WHERE conditions of SQL statement without 'where' keyword  
&nbsp;&nbsp;&nbsp;&nbsp;Example: income &lt; 1000 and population &gt;= 10000

## DESCRIPTION

*v.hull* computes the convex hull of a vector map and outputs the convex
hull polygon as a vector area map. The convex hull, or convex envelope,
for an object or a set of objects is the minimal convex set containing
the given objects. This module creates a vector polygon containing all
vector points or lines of the input map.

In the case of 3D input points, the hull will be a 3D hull as well,
unless the user specifies the **-f** flag. The 3D hull will be composed
of triangular faces.

![Convex hull polygon](v_hull.png)  
*Fig: Convex hull polygon created with v.hull*

## NOTES

In order to use the **where** option the **layer** option must be set to
a positive number (the default is '-1' for 'all layers'), otherwise all
points from all layers will be used and the **cats** and **where**
options will be ignored.

## EXAMPLE

Example of *v.hull* 3D output (using two random 3D point clouds, North
Carolina sample data set):

```sh
g.region rural_1m -p
r.mapcalc "zero = 0"
v.random -z output=random3d_a n=10 zmin=0 zmax=200
v.random -z output=random3d_b n=15 zmin=400 zmax=600
v.hull input=random3d_a output=random3d_a_hull
v.hull input=random3d_b output=random3d_b_hull

d.mon wx0
d.vect random3d_a_hull
d.vect random3d_a color=red

d.vect random3d_b_hull
d.vect random3d_b color=red

# 3D view in wxGUI (g.gui)
```

![Convex hull in 3D](v_hull_3d.png)  
*Fig: Convex hull in 3D from 3D points created with v.hull*

## REFERENCES

- M. de Berg, M. van Kreveld, M. Overmars, O. Schwarzkopf, (2000).
  Computational geometry, chapter 1.1, 2-8.
- J. O'Rourke, (1998). Computational Geometry in C (Second Edition),
  chapter 4.

## SEE ALSO

*[v.delaunay](v.delaunay.md)*

## AUTHORS

Andrea Aime, Modena, Italy  
Markus Neteler, ITC-irst (update to 5.7)  
Benjamin Ducke, CAU Kiel (3D hull support)  
Martin Landa, CTU in Prague, Czech Republic (vector lines support)

## SOURCE CODE

Available at: [v.hull source code](https://github.com/OSGeo/grass/tree/main/vector/v.hull)
([history](https://github.com/OSGeo/grass/commits/main/vector/v.hull))  
Latest change: Wednesday Feb 26 22:15:39 2025 in commit [c855d99](https://github.com/OSGeo/grass/commit/c855d997fd574d1b3d8cd7afdaff087a1ca5ffd6)
