---
name: v.in.mapgen.py
description: Imports Mapgen or Matlab-ASCII vector maps into GRASS.
keywords: [ vector, import ]
---

# v.in.mapgen.py

## NAME

***v.in.mapgen.py*** - Imports Mapgen or Matlab-ASCII vector maps into GRASS.

### 
### SYNOPSIS

**v.in.mapgen.py**  
**v.in.mapgen.py --help**  
**v.in.mapgen.py** [**-fz**]  **input**=*name*
 [**output**=*name*]
 [**--overwrite**]  [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**-f**  
&nbsp;&nbsp;&nbsp;&nbsp;Input map is in Matlab format  
**-z**  
&nbsp;&nbsp;&nbsp;&nbsp;Create a 3D vector points map from 3 column Matlab data  
**--overwrite**  
&nbsp;&nbsp;&nbsp;&nbsp;Allow output files to overwrite existing files  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**input**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of input file in Mapgen/Matlab format  
**output**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Name for output vector map (omit for display to stdout)

## DESCRIPTION

*v.in.mapgen* allows the user to import Mapgen or Matlab vector maps
into GRASS.

## NOTES

This module only imports data into vector lines.

The user can get coastline data in Mapgen or Matlab format from NOAA's
Coastline Extractor at
<https://www.ngdc.noaa.gov/mgg/shorelines/shorelines.html>.

Matlab vector line maps are simply a series of "x y" data points. Lines
are separated by a row containing `NaN NaN`. Output from Matlab with
this command:  

```sh
    save filename.txt arrayname -ASCII
```

The user can import 3D lines from Matlab by exporting a 3 column array
and using the **-z** flag.

## SEE ALSO

*[v.in.ascii](v.in.ascii.md)*

## AUTHORS

Based on *v.in.mapgen.sh* for GRASS 5.0 by Andreas Lange  
Rewritten for GRASS 6 by Hamish Bowman

## SOURCE CODE

Available at: [v.in.mapgen source code](https://github.com/OSGeo/grass/tree/main/scripts/v.in.mapgen)
([history](https://github.com/OSGeo/grass/commits/main/scripts/v.in.mapgen))  
Latest change: Friday Feb 07 19:16:09 2025 in commit [a82a39f](https://github.com/OSGeo/grass/commit/a82a39f673b97fafcfce1604dc3e6015cb96487a)
