---
name: v.in.region
description: Creates a vector polygon from the current region extent.
keywords: [ vector, geometry ]
---

# v.in.region

## NAME

***v.in.region*** - Creates a vector polygon from the current region extent.

### 
### SYNOPSIS

**v.in.region**  
**v.in.region --help**  
**v.in.region** [**-d**]  **output**=*name*
 [**type**=*string*]
 [**cat**=*integer*]
 [**--overwrite**]  [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**-d**  
&nbsp;&nbsp;&nbsp;&nbsp;Densify lines using region resolution  
**--overwrite**  
&nbsp;&nbsp;&nbsp;&nbsp;Allow output files to overwrite existing files  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**output**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name for output vector map  
**type**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Select type: line or area  
&nbsp;&nbsp;&nbsp;&nbsp;Options: *line, area*  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *area*  
**cat**=*integer*  
&nbsp;&nbsp;&nbsp;&nbsp;Category value  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *1*

## DESCRIPTION

*v.in.region* creates a new vector map from current region extent.

If the output of *v.in.region* is to be used for raster reprojection,
the **-d** flag should be used after setting the region to the raster
map to be reprojected with *[r.proj](r.proj.md)*.

## EXAMPLE

The example is based on the North Carolina sample data. To create a
bounding box vector map based on a raster map, the computational region
is first set to the raster map. Then a vector bounding box is created
based on the actual computational region (in this case precisely
reflecting the pixel geometry of the raster map), resulting in a new
vector polygon:

```sh
g.region raster=soils_Kfactor -p
v.in.region output=soils_Kfactor_bbox
v.info map=soils_Kfactor_bbox
```

## SEE ALSO

*[g.region](g.region.md), [r.proj](r.proj.md), [v.info](v.info.md)*

## AUTHOR

Radim Blazek

## SOURCE CODE

Available at: [v.in.region source code](https://github.com/OSGeo/grass/tree/main/vector/v.in.region)
([history](https://github.com/OSGeo/grass/commits/main/vector/v.in.region))  
Latest change: Friday Feb 07 19:16:09 2025 in commit [a82a39f](https://github.com/OSGeo/grass/commit/a82a39f673b97fafcfce1604dc3e6015cb96487a)
