---
name: v.lrs.segment
description: Creates points/segments from input lines, linear reference system and positions read from stdin or a file.
keywords: [ vector, linear reference system, network ]
---

# v.lrs.segment

## NAME

***v.lrs.segment*** - Creates points/segments from input lines, linear reference system and positions read from stdin or a file.

### 
### SYNOPSIS

**v.lrs.segment**  
**v.lrs.segment --help**  
**v.lrs.segment**  **input**=*name*
 **output**=*name*
 [**llayer**=*string*]
 [**rsdriver**=*string*]
 [**rsdatabase**=*string*]
 **rstable**=*string*
 [**file**=*name*]
 [**--overwrite**]  [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**--overwrite**  
&nbsp;&nbsp;&nbsp;&nbsp;Allow output files to overwrite existing files  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**input**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of input vector map  
&nbsp;&nbsp;&nbsp;&nbsp;Input vector map containing lines  
**output**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Output vector map where segments will be written  
**llayer**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Layer number or name  
&nbsp;&nbsp;&nbsp;&nbsp;Line layer  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *1*  
**rsdriver**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Driver name for reference system table  
&nbsp;&nbsp;&nbsp;&nbsp;Options: *dbf, odbc, ogr, pg, sqlite*  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *sqlite*  
**rsdatabase**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Database name for reference system table  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *$GISDBASE/$LOCATION_NAME/$MAPSET/sqlite/sqlite.db*  
**rstable**=*string* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of the reference system table  
**file**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Name of file containing segment rules. If not given, read from stdin.

## DESCRIPTION

*v.lrs.segment* creates points/segments from input lines, linear
reference system and positions read from `standard in` or a file.

The format is as follows:  

```sh
P <point_id> <line_id> <milepost>+<offset> [<side offset>]
L <segment_id> <line_id> <milepost>+<offset> <milepost>+<offset> [<side offset>]
```

## NOTES

For more information and examples see the help page for
*v.lrs.segment*'s sister module, *[v.segment](v.segment.md)*.

## EXAMPLE

This example is written for the Spearfish dataset (it continues the
example from *v.lrs.create*).

In this example, the 'route_lrs' shall be extended for a new position
(point) along the LRS after bus stop 4:

```sh
# new point on LRS
echo "P 7 22 4+180" | v.lrs.segment route_lrs out=route_lrs_new rstable=route_lrs

g.region vector=route_lrs n=n+100 s=s-100 -p
d.erase
# existing LRS
d.vect route_lrs
d.vect busstops disp=attr attr=cat size=10 bg=white lcol=blue yref=bottom
d.vect busstops icon=basic/circle fcol=blue
db.select table=route_lrs

# show modified map
d.vect route_lrs_new col=red
```

## TODO

Figure out how to merge result into existing LRS map and table.

## SEE ALSO

*[v.lrs.create](v.lrs.create.md), [v.lrs.where](v.lrs.where.md),
[v.lrs.label](v.lrs.label.md), [v.segment](v.segment.md)*

*[LRS tutorial](lrs.md),  
[Introducing the Linear Reference System in
GRASS](https://foss4g.asia/2004/Full-Paper_PDF/Introducing-the-Linear-Reference-System-in-GRASS.pdf)*

## AUTHOR

Radim Blazek

## SOURCE CODE

Available at: [v.lrs.segment source code](https://github.com/OSGeo/grass/tree/main/vector/v.lrs/v.lrs.segment)
([history](https://github.com/OSGeo/grass/commits/main/vector/v.lrs/v.lrs.segment))  
Latest change: Friday Feb 07 19:16:09 2025 in commit [a82a39f](https://github.com/OSGeo/grass/commit/a82a39f673b97fafcfce1604dc3e6015cb96487a)
