---
name: v.lrs.where
description: Finds line id and real km+offset for given points in vector map using linear reference system.
keywords: [ vector, linear reference system, network ]
---

# v.lrs.where

## NAME

***v.lrs.where*** - Finds line id and real km+offset for given points in vector map using linear reference system.

### 
### SYNOPSIS

**v.lrs.where**  
**v.lrs.where --help**  
**v.lrs.where**  **lines**=*name*
 **points**=*name*
 [**llayer**=*string*]
 [**player**=*string*]
 [**rsdriver**=*string*]
 [**rsdatabase**=*string*]
 **rstable**=*string*
 [**threshold**=*float*]
 [**--verbose**]  [**--quiet**]  [**--ui**]

**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**lines**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of input vector map  
&nbsp;&nbsp;&nbsp;&nbsp;Input vector map containing lines  
**points**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of input vector map  
&nbsp;&nbsp;&nbsp;&nbsp;Input vector map containing points  
**llayer**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Layer number or name  
&nbsp;&nbsp;&nbsp;&nbsp;Line layer  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *1*  
**player**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Layer number or name  
&nbsp;&nbsp;&nbsp;&nbsp;Point layer  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *1*  
**rsdriver**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Driver name for reference system table  
&nbsp;&nbsp;&nbsp;&nbsp;Options: *dbf, odbc, ogr, pg, sqlite*  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *sqlite*  
**rsdatabase**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Database name for reference system table  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *$GISDBASE/$LOCATION_NAME/$MAPSET/sqlite/sqlite.db*  
**rstable**=*string* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of the reference system table  
**threshold**=*float*  
&nbsp;&nbsp;&nbsp;&nbsp;Maximum distance to nearest line  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *1000*

## DESCRIPTION

*v.lrs.where* identifies line id and real milepost+offset for points in
vector map using linear reference system.

## EXAMPLE

This example is written for the Spearfish dataset (it continues the
example from *v.lrs.create*).

In this example, the 'route_lrs' shall be queried for unknown positions
(points, stored in the map *newpoints*) along the LRS:

```sh
# generate query points
echo "590866.15|4926737.0
590933|4927133" | v.in.ascii out=newpoints

v.lrs.where lines=route_lrs points=newpoints rstable=route_lrs
pcat|lid|mpost|offset
pcat|lid|mpost|offset
1|22|4.000000+212.091461
2|22|6.000000+188.112093

# verification
g.region vector=route_lrs n=n+100 s=s-100 -p
d.erase
d.vect route_lrs
d.vect busstops disp=attr attr=cat size=10 bg=white lcol=blue yref=bottom
d.vect busstops icon=basic/circle fcol=blue
d.vect newpoints col=red

# measure distance to previous bus stop:
# use measuring tool in graphical user interface
```

## SEE ALSO

*[v.lrs.where](v.lrs.create.md), [v.lrs.segment](v.lrs.segment.md),
[v.lrs.label](v.lrs.label.md)*

*[LRS tutorial](lrs.md),  
[Introducing the Linear Reference System in
GRASS](https://foss4g.asia/2004/Full-Paper_PDF/Introducing-the-Linear-Reference-System-in-GRASS.pdf)*

## AUTHORS

Radim Blazek, ITC-irst/MPA Solutions  
Documentation update (based on above journal article and available
fragments): Markus Neteler

## SOURCE CODE

Available at: [v.lrs.where source code](https://github.com/OSGeo/grass/tree/main/vector/v.lrs/v.lrs.where)
([history](https://github.com/OSGeo/grass/commits/main/vector/v.lrs/v.lrs.where))  
Latest change: Friday Feb 07 19:16:09 2025 in commit [a82a39f](https://github.com/OSGeo/grass/commit/a82a39f673b97fafcfce1604dc3e6015cb96487a)
