---
name: v.net.allpairs
description: Computes the shortest path between all pairs of nodes in the network.
keywords: [ vector, network, shortest path ]
---

# v.net.allpairs

## NAME

***v.net.allpairs*** - Computes the shortest path between all pairs of nodes in the network.

### 
### SYNOPSIS

**v.net.allpairs**  
**v.net.allpairs --help**  
**v.net.allpairs** [**-g**]  **input**=*name*
 **output**=*name*
 [**arc_layer**=*string*]
 [**node_layer**=*string*]
 [**cats**=*range*]
 [**where**=*sql_query*]
 [**arc_column**=*name*]
 [**arc_backward_column**=*name*]
 [**node_column**=*string*]
 [**--overwrite**]  [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**-g**  
&nbsp;&nbsp;&nbsp;&nbsp;Use geodesic calculation for longitude-latitude projects  
**--overwrite**  
&nbsp;&nbsp;&nbsp;&nbsp;Allow output files to overwrite existing files  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**input**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of input vector map  
&nbsp;&nbsp;&nbsp;&nbsp;Or data source for direct OGR access  
**output**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name for output vector map  
**arc_layer**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Arc layer  
&nbsp;&nbsp;&nbsp;&nbsp;Vector features can have category values in different layers. This number determines which layer to use. When used with direct OGR access this is the layer name.  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *1*  
**node_layer**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Node layer  
&nbsp;&nbsp;&nbsp;&nbsp;Vector features can have category values in different layers. This number determines which layer to use. When used with direct OGR access this is the layer name.  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *2*  
**cats**=*range*  
&nbsp;&nbsp;&nbsp;&nbsp;Category values  
&nbsp;&nbsp;&nbsp;&nbsp;Example: 1,3,7-9,13  
**where**=*sql_query*  
&nbsp;&nbsp;&nbsp;&nbsp;WHERE conditions of SQL statement without 'where' keyword  
&nbsp;&nbsp;&nbsp;&nbsp;Example: income &lt; 1000 and population &gt;= 10000  
**arc_column**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Arc forward/both direction(s) cost column (number)  
**arc_backward_column**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Arc backward direction cost column (number)  
**node_column**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Node cost column (number)

## DESCRIPTION

*v.net.allpairs* computes the shortest path between each selected node
and all other selected nodes. The output is a vector with the selected
nodes and the shortest paths.

## NOTES

An attribute table is created and linked to layer *arc_layer*. The table
contains four columns: *cat*, *from_cat*, *to_cat*, *cost*. Each *cat*
entry denotes the category of the shortest path from the node with
category *from_cat* to the node with category *to_cat*. If points are
specified by **cats, layer** or **where** parameters then the table is
filled only for the selected points.  
If **arc_backward_column** is not given then then the same costs are
used for forward and backward arcs.

## EXAMPLE

Find shortest path along roads from selected archsites (Spearfish sample
dataset):

```sh
# prepare network: connect archsites to roads with threshold 200
v.net input=roads@PERMANENT points=archsites@PERMANENT \
output=roads_net operation=connect thresh=200

# verify result
v.category input=roads_net option=report

# only lines should have a category in layer 1
# only points should have a category in layer 2

# shortest path between all points with categories 1 - 5 in layer 2
v.net.allpairs input=roads_net cats=1-5 out=roads_net_all
v.db.select roads_net_all
```

Result in matrix form:

```sh
from\to 1       3       4       5
1   0       18820.386   17206.651   17373.274
3   18820.386   0       1739.079    9040.575
4   17206.651   1739.079    0       7426.84
5   17373.274   9040.575    7426.84     0
```

## SEE ALSO

*[v.net.path](v.net.path.md), [v.net.distance](v.net.distance.md)*

## AUTHORS

Daniel Bundala, Google Summer of Code 2009, Student  
Wolf Bergenheim, Mentor  
Markus Metz

## SOURCE CODE

Available at: [v.net.allpairs source code](https://github.com/OSGeo/grass/tree/main/vector/v.net.allpairs)
([history](https://github.com/OSGeo/grass/commits/main/vector/v.net.allpairs))  
Latest change: Friday Feb 07 19:16:09 2025 in commit [a82a39f](https://github.com/OSGeo/grass/commit/a82a39f673b97fafcfce1604dc3e6015cb96487a)
