---
name: v.net.bridge
description: Computes bridges and articulation points in the network.
keywords: [ vector, network, articulation points ]
---

# v.net.bridge

## NAME

***v.net.bridge*** - Computes bridges and articulation points in the network.

### 
### SYNOPSIS

**v.net.bridge**  
**v.net.bridge --help**  
**v.net.bridge**  **input**=*name*
 **output**=*name*
 [**arc_layer**=*string*]
 [**node_layer**=*string*]
 [**arc_column**=*name*]
 [**arc_backward_column**=*name*]
 [**node_column**=*string*]
 **method**=*string*
 [**--overwrite**]  [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**--overwrite**  
&nbsp;&nbsp;&nbsp;&nbsp;Allow output files to overwrite existing files  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**input**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of input vector map  
&nbsp;&nbsp;&nbsp;&nbsp;Or data source for direct OGR access  
**output**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name for output vector map  
**arc_layer**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Arc layer  
&nbsp;&nbsp;&nbsp;&nbsp;Vector features can have category values in different layers. This number determines which layer to use. When used with direct OGR access this is the layer name.  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *1*  
**node_layer**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Node layer  
&nbsp;&nbsp;&nbsp;&nbsp;Vector features can have category values in different layers. This number determines which layer to use. When used with direct OGR access this is the layer name.  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *2*  
**arc_column**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Arc forward/both direction(s) cost column (number)  
**arc_backward_column**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Arc backward direction cost column (number)  
**node_column**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Node cost column (number)  
**method**=*string* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Feature type  
&nbsp;&nbsp;&nbsp;&nbsp;Options: *bridge, articulation*  
&nbsp;&nbsp;&nbsp;&nbsp;**bridge**: Finds bridges  
&nbsp;&nbsp;&nbsp;&nbsp;**articulation**: Finds articulation points

## DESCRIPTION

*v.net.bridge* finds bridges and articulation points in a network.

## NOTES

Bridge in a network is an edge/line whose removal would disconnect the
(sub-)network. A node is an articulation point if its removal would
disconnect the (sub-)network. For more information and formal
definitions check the wikipedia entries:
[bridge](https://en.wikipedia.org/wiki/Bridge_%28graph_theory%29) and
[articulation point](https://en.wikipedia.org/wiki/Cut_vertex).

The output of the module contains the selected features. For
**method=bridge**, lines corresponding to bridges are copied from the
input map to the output map. On the other hand, for
**method=articulation**, points are created on the positions of
articulation points.

In GRASS GIS, *line* is not always a single line segment. It might be,
and often is, a sequence of line segments between two intersections.
Also, articulation point is a standard graph theoretic terminology which
is slightly misleading in GRASS. An articulation point in graph theory
is an articulation *node* in GRASS terminology.

## SEE ALSO

*[v.net](v.net.md), [v.category](v.category.md)*

## AUTHORS

Daniel Bundala, Google Summer of Code 2009, Student  
Wolf Bergenheim, Mentor

## SOURCE CODE

Available at: [v.net.bridge source code](https://github.com/OSGeo/grass/tree/main/vector/v.net.bridge)
([history](https://github.com/OSGeo/grass/commits/main/vector/v.net.bridge))  
Latest change: Friday Feb 07 19:16:09 2025 in commit [a82a39f](https://github.com/OSGeo/grass/commit/a82a39f673b97fafcfce1604dc3e6015cb96487a)
