---
name: v.net.centrality
description: Computes degree, centrality, betweeness, closeness and eigenvector centrality measures in the network.
keywords: [ vector, network, centrality measures ]
---

# v.net.centrality

## NAME

***v.net.centrality*** - Computes degree, centrality, betweeness, closeness and eigenvector centrality measures in the network.

### 
### SYNOPSIS

**v.net.centrality**  
**v.net.centrality --help**  
**v.net.centrality** [**-ga**]  **input**=*name*
 [**arc_layer**=*string*]
 [**node_layer**=*string*]
 **output**=*name*
 [**cats**=*range*]
 [**where**=*sql_query*]
 [**arc_column**=*name*]
 [**arc_backward_column**=*name*]
 [**node_column**=*string*]
 [**degree**=*name*]
 [**closeness**=*name*]
 [**betweenness**=*name*]
 [**eigenvector**=*name*]
 [**iterations**=*integer*]
 [**error**=*float*]
 [**--overwrite**]  [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**-g**  
&nbsp;&nbsp;&nbsp;&nbsp;Use geodesic calculation for longitude-latitude projects  
**-a**  
&nbsp;&nbsp;&nbsp;&nbsp;Add points on nodes  
**--overwrite**  
&nbsp;&nbsp;&nbsp;&nbsp;Allow output files to overwrite existing files  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**input**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of input vector map  
&nbsp;&nbsp;&nbsp;&nbsp;Or data source for direct OGR access  
**arc_layer**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Arc layer  
&nbsp;&nbsp;&nbsp;&nbsp;Vector features can have category values in different layers. This number determines which layer to use. When used with direct OGR access this is the layer name.  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *1*  
**node_layer**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Node layer  
&nbsp;&nbsp;&nbsp;&nbsp;Vector features can have category values in different layers. This number determines which layer to use. When used with direct OGR access this is the layer name.  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *2*  
**output**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name for output vector map  
**cats**=*range*  
&nbsp;&nbsp;&nbsp;&nbsp;Category values  
&nbsp;&nbsp;&nbsp;&nbsp;Example: 1,3,7-9,13  
**where**=*sql_query*  
&nbsp;&nbsp;&nbsp;&nbsp;WHERE conditions of SQL statement without 'where' keyword  
&nbsp;&nbsp;&nbsp;&nbsp;Example: income &lt; 1000 and population &gt;= 10000  
**arc_column**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Arc forward/both direction(s) cost column (number)  
**arc_backward_column**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Arc backward direction cost column (number)  
**node_column**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Node cost column (number)  
**degree**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Name of degree centrality column  
**closeness**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Name of closeness centrality column  
**betweenness**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Name of betweenness centrality column  
**eigenvector**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Name of eigenvector centrality column  
**iterations**=*integer*  
&nbsp;&nbsp;&nbsp;&nbsp;Maximum number of iterations to compute eigenvector centrality  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *1000*  
**error**=*float*  
&nbsp;&nbsp;&nbsp;&nbsp;Cumulative error tolerance for eigenvector centrality  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *0.1*

## DESCRIPTION

*v.net.centrality* computes degree, closeness, betweenness and
eigenvector centrality measures.

## NOTES

The module computes various centrality measures for each node and stores
them in the given columns of an attribute table, which is created and
linked to the output map. For the description of these, please check the
following [wikipedia article](https://en.wikipedia.org/wiki/Centrality).
If the column name is not given for a measure then that measure is not
computed. If **-a** flag is set then points are added on nodes without
points. Also, the points for which the output is computed can be
specified by **cats**, **layer** and **where** parameters. However, if
any of these parameters is present then **-a** flag is ignored and no
new points are added.  
Betweenness measure is not normalised. In order to get the normalised
values (between 0 and 1), each number needs to be divided by *N choose
2=N\*(N-1)/2* where N is the number of nodes in the connected component.
Computation of eigenvector measure terminates if the given number of
iterations is reached or the cumulative *squared* error between the
successive iterations is less than **error**.

## EXAMPLES

Compute closeness and betweenness centrality measures for each node and
produce a map containing not only points already present in the input
map but a map with point on every node.

```sh
v.net.centrality input=roads output=roads_cent closeness=closeness \
      betweenness=betweenness -a
```

## SEE ALSO

*[v.net](v.net.md), [v.generalize](v.generalize.md)*

## AUTHORS

Daniel Bundala, Google Summer of Code 2009, Student  
Wolf Bergenheim, Mentor

## SOURCE CODE

Available at: [v.net.centrality source code](https://github.com/OSGeo/grass/tree/main/vector/v.net.centrality)
([history](https://github.com/OSGeo/grass/commits/main/vector/v.net.centrality))  
Latest change: Friday Feb 07 19:16:09 2025 in commit [a82a39f](https://github.com/OSGeo/grass/commit/a82a39f673b97fafcfce1604dc3e6015cb96487a)
