---
name: v.net.components
description: Computes strongly and weakly connected components in the network.
keywords: [ vector, network, components ]
---

# v.net.components

## NAME

***v.net.components*** - Computes strongly and weakly connected components in the network.

### 
### SYNOPSIS

**v.net.components**  
**v.net.components --help**  
**v.net.components** [**-a**]  **input**=*name*
 [**arc_layer**=*string*]
 [**node_layer**=*string*]
 [**arc_column**=*name*]
 [**arc_backward_column**=*name*]
 [**node_column**=*string*]
 **output**=*name*
 **method**=*string*
 [**--overwrite**]  [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**-a**  
&nbsp;&nbsp;&nbsp;&nbsp;Add points on nodes  
**--overwrite**  
&nbsp;&nbsp;&nbsp;&nbsp;Allow output files to overwrite existing files  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**input**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of input vector map  
&nbsp;&nbsp;&nbsp;&nbsp;Or data source for direct OGR access  
**arc_layer**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Arc layer  
&nbsp;&nbsp;&nbsp;&nbsp;Vector features can have category values in different layers. This number determines which layer to use. When used with direct OGR access this is the layer name.  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *1*  
**node_layer**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Node layer  
&nbsp;&nbsp;&nbsp;&nbsp;Vector features can have category values in different layers. This number determines which layer to use. When used with direct OGR access this is the layer name.  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *2*  
**arc_column**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Arc forward/both direction(s) cost column (number)  
**arc_backward_column**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Arc backward direction cost column (number)  
**node_column**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Node cost column (number)  
**output**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name for output vector map  
**method**=*string* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Type of components  
&nbsp;&nbsp;&nbsp;&nbsp;Options: *weak, strong*  
&nbsp;&nbsp;&nbsp;&nbsp;**weak**: Weakly connected components  
&nbsp;&nbsp;&nbsp;&nbsp;**strong**: Strongly connected components

## DESCRIPTION

*v.net.components* computes the weakly and strongly connected components
in a network.

## NOTES

Two nodes, *u* and *v* are in the same strongly connected component if
there are directed paths from *u* to *v* and from *v* to *u*. The nodes
are in the same weakly connected component if, ignoring edge directions,
there is a path between them.

The type of components is specified by **method** parameter.
*v.net.components* creates a table and links it to layer 1. This table
contains only two integer columns: *cat* and *comp*. If a point or both
endpoints of a line belong to the same component then the point/line is
written to the output map and appropriate information is stored in the
table. If **-a** flag is set then new points are added on the nodes
without points. These points have category numbers larger than any
category used in the input map.

One-way roads can be defined by assigning a cost of -1 to the
appropriate cost column (**arc_column** or **arc_backward_column**).
This affects only strongly connected components. Network nodes can be
closed by assigning a cost of -1 to the node cost column. All nodes with
a cost \< 0 can not be traversed and are end points, while all nodes
with a cost ≥ 0 can be traversed. This affects both weakly and strongly
connected components.

## EXAMPLES

Any road network should form a single strongly connected component.
Otherwise, it is impossible to travel between some places.

```sh
v.net.components input=roads output=roads_components method=strong
```

## SEE ALSO

*[v.net](v.net.md), [v.category](v.category.md)*

## AUTHORS

Daniel Bundala, Google Summer of Code 2009, Student  
Wolf Bergenheim, Mentor  
Markus Metz

## SOURCE CODE

Available at: [v.net.components source code](https://github.com/OSGeo/grass/tree/main/vector/v.net.components)
([history](https://github.com/OSGeo/grass/commits/main/vector/v.net.components))  
Latest change: Friday Feb 07 19:16:09 2025 in commit [a82a39f](https://github.com/OSGeo/grass/commit/a82a39f673b97fafcfce1604dc3e6015cb96487a)
