---
name: v.net.flow
description: Computes the maximum flow between two sets of nodes in the network.
keywords: [ vector, network, flow ]
---

# v.net.flow

## NAME

***v.net.flow*** - Computes the maximum flow between two sets of nodes in the network.

### 
### SYNOPSIS

**v.net.flow**  
**v.net.flow --help**  
**v.net.flow**  **input**=*name*
 [**arc_layer**=*string*]
 [**node_layer**=*string*]
 **output**=*name*
 **cut**=*name*
 [**arc_column**=*name*]
 [**arc_backward_column**=*name*]
 [**node_column**=*name*]
 [**source_cats**=*range*]
 [**source_where**=*sql_query*]
 [**sink_cats**=*range*]
 [**sink_where**=*sql_query*]
 [**--overwrite**]  [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**--overwrite**  
&nbsp;&nbsp;&nbsp;&nbsp;Allow output files to overwrite existing files  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**input**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of input vector map  
&nbsp;&nbsp;&nbsp;&nbsp;Or data source for direct OGR access  
**arc_layer**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Arc layer  
&nbsp;&nbsp;&nbsp;&nbsp;Vector features can have category values in different layers. This number determines which layer to use. When used with direct OGR access this is the layer name.  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *1*  
**node_layer**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Node layer  
&nbsp;&nbsp;&nbsp;&nbsp;Vector features can have category values in different layers. This number determines which layer to use. When used with direct OGR access this is the layer name.  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *2*  
**output**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name for output vector map  
**cut**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name for output vector map containing a minimum cut  
**arc_column**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Arc forward/both direction(s) cost column (number)  
**arc_backward_column**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Arc backward direction cost column (number)  
**node_column**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Node cost column (number)  
**source_cats**=*range*  
&nbsp;&nbsp;&nbsp;&nbsp;Source category values  
&nbsp;&nbsp;&nbsp;&nbsp;Example: 1,3,7-9,13  
**source_where**=*sql_query*  
&nbsp;&nbsp;&nbsp;&nbsp;Source WHERE conditions of SQL statement without 'where' keyword  
&nbsp;&nbsp;&nbsp;&nbsp;Example: income &lt; 1000 and population &gt;= 10000  
**sink_cats**=*range*  
&nbsp;&nbsp;&nbsp;&nbsp;Sink category values  
&nbsp;&nbsp;&nbsp;&nbsp;Example: 1,3,7-9,13  
**sink_where**=*sql_query*  
&nbsp;&nbsp;&nbsp;&nbsp;Sink WHERE conditions of SQL statement without 'where' keyword  
&nbsp;&nbsp;&nbsp;&nbsp;Example: income &lt; 1000 and population &gt;= 10000

## DESCRIPTION

*v.net.flow* computes the maximum flow and minimum cut between two sets
of nodes.

## NOTES

The two sets of nodes are called *sources* and *sink* and *v.net.flow*
finds the maximum flow from the former to the latter ones. Edge
capacities can be specified by **arc_column** for forward direction and
**arc_backward_column** for backward direction. If the latter parameter
is omitted then the same capacity is used in either direction. The sets
are given by the respective **cats**, **layer** and **where**
parameters. Maximum flow corresponds to the maximum amount of water
possibly flowing through the network preserving the capacity constraints
and minimum cut to the set of edges of minimum total capacity completely
separating sources from sinks. The cut produced by this module
corresponds to the first fully saturated edges from sources to sinks. An
attribute table containing the flow information is linked to the
**output** map. The table consists of two columns: *cat* and *flow* and
stores the flow along each line. Negative flow means that "water" is
flowing in the backward direction. **Cut** map contains the edges in the
minimum cut.  
A famous
[result](https://en.wikipedia.org/wiki/Max-flow_min-cut_theorem) says
that the total amount of water flowing is equal to the minimum cut.

## EXAMPLES

Find maximum flow from factories to stores using SPEED for the
capacities.

```sh
v.net.flow input=roads output=roads_flow cut=roads_cut arc_column=SPEED \
           source_where="type=factory" sink_where="type=store"
```

If all the capacties are one then the minimum cut corresponds to the
minimum number of edges separating sources from sinks.

```sh
v.net.flow input=network output=flow cut=cut arc_column=ones \
           source_cats=1-10 sink_cats=100-100
```

## SEE ALSO

*[v.net](v.net.md), [v.net.connectivity](v.net.connectivity.md)*

## AUTHORS

Daniel Bundala, Google Summer of Code 2009, Student  
Wolf Bergenheim, Mentor

## SOURCE CODE

Available at: [v.net.flow source code](https://github.com/OSGeo/grass/tree/main/vector/v.net.flow)
([history](https://github.com/OSGeo/grass/commits/main/vector/v.net.flow))  
Latest change: Friday Feb 07 19:16:09 2025 in commit [a82a39f](https://github.com/OSGeo/grass/commit/a82a39f673b97fafcfce1604dc3e6015cb96487a)
