---
name: v.net.spanningtree
description: Computes minimum spanning tree for the network.
keywords: [ vector, network, spanning tree ]
---

# v.net.spanningtree

## NAME

***v.net.spanningtree*** - Computes minimum spanning tree for the network.

### 
### SYNOPSIS

**v.net.spanningtree**  
**v.net.spanningtree --help**  
**v.net.spanningtree** [**-g**]  **input**=*name*
 **output**=*name*
 [**arc_layer**=*string*]
 [**node_layer**=*string*]
 [**arc_column**=*name*]
 [**node_column**=*name*]
 [**--overwrite**]  [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**-g**  
&nbsp;&nbsp;&nbsp;&nbsp;Use geodesic calculation for longitude-latitude projects  
**--overwrite**  
&nbsp;&nbsp;&nbsp;&nbsp;Allow output files to overwrite existing files  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**input**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of input vector map  
&nbsp;&nbsp;&nbsp;&nbsp;Or data source for direct OGR access  
**output**=*name* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name for output vector map  
**arc_layer**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Arc layer  
&nbsp;&nbsp;&nbsp;&nbsp;Vector features can have category values in different layers. This number determines which layer to use. When used with direct OGR access this is the layer name.  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *1*  
**node_layer**=*string*  
&nbsp;&nbsp;&nbsp;&nbsp;Node layer  
&nbsp;&nbsp;&nbsp;&nbsp;Vector features can have category values in different layers. This number determines which layer to use. When used with direct OGR access this is the layer name.  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *2*  
**arc_column**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Arc forward/both direction(s) cost column (number)  
**node_column**=*name*  
&nbsp;&nbsp;&nbsp;&nbsp;Node cost column (number)

## DESCRIPTION

*v.net.spanningtree* finds the minimum spanning tree in a network.

## NOTES

A spanning tree is a minimum cost subnetwork connecting all nodes in an
undirected network (same forward and backward costs). If a network is
disconnected then the module computes the minimum spanning tree for each
(weakly) connected component. So, strictly speaking,
*v.net.spanningtree* does not compute spanning tree but a spanning
forest. As the name suggests, a spanning tree is a tree. That is, it
contains no cycles and if a component has N nodes then the tree has N-1
edges connecting all nodes. **Accol** is used to specify the costs of
the edges. The **output** consists of the edges in the spanning tree.

## EXAMPLES

Find cheapest set of pipelines connecting all nodes.

```sh
v.net.spanningtree input=projected_pipelines output=spanningtree accol=cost
```

## SEE ALSO

*[v.net](v.net.md), [v.net.steiner](v.net.steiner.md)*

## AUTHORS

Daniel Bundala, Google Summer of Code 2009, Student  
Wolf Bergenheim, Mentor

## SOURCE CODE

Available at: [v.net.spanningtree source code](https://github.com/OSGeo/grass/tree/main/vector/v.net.spanningtree)
([history](https://github.com/OSGeo/grass/commits/main/vector/v.net.spanningcommits))  
Latest change: Friday Feb 07 19:16:09 2025 in commit [a82a39f](https://github.com/OSGeo/grass/commit/a82a39f673b97fafcfce1604dc3e6015cb96487a)
