---
name: v.what
description: Queries a vector map at given locations.
keywords: [ vector, querying, position ]
---

# v.what

## NAME

***v.what*** - Queries a vector map at given locations.

### 
### SYNOPSIS

**v.what**  
**v.what --help**  
**v.what** [**-dagjm**]  **map**=*name* [,*name*,...]
 [**layer**=*string* [,*string*,...]]
 [**type**=*string* [,*string*,...]]
 **coordinates**=*east,north*
 [**distance**=*float*]
 [**columns**=*name* [,*name*,...]]
 [**--verbose**]  [**--quiet**]  [**--ui**]

#### Flags

**-d**  
&nbsp;&nbsp;&nbsp;&nbsp;Print topological information (debugging)  
**-a**  
&nbsp;&nbsp;&nbsp;&nbsp;Print attribute information  
**-g**  
&nbsp;&nbsp;&nbsp;&nbsp;Print the stats in shell script style  
**-j**  
&nbsp;&nbsp;&nbsp;&nbsp;Print the stats in JSON  
**-m**  
&nbsp;&nbsp;&nbsp;&nbsp;Print multiple features if overlapping features are found  
**--help**  
&nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
**--verbose**  
&nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
**--quiet**  
&nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
**--ui**  
&nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

#### Parameters

**map**=*name* [,*name*,...] **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Name of vector map(s)  
**layer**=*string* [,*string*,...]  
&nbsp;&nbsp;&nbsp;&nbsp;Layer number or name ('-1' for all layers)  
&nbsp;&nbsp;&nbsp;&nbsp;A single vector map can be connected to multiple database tables. This number determines which table to use. When used with direct OGR access this is the layer name.  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *-1*  
**type**=*string* [,*string*,...]  
&nbsp;&nbsp;&nbsp;&nbsp;Input feature type  
&nbsp;&nbsp;&nbsp;&nbsp;Options: *point, line, boundary, centroid, area, face, kernel*  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *point,line,area,face*  
**coordinates**=*east,north* **[required]**  
&nbsp;&nbsp;&nbsp;&nbsp;Coordinates for query  
&nbsp;&nbsp;&nbsp;&nbsp;'-' for standard input  
**distance**=*float*  
&nbsp;&nbsp;&nbsp;&nbsp;Query threshold distance  
&nbsp;&nbsp;&nbsp;&nbsp;Default: *0*  
**columns**=*name* [,*name*,...]  
&nbsp;&nbsp;&nbsp;&nbsp;Name of attribute column(s)  
&nbsp;&nbsp;&nbsp;&nbsp;Default: all columns

## DESCRIPTION

*v.what* outputs the category number value(s) associated with
user-specified location(s) in user-specified vector map layer(s). This
module was derived from the *d.what.vect* module by removing all
interactive code and modification of the output for easy parsing. Using
the *-g* flag generates script-style output which is easily parsable.

## EXAMPLE

North Carolina sample dataset example:

Query polygon at given position:

```sh
v.what zipcodes_wake coordinates=637502.25,221744.25
```

Find closest hospital to given position within given distance (search
radius):

```sh
v.what hospitals coordinates=542690.4,204802.7 distance=2000000
```

## SEE ALSO

*[d.what.rast](d.what.rast.md), [d.what.vect](d.what.vect.md),
[v.rast.stats](v.rast.stats.md), [v.vect.stats](v.vect.stats.md),
[v.what.rast](v.what.rast.md), [v.what.rast3](v.what.rast3.md),
[v.what.vect](v.what.vect.md)*

## AUTHOR

Trevor Wiens  
Edmonton, Alberta, Canada

## SOURCE CODE

Available at: [v.what source code](https://github.com/OSGeo/grass/tree/main/vector/v.what)
([history](https://github.com/OSGeo/grass/commits/main/vector/v.what))  
Latest change: Monday Mar 10 21:11:57 2025 in commit [bd253b7](https://github.com/OSGeo/grass/commit/bd253b721a7bc07b4c89f4d017a853b9727188b0)
